Module booking_part_api

Module booking_part_api 

Enums

CreateBookingBookedOffersAncillariesError
struct for typed errors of method create_booking_booked_offers_ancillaries
CreateBookingBookedOffersPartsError
struct for typed errors of method create_booking_booked_offers_parts
CreateBookingBookedOffersReservationsError
struct for typed errors of method create_booking_booked_offers_reservations
DeleteBookingBookedOffersAdmissionError
struct for typed errors of method delete_booking_booked_offers_admission
DeleteBookingBookedOffersAncillaryError
struct for typed errors of method delete_booking_booked_offers_ancillary
DeleteBookingBookedOffersPartsError
struct for typed errors of method delete_booking_booked_offers_parts
DeleteBookingBookedOffersReservationsError
struct for typed errors of method delete_booking_booked_offers_reservations

Functions

create_booking_booked_offers_ancillariesDeprecated
DEPRECATED in favour to unified endpoint handling both ancillaries and reservations. Adds an ancillary to a booking. A provider can decide to allow or reject additional admissions, reservations or ancillaries on an confirmed booking.
create_booking_booked_offers_parts
Adds a reservation or an ancillary to a booking. A provider can decide to allow or reject additional admissions, reservations or ancillaries on an confirmed booking.
create_booking_booked_offers_reservationsDeprecated
DEPRECATED in favour to unified endpoint handling both ancillaries and reservations. Adds a reservation to a booking. A provider can decide to allow or reject additional admissions, reservations or ancillaries on an confirmed booking.
delete_booking_booked_offers_admission
Removes an admission from pre-booked booking.It is up to the provider to change or remove dependent bookedOfferParts or to reject the request. A repricing might occur.
delete_booking_booked_offers_ancillaryDeprecated
delete_booking_booked_offers_parts
delete_booking_booked_offers_reservationsDeprecated