Module bookings_api

Module bookings_api 

Enums

DeleteBookingsIdError
struct for typed errors of method delete_bookings_id
GetBookingsIdError
struct for typed errors of method get_bookings_id
GetBookingsIdHistoryError
struct for typed errors of method get_bookings_id_history
PostBookingCleanupError
struct for typed errors of method post_booking_cleanup
PostBookingsError
struct for typed errors of method post_bookings
UpdateBookingError
struct for typed errors of method update_booking

Functions

delete_bookings_id
It is only possible before the booking is confirmed.
get_bookings_id
get_bookings_id_history
post_booking_cleanup
The booking is cleaned up completely: confirmed items are refunded, and unconfirmed items are deleted. – Attention point: refundDate and overruleCode are deprecated request attributes and will be ignored
post_bookings
update_booking
Updates fulfillment types, place selection and add payment. Does not confirm the booking. The booking is confirmed by calling ‘POST /bookings/{bookingId}/fulfillments’.