Module bookings_split_api

Module bookings_split_api 

Enums

SplitBookingsError
struct for typed errors of method split_bookings

Functions

split_bookings
Splits a booking into a set of bookings according to the defined groups of a passenger(s). Only possible if allowed by the underlying tariff, if the bookedOffers are sufficiently partitioned and no pricing is needed.