Module exchange_api

Module exchange_api 

Enums

CreateBookingsExchangeOperationsError
struct for typed errors of method create_bookings_exchange_operations
CreateExchangeOffersCollectionError
struct for typed errors of method create_exchange_offers_collection
DeleteBookingsExchangeOperationError
struct for typed errors of method delete_bookings_exchange_operation
GetBookingsExchangeOperationsError
struct for typed errors of method get_bookings_exchange_operations
UpdateBookingsExchangeOperationsError
struct for typed errors of method update_bookings_exchange_operations

Functions

create_bookings_exchange_operations
create_exchange_offers_collection
Returns exchange offers for specified fulfillments submitted given requested new trip characteristics.
delete_bookings_exchange_operation
get_bookings_exchange_operations
Returns the exchange operation with the id provided. It may be a provisional or a confirmed exchange.
update_bookings_exchange_operations