Module master_data_api

Module master_data_api 

Enums

GetCoachDeckLayoutError
struct for typed errors of method get_coach_deck_layout
GetCoachDeckLayoutsError
struct for typed errors of method get_coach_deck_layouts
GetCoachLayoutsError
struct for typed errors of method get_coach_layouts
GetCoachLayoutsLayoutIdError
struct for typed errors of method get_coach_layouts_layout_id
GetPassengerCategoriesError
struct for typed errors of method get_passenger_categories
GetPlacesError
struct for typed errors of method get_places
GetProductTagsError
struct for typed errors of method get_product_tags
GetProductsError
struct for typed errors of method get_products
GetProductsIdError
struct for typed errors of method get_products_id
GetReductionCardsError
struct for typed errors of method get_reduction_cards
GetZonesError
struct for typed errors of method get_zones

Functions

get_coach_deck_layout
Retrieve a coach layout description needed for graphical reservation for a given layout id.
get_coach_deck_layouts
Retrieve the coach layout description needed for graphical reservation. The coach layouts can either be retrieved as a complete list or specificity for a train identified via offerId and reservationId or fareId
get_coach_layoutsDeprecated
Retrieve the coach layout description needed for graphical reservation. The coach layouts can either be retrieved as a complete list or specificity for a train identified via offerId and reservationId or fareId.

Deprecated: Substituted by getCoachDeckLayouts (since: 3.5.0, removed with: 4.0.0)
get_coach_layouts_layout_idDeprecated
Retrieve a coach layout description needed for graphical reservation for a given layout id.

Deprecated: Substituted by getCoachDeckLayout (since: 3.5.0, removed with: 4.0.0)
get_passenger_categories
Provider may optionally define passenger categories. These are usually intended for frontend (UI) usage instead of full passenger specification entry when provider works with unified list of passenger categories. For precise entry, or when PassengerCategory is not defined, the full passenger specification must always be supported by the provider.
get_places
get_product_tags
get_products
get_products_id
get_reduction_cards
returns a collection of reduction card definitions
get_zones