Module offer_overview_api

Module offer_overview_api 

Enums

GetOfferOverviewRouteError
struct for typed errors of method get_offer_overview_route
GetOfferOverviewTripError
struct for typed errors of method get_offer_overview_trip

Functions

get_offer_overview_route
Returns an overview of prices for a given route search and criteria. The overview does not contain detailed offer information, but only the prices.
get_offer_overview_trip
Returns an overview of prices for a given trip search and criteria. The overview does not contain detailed offer information, but only the prices.