Module refund_api

Module refund_api 

Enums

DeleteRefundOffersError
struct for typed errors of method delete_refund_offers
GetRefundOffersError
struct for typed errors of method get_refund_offers
PatchRefundOffersError
struct for typed errors of method patch_refund_offers
PostPrepareRefundOffersError
struct for typed errors of method post_prepare_refund_offers
PostRefundOffersError
struct for typed errors of method post_refund_offers

Functions

delete_refund_offers
In case the unconfimed refund offer is not sored in the booking object the delete request must return an ok (http 204). In case the refund offer is already confirmed and can not be deleted the reply must be an error (http 409 conflict).
get_refund_offers
patch_refund_offers
post_prepare_refund_offers
Step 1 in a two phase commit process. An aggregator can use this to secure that all underlaying provider systems are up and running and the provider booking is ready to be refunded.
post_refund_offers
The RefundOffer contains the required information on the potential operation. One refund offer can then be accepted via a PATCH, deleted or left to die at the end of its lifetime.