Module trips_api

Module trips_api 

Enums

GetTripsCollectionIdError
struct for typed errors of method get_trips_collection_id
GetTripsIdError
struct for typed errors of method get_trips_id
PostTripsChangeError
struct for typed errors of method post_trips_change
PostTripsError
struct for typed errors of method post_trips

Functions

get_trips_collection_id
Returns a collection of trips for a for a given trips collection id. The unique codes of the origin and destination can be resolved using the places service.
get_trips_id
A trip consists of one or more legs for a given tripId. Depending on the embed either references or full location definitions is returned.
post_trips
Returns trips for a given trip request based on the OJP specification.
post_trips_change
Returns a new trip for given OJP parameters based on an already existing trip.