AbstractBookingPart

Enum AbstractBookingPart 

pub enum AbstractBookingPart {
    Admission {
Show 33 fields id: String, summary: Option<String>, created_on: String, confirmable_until: Option<String>, valid_from: String, valid_until: Option<String>, confirmed_on: Option<String>, confirmed_fulfillment_options: Option<Box<FulfillmentOption>>, price: Box<Price>, refund_amount: Option<Box<Price>>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, summary_product_id: Option<String>, products: Option<Vec<ProductLegAssociation>>, status: BookingPartStatus, pricing_status: Option<String>, offer_mode: Option<OfferMode>, booking_part_code: Option<String>, distributor_booking_ref: Option<String>, retailer_booking_ref: Option<String>, passenger_ids: Vec<String>, available_fulfillment_options: Option<Vec<FulfillmentOption>>, refundable: RefundType, exchangeable: ExchangeableType, after_sale_conditions: Option<Vec<AfterSaleCondition>>, after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reductions: Option<Vec<CardReference>>, indicated_consumption: Option<Box<IndicatedConsumption>>, accounting_ref: Option<Box<AccountingRef>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>,
}, Ancillary {
Show 33 fields id: String, summary: Option<String>, created_on: String, confirmable_until: Option<String>, valid_from: String, valid_until: Option<String>, confirmed_on: Option<String>, confirmed_fulfillment_options: Option<Box<FulfillmentOption>>, price: Box<Price>, refund_amount: Option<Box<Price>>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, summary_product_id: Option<String>, products: Option<Vec<ProductLegAssociation>>, status: BookingPartStatus, pricing_status: Option<String>, offer_mode: Option<OfferMode>, booking_part_code: Option<String>, distributor_booking_ref: Option<String>, retailer_booking_ref: Option<String>, passenger_ids: Vec<String>, available_fulfillment_options: Option<Vec<FulfillmentOption>>, refundable: RefundType, exchangeable: ExchangeableType, after_sale_conditions: Option<Vec<AfterSaleCondition>>, after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reductions: Option<Vec<CardReference>>, indicated_consumption: Option<Box<IndicatedConsumption>>, accounting_ref: Option<Box<AccountingRef>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>,
}, ContinuousServiceBookingPart {
Show 33 fields id: String, summary: Option<String>, created_on: String, confirmable_until: Option<String>, valid_from: String, valid_until: Option<String>, confirmed_on: Option<String>, confirmed_fulfillment_options: Option<Box<FulfillmentOption>>, price: Box<Price>, refund_amount: Option<Box<Price>>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, summary_product_id: Option<String>, products: Option<Vec<ProductLegAssociation>>, status: BookingPartStatus, pricing_status: Option<String>, offer_mode: Option<OfferMode>, booking_part_code: Option<String>, distributor_booking_ref: Option<String>, retailer_booking_ref: Option<String>, passenger_ids: Vec<String>, available_fulfillment_options: Option<Vec<FulfillmentOption>>, refundable: RefundType, exchangeable: ExchangeableType, after_sale_conditions: Option<Vec<AfterSaleCondition>>, after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reductions: Option<Vec<CardReference>>, indicated_consumption: Option<Box<IndicatedConsumption>>, accounting_ref: Option<Box<AccountingRef>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>,
}, ContinuousServiceOfferPart {
Show 33 fields id: String, summary: Option<String>, created_on: String, confirmable_until: Option<String>, valid_from: String, valid_until: Option<String>, confirmed_on: Option<String>, confirmed_fulfillment_options: Option<Box<FulfillmentOption>>, price: Box<Price>, refund_amount: Option<Box<Price>>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, summary_product_id: Option<String>, products: Option<Vec<ProductLegAssociation>>, status: BookingPartStatus, pricing_status: Option<String>, offer_mode: Option<OfferMode>, booking_part_code: Option<String>, distributor_booking_ref: Option<String>, retailer_booking_ref: Option<String>, passenger_ids: Vec<String>, available_fulfillment_options: Option<Vec<FulfillmentOption>>, refundable: RefundType, exchangeable: ExchangeableType, after_sale_conditions: Option<Vec<AfterSaleCondition>>, after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reductions: Option<Vec<CardReference>>, indicated_consumption: Option<Box<IndicatedConsumption>>, accounting_ref: Option<Box<AccountingRef>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>,
}, Reservation {
Show 33 fields id: String, summary: Option<String>, created_on: String, confirmable_until: Option<String>, valid_from: String, valid_until: Option<String>, confirmed_on: Option<String>, confirmed_fulfillment_options: Option<Box<FulfillmentOption>>, price: Box<Price>, refund_amount: Option<Box<Price>>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, summary_product_id: Option<String>, products: Option<Vec<ProductLegAssociation>>, status: BookingPartStatus, pricing_status: Option<String>, offer_mode: Option<OfferMode>, booking_part_code: Option<String>, distributor_booking_ref: Option<String>, retailer_booking_ref: Option<String>, passenger_ids: Vec<String>, available_fulfillment_options: Option<Vec<FulfillmentOption>>, refundable: RefundType, exchangeable: ExchangeableType, after_sale_conditions: Option<Vec<AfterSaleCondition>>, after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reductions: Option<Vec<CardReference>>, indicated_consumption: Option<Box<IndicatedConsumption>>, accounting_ref: Option<Box<AccountingRef>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>,
}, }

Variants



Admission

Fields

summary: Option<String>
created_on: String

Validity of offer towards passenger

confirmable_until: Option<String>

confirmationTimeLimit in booking should be used. Date until the booking part needs to be confirmed. Must be provided for a booking part in PREBOOKED stated. For later states, the value is ignored and can be null.

valid_from: String
valid_until: Option<String>

Validity of offer towards passenger

confirmed_on: Option<String>
confirmed_fulfillment_options: Option<Box<FulfillmentOption>>
price: Box<Price>
refund_amount: Option<Box<Price>>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
summary_product_id: Option<String>

Id of the product representing the commercial attributes of this booking part. Although not currently mandatory, this attribute should in all cases be filled in order to allow matching a booking response to the data in the booking request

products: Option<Vec<ProductLegAssociation>>

In offer mode, in almost all cases exactly one product is referenced. Only on some French trips consisting of a TGV and a TER two products need to be used. In fare mode, no product exists as first needs to created from the different fares.

pricing_status: Option<String>

payment status in post-payment scenarios

offer_mode: Option<OfferMode>
booking_part_code: Option<String>

The unique booking code for the part in the provider system.

distributor_booking_ref: Option<String>

reference to the booking in the downstream distributor system

retailer_booking_ref: Option<String>

reference to the booking in the downstream distributor system

passenger_ids: Vec<String>

Id of the passenger

available_fulfillment_options: Option<Vec<FulfillmentOption>>
refundable: RefundType
exchangeable: ExchangeableType
after_sale_conditions: Option<Vec<AfterSaleCondition>>

Fine grained specification of the after sale condition of the booking.

after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reductions: Option<Vec<CardReference>>
indicated_consumption: Option<Box<IndicatedConsumption>>
accounting_ref: Option<Box<AccountingRef>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>


Ancillary

Fields

summary: Option<String>
created_on: String

Validity of offer towards passenger

confirmable_until: Option<String>

confirmationTimeLimit in booking should be used. Date until the booking part needs to be confirmed. Must be provided for a booking part in PREBOOKED stated. For later states, the value is ignored and can be null.

valid_from: String
valid_until: Option<String>

Validity of offer towards passenger

confirmed_on: Option<String>
confirmed_fulfillment_options: Option<Box<FulfillmentOption>>
price: Box<Price>
refund_amount: Option<Box<Price>>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
summary_product_id: Option<String>

Id of the product representing the commercial attributes of this booking part. Although not currently mandatory, this attribute should in all cases be filled in order to allow matching a booking response to the data in the booking request

products: Option<Vec<ProductLegAssociation>>

In offer mode, in almost all cases exactly one product is referenced. Only on some French trips consisting of a TGV and a TER two products need to be used. In fare mode, no product exists as first needs to created from the different fares.

pricing_status: Option<String>

payment status in post-payment scenarios

offer_mode: Option<OfferMode>
booking_part_code: Option<String>

The unique booking code for the part in the provider system.

distributor_booking_ref: Option<String>

reference to the booking in the downstream distributor system

retailer_booking_ref: Option<String>

reference to the booking in the downstream distributor system

passenger_ids: Vec<String>

Id of the passenger

available_fulfillment_options: Option<Vec<FulfillmentOption>>
refundable: RefundType
exchangeable: ExchangeableType
after_sale_conditions: Option<Vec<AfterSaleCondition>>

Fine grained specification of the after sale condition of the booking.

after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reductions: Option<Vec<CardReference>>
indicated_consumption: Option<Box<IndicatedConsumption>>
accounting_ref: Option<Box<AccountingRef>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>


ContinuousServiceBookingPart

Fields

summary: Option<String>
created_on: String

Validity of offer towards passenger

confirmable_until: Option<String>

confirmationTimeLimit in booking should be used. Date until the booking part needs to be confirmed. Must be provided for a booking part in PREBOOKED stated. For later states, the value is ignored and can be null.

valid_from: String
valid_until: Option<String>

Validity of offer towards passenger

confirmed_on: Option<String>
confirmed_fulfillment_options: Option<Box<FulfillmentOption>>
price: Box<Price>
refund_amount: Option<Box<Price>>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
summary_product_id: Option<String>

Id of the product representing the commercial attributes of this booking part. Although not currently mandatory, this attribute should in all cases be filled in order to allow matching a booking response to the data in the booking request

products: Option<Vec<ProductLegAssociation>>

In offer mode, in almost all cases exactly one product is referenced. Only on some French trips consisting of a TGV and a TER two products need to be used. In fare mode, no product exists as first needs to created from the different fares.

pricing_status: Option<String>

payment status in post-payment scenarios

offer_mode: Option<OfferMode>
booking_part_code: Option<String>

The unique booking code for the part in the provider system.

distributor_booking_ref: Option<String>

reference to the booking in the downstream distributor system

retailer_booking_ref: Option<String>

reference to the booking in the downstream distributor system

passenger_ids: Vec<String>

Id of the passenger

available_fulfillment_options: Option<Vec<FulfillmentOption>>
refundable: RefundType
exchangeable: ExchangeableType
after_sale_conditions: Option<Vec<AfterSaleCondition>>

Fine grained specification of the after sale condition of the booking.

after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reductions: Option<Vec<CardReference>>
indicated_consumption: Option<Box<IndicatedConsumption>>
accounting_ref: Option<Box<AccountingRef>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>


ContinuousServiceOfferPart

Fields

summary: Option<String>
created_on: String

Validity of offer towards passenger

confirmable_until: Option<String>

confirmationTimeLimit in booking should be used. Date until the booking part needs to be confirmed. Must be provided for a booking part in PREBOOKED stated. For later states, the value is ignored and can be null.

valid_from: String
valid_until: Option<String>

Validity of offer towards passenger

confirmed_on: Option<String>
confirmed_fulfillment_options: Option<Box<FulfillmentOption>>
price: Box<Price>
refund_amount: Option<Box<Price>>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
summary_product_id: Option<String>

Id of the product representing the commercial attributes of this booking part. Although not currently mandatory, this attribute should in all cases be filled in order to allow matching a booking response to the data in the booking request

products: Option<Vec<ProductLegAssociation>>

In offer mode, in almost all cases exactly one product is referenced. Only on some French trips consisting of a TGV and a TER two products need to be used. In fare mode, no product exists as first needs to created from the different fares.

pricing_status: Option<String>

payment status in post-payment scenarios

offer_mode: Option<OfferMode>
booking_part_code: Option<String>

The unique booking code for the part in the provider system.

distributor_booking_ref: Option<String>

reference to the booking in the downstream distributor system

retailer_booking_ref: Option<String>

reference to the booking in the downstream distributor system

passenger_ids: Vec<String>

Id of the passenger

available_fulfillment_options: Option<Vec<FulfillmentOption>>
refundable: RefundType
exchangeable: ExchangeableType
after_sale_conditions: Option<Vec<AfterSaleCondition>>

Fine grained specification of the after sale condition of the booking.

after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reductions: Option<Vec<CardReference>>
indicated_consumption: Option<Box<IndicatedConsumption>>
accounting_ref: Option<Box<AccountingRef>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>


Reservation

Fields

summary: Option<String>
created_on: String

Validity of offer towards passenger

confirmable_until: Option<String>

confirmationTimeLimit in booking should be used. Date until the booking part needs to be confirmed. Must be provided for a booking part in PREBOOKED stated. For later states, the value is ignored and can be null.

valid_from: String
valid_until: Option<String>

Validity of offer towards passenger

confirmed_on: Option<String>
confirmed_fulfillment_options: Option<Box<FulfillmentOption>>
price: Box<Price>
refund_amount: Option<Box<Price>>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
summary_product_id: Option<String>

Id of the product representing the commercial attributes of this booking part. Although not currently mandatory, this attribute should in all cases be filled in order to allow matching a booking response to the data in the booking request

products: Option<Vec<ProductLegAssociation>>

In offer mode, in almost all cases exactly one product is referenced. Only on some French trips consisting of a TGV and a TER two products need to be used. In fare mode, no product exists as first needs to created from the different fares.

pricing_status: Option<String>

payment status in post-payment scenarios

offer_mode: Option<OfferMode>
booking_part_code: Option<String>

The unique booking code for the part in the provider system.

distributor_booking_ref: Option<String>

reference to the booking in the downstream distributor system

retailer_booking_ref: Option<String>

reference to the booking in the downstream distributor system

passenger_ids: Vec<String>

Id of the passenger

available_fulfillment_options: Option<Vec<FulfillmentOption>>
refundable: RefundType
exchangeable: ExchangeableType
after_sale_conditions: Option<Vec<AfterSaleCondition>>

Fine grained specification of the after sale condition of the booking.

after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reductions: Option<Vec<CardReference>>
indicated_consumption: Option<Box<IndicatedConsumption>>
accounting_ref: Option<Box<AccountingRef>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>