AbstractOfferPart

Enum AbstractOfferPart 

pub enum AbstractOfferPart {
    AdmissionOfferPart {
Show 31 fields id: String, summary: Option<String>, created_on: String, valid_from: String, valid_until: Option<String>, price: Box<Price>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, price_guaranteed_until: Option<String>, offer_mode: OfferMode, is_reusable: Option<bool>, passenger_refs: Vec<String>, numeric_availability: Option<i32>, refundable: RefundType, exchangeable: ExchangeableType, after_sales_conditions: Option<Vec<AfterSaleCondition>>, trip_tags: Option<Vec<String>>, return_tags: Option<Vec<String>>, offer_tag: Option<Box<OfferTag>>, requested_information: Option<String>, summary_product_id: Option<String>, products: Vec<ProductLegAssociation>, available_fulfillment_options: Vec<FulfillmentOption>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reduction_card_types: Option<Vec<ReductionCardType>>, regional_validity_summary: Option<Box<RegionalValiditySummary>>, indicated_consumption: Option<Box<IndicatedConsumption>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>, _links: Option<Vec<Link>>,
}, AncillaryOfferPart {
Show 31 fields id: String, summary: Option<String>, created_on: String, valid_from: String, valid_until: Option<String>, price: Box<Price>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, price_guaranteed_until: Option<String>, offer_mode: OfferMode, is_reusable: Option<bool>, passenger_refs: Vec<String>, numeric_availability: Option<i32>, refundable: RefundType, exchangeable: ExchangeableType, after_sales_conditions: Option<Vec<AfterSaleCondition>>, trip_tags: Option<Vec<String>>, return_tags: Option<Vec<String>>, offer_tag: Option<Box<OfferTag>>, requested_information: Option<String>, summary_product_id: Option<String>, products: Vec<ProductLegAssociation>, available_fulfillment_options: Vec<FulfillmentOption>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reduction_card_types: Option<Vec<ReductionCardType>>, regional_validity_summary: Option<Box<RegionalValiditySummary>>, indicated_consumption: Option<Box<IndicatedConsumption>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>, _links: Option<Vec<Link>>,
}, ReservationOfferPart {
Show 31 fields id: String, summary: Option<String>, created_on: String, valid_from: String, valid_until: Option<String>, price: Box<Price>, trip_coverage: Option<Box<TripCoverage>>, inbound_trip_coverage: Option<Box<TripCoverage>>, price_guaranteed_until: Option<String>, offer_mode: OfferMode, is_reusable: Option<bool>, passenger_refs: Vec<String>, numeric_availability: Option<i32>, refundable: RefundType, exchangeable: ExchangeableType, after_sales_conditions: Option<Vec<AfterSaleCondition>>, trip_tags: Option<Vec<String>>, return_tags: Option<Vec<String>>, offer_tag: Option<Box<OfferTag>>, requested_information: Option<String>, summary_product_id: Option<String>, products: Vec<ProductLegAssociation>, available_fulfillment_options: Vec<FulfillmentOption>, applied_corporate_codes: Option<Vec<CorporateCode>>, applied_passenger_types: Option<Vec<AppliedPassengerType>>, applied_promotion_codes: Option<Vec<PromotionCode>>, applied_reduction_card_types: Option<Vec<ReductionCardType>>, regional_validity_summary: Option<Box<RegionalValiditySummary>>, indicated_consumption: Option<Box<IndicatedConsumption>>, granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>, _links: Option<Vec<Link>>,
}, }
AbstractOfferPart : Generic offer object that contains all common information about an offer.

Variants



AdmissionOfferPart

Fields

summary: Option<String>

A human-readable description of the Offer.

created_on: String
valid_from: String

Time from which on the offer can be used, e.g. travel.

valid_until: Option<String>

Time until the offer can be used, e.g. travel.

price: Box<Price>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
price_guaranteed_until: Option<String>

Indicates until when the price for the given offer is guaranteed.

offer_mode: OfferMode
is_reusable: Option<bool>

Indicates whether the offerId can be used in more than one booking.

passenger_refs: Vec<String>
numeric_availability: Option<i32>

Total amount of items of this type currently available. For reservation offers, this would be the total number of seats available, regardless of their properties.

refundable: RefundType
exchangeable: ExchangeableType
after_sales_conditions: Option<Vec<AfterSaleCondition>>
trip_tags: Option<Vec<String>>

List of tags (and their type) that allow identifying sets of compatible offers when trying to combine multiple offers covering one single trip. At least one (not all) tripTags must be in common to allow combination If no tag is provided, there is no trip constraint on this specific offer.

return_tags: Option<Vec<String>>

List of tags (and their type) that allow identifying sets of compatible offers when booking a return trip involving return-specific fares. All returnTags must be present in the counterpart offer to allow combination If no tag is provided, there is no return constraint on this specific offer.

offer_tag: Option<Box<OfferTag>>
requested_information: Option<String>

Boolean-expression indicating the data that must be set in the data model in order to proceed to next step of the process. The syntax and semantics of the expression is described in detail in the OSDM documentation.

summary_product_id: Option<String>

Id of the product representing the commercial attributes of this offer part. Although not currently mandatory, this attribute should in all cases be facilitate product based processing at the client

available_fulfillment_options: Vec<FulfillmentOption>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reduction_card_types: Option<Vec<ReductionCardType>>
regional_validity_summary: Option<Box<RegionalValiditySummary>>
indicated_consumption: Option<Box<IndicatedConsumption>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>
_links: Option<Vec<Link>>

Java Property Name: ‘links’



AncillaryOfferPart

Fields

summary: Option<String>

A human-readable description of the Offer.

created_on: String
valid_from: String

Time from which on the offer can be used, e.g. travel.

valid_until: Option<String>

Time until the offer can be used, e.g. travel.

price: Box<Price>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
price_guaranteed_until: Option<String>

Indicates until when the price for the given offer is guaranteed.

offer_mode: OfferMode
is_reusable: Option<bool>

Indicates whether the offerId can be used in more than one booking.

passenger_refs: Vec<String>
numeric_availability: Option<i32>

Total amount of items of this type currently available. For reservation offers, this would be the total number of seats available, regardless of their properties.

refundable: RefundType
exchangeable: ExchangeableType
after_sales_conditions: Option<Vec<AfterSaleCondition>>
trip_tags: Option<Vec<String>>

List of tags (and their type) that allow identifying sets of compatible offers when trying to combine multiple offers covering one single trip. At least one (not all) tripTags must be in common to allow combination If no tag is provided, there is no trip constraint on this specific offer.

return_tags: Option<Vec<String>>

List of tags (and their type) that allow identifying sets of compatible offers when booking a return trip involving return-specific fares. All returnTags must be present in the counterpart offer to allow combination If no tag is provided, there is no return constraint on this specific offer.

offer_tag: Option<Box<OfferTag>>
requested_information: Option<String>

Boolean-expression indicating the data that must be set in the data model in order to proceed to next step of the process. The syntax and semantics of the expression is described in detail in the OSDM documentation.

summary_product_id: Option<String>

Id of the product representing the commercial attributes of this offer part. Although not currently mandatory, this attribute should in all cases be facilitate product based processing at the client

available_fulfillment_options: Vec<FulfillmentOption>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reduction_card_types: Option<Vec<ReductionCardType>>
regional_validity_summary: Option<Box<RegionalValiditySummary>>
indicated_consumption: Option<Box<IndicatedConsumption>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>
_links: Option<Vec<Link>>

Java Property Name: ‘links’



ReservationOfferPart

Fields

summary: Option<String>

A human-readable description of the Offer.

created_on: String
valid_from: String

Time from which on the offer can be used, e.g. travel.

valid_until: Option<String>

Time until the offer can be used, e.g. travel.

price: Box<Price>
trip_coverage: Option<Box<TripCoverage>>
inbound_trip_coverage: Option<Box<TripCoverage>>
price_guaranteed_until: Option<String>

Indicates until when the price for the given offer is guaranteed.

offer_mode: OfferMode
is_reusable: Option<bool>

Indicates whether the offerId can be used in more than one booking.

passenger_refs: Vec<String>
numeric_availability: Option<i32>

Total amount of items of this type currently available. For reservation offers, this would be the total number of seats available, regardless of their properties.

refundable: RefundType
exchangeable: ExchangeableType
after_sales_conditions: Option<Vec<AfterSaleCondition>>
trip_tags: Option<Vec<String>>

List of tags (and their type) that allow identifying sets of compatible offers when trying to combine multiple offers covering one single trip. At least one (not all) tripTags must be in common to allow combination If no tag is provided, there is no trip constraint on this specific offer.

return_tags: Option<Vec<String>>

List of tags (and their type) that allow identifying sets of compatible offers when booking a return trip involving return-specific fares. All returnTags must be present in the counterpart offer to allow combination If no tag is provided, there is no return constraint on this specific offer.

offer_tag: Option<Box<OfferTag>>
requested_information: Option<String>

Boolean-expression indicating the data that must be set in the data model in order to proceed to next step of the process. The syntax and semantics of the expression is described in detail in the OSDM documentation.

summary_product_id: Option<String>

Id of the product representing the commercial attributes of this offer part. Although not currently mandatory, this attribute should in all cases be facilitate product based processing at the client

available_fulfillment_options: Vec<FulfillmentOption>
applied_corporate_codes: Option<Vec<CorporateCode>>
applied_passenger_types: Option<Vec<AppliedPassengerType>>
applied_promotion_codes: Option<Vec<PromotionCode>>
applied_reduction_card_types: Option<Vec<ReductionCardType>>
regional_validity_summary: Option<Box<RegionalValiditySummary>>
indicated_consumption: Option<Box<IndicatedConsumption>>
granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>
_links: Option<Vec<Link>>

Java Property Name: ‘links’