pub struct AccountingRef {
pub accounting_company: String,
pub accounting_ids: Option<Vec<String>>,
}Expand description
AccountingRef : reference to accounting data in case the accounting is not provided by the API provider
Fields
accounting_company: StringIdentifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
accounting_ids: Option<Vec<String>>ids of accounting data used to link the booking part with accounting data in the billing send by the accounting company
Implementations
Sourceimpl AccountingRef
impl AccountingRef
Sourcepub fn new(accounting_company: String) -> AccountingRef
pub fn new(accounting_company: String) -> AccountingRef
reference to accounting data in case the accounting is not provided by the API provider