pub struct Address {Show 15 fields
pub object_type: String,
pub id: String,
pub alternative_ids: Option<Option<Vec<String>>>,
pub geo_position: Option<Box<GeoPosition>>,
pub ref: Option<Box<PlaceRef>>,
pub _links: Option<Vec<Link>>,
pub name: Option<Option<String>>,
pub code: Option<Option<String>>,
pub country_name: Option<Option<String>>,
pub country_code: Option<String>,
pub post_code: Option<Option<String>>,
pub city: Option<Option<String>>,
pub topographic_place_name: Option<Option<String>>,
pub street: Option<Option<String>>,
pub house_number: Option<Option<String>>,
}Expand description
Address : A descriptive data associated with a place that can be used to describe the unique geographical context of a place for the purposes of identifying it. may be refined as either a road address, a postal address or both. Provided by OJP.
Fields
object_type: StringAttribute is used as discriminator for inheritance between data types.
id: Stringid defining the place. The code is provided as URN, relative URNs are allowed with base path urn:uic:stn ‘0850000’
alternative_ids: Option<Option<Vec<String>>>For a place with ids in different reference systems, the alternative ids can be returned. The reference system is encoded in the string. E.g.: ‘urn:uic:std:80000’, ‘x_swe:stn:10000’, ‘ch:1:sloid:343434’
geo_position: Option<Box<GeoPosition>>ref: Option<Box<PlaceRef>>_links: Option<Vec<Link>>Java Property Name: ‘links’
name: Option<Option<String>>Name or description of address for use in passenger information.
code: Option<Option<String>>id of the address
country_name: Option<Option<String>>Country of the address.
country_code: Option<String>ISO 3166-1 alpha-2 2 character country code
post_code: Option<Option<String>>Postal code of the address.
city: Option<Option<String>>City name
topographic_place_name: Option<Option<String>>TopographicPlace name of the address. If set it should at least contain the city name.
street: Option<Option<String>>Street name of the address. Can also contain the house number.
house_number: Option<Option<String>>House number of the address. House number can either be in this separate field, or can be contained in the street field.