AncillaryOfferPart

Struct AncillaryOfferPart 

pub struct AncillaryOfferPart {
Show 36 fields pub object_type: String, pub id: String, pub summary: Option<Option<String>>, pub created_on: String, pub valid_from: String, pub valid_until: Option<Option<String>>, pub price: Box<Price>, pub trip_coverage: Option<Box<TripCoverage>>, pub inbound_trip_coverage: Option<Box<TripCoverage>>, pub price_guaranteed_until: Option<Option<String>>, pub offer_mode: OfferMode, pub is_reusable: Option<Option<bool>>, pub passenger_refs: Vec<String>, pub numeric_availability: Option<Option<i32>>, pub refundable: RefundType, pub exchangeable: ExchangeableType, pub after_sales_conditions: Option<Vec<AfterSaleCondition>>, pub trip_tags: Option<Option<Vec<String>>>, pub return_tags: Option<Option<Vec<String>>>, pub offer_tag: Option<Box<OfferTag>>, pub requested_information: Option<Option<String>>, pub summary_product_id: Option<String>, pub products: Vec<ProductLegAssociation>, pub available_fulfillment_options: Vec<FulfillmentOption>, pub applied_corporate_codes: Option<Vec<CorporateCode>>, pub applied_passenger_types: Option<Vec<AppliedPassengerType>>, pub applied_promotion_codes: Option<Vec<PromotionCode>>, pub applied_reduction_card_types: Option<Vec<ReductionCardType>>, pub regional_validity_summary: Option<Box<RegionalValiditySummary>>, pub indicated_consumption: Option<Box<IndicatedConsumption>>, pub granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>, pub _links: Option<Vec<Link>>, pub fee_refs: Option<Vec<OfferPartReference>>, pub category: Option<Option<String>>, pub type: String, pub reservations: Option<Vec<ReservationRelation>>,
}

Fields

object_type: String

Attribute is used as discriminator for inheritance between data types.

id: Stringsummary: Option<Option<String>>

A human-readable description of the Offer.

created_on: Stringvalid_from: String

Time from which on the offer can be used, e.g. travel.

valid_until: Option<Option<String>>

Time until the offer can be used, e.g. travel.

price: Box<Price>trip_coverage: Option<Box<TripCoverage>>inbound_trip_coverage: Option<Box<TripCoverage>>price_guaranteed_until: Option<Option<String>>

Indicates until when the price for the given offer is guaranteed.

offer_mode: OfferModeis_reusable: Option<Option<bool>>

Indicates whether the offerId can be used in more than one booking.

passenger_refs: Vec<String>numeric_availability: Option<Option<i32>>

Total amount of items of this type currently available. For reservation offers, this would be the total number of seats available, regardless of their properties.

refundable: RefundTypeexchangeable: ExchangeableTypeafter_sales_conditions: Option<Vec<AfterSaleCondition>>trip_tags: Option<Option<Vec<String>>>

List of tags (and their type) that allow identifying sets of compatible offers when trying to combine multiple offers covering one single trip. At least one (not all) tripTags must be in common to allow combination If no tag is provided, there is no trip constraint on this specific offer.

return_tags: Option<Option<Vec<String>>>

List of tags (and their type) that allow identifying sets of compatible offers when booking a return trip involving return-specific fares. All returnTags must be present in the counterpart offer to allow combination If no tag is provided, there is no return constraint on this specific offer.

offer_tag: Option<Box<OfferTag>>requested_information: Option<Option<String>>

Boolean-expression indicating the data that must be set in the data model in order to proceed to next step of the process. The syntax and semantics of the expression is described in detail in the OSDM documentation.

summary_product_id: Option<String>

Id of the product representing the commercial attributes of this offer part. Although not currently mandatory, this attribute should in all cases be facilitate product based processing at the client

products: Vec<ProductLegAssociation>available_fulfillment_options: Vec<FulfillmentOption>applied_corporate_codes: Option<Vec<CorporateCode>>applied_passenger_types: Option<Vec<AppliedPassengerType>>applied_promotion_codes: Option<Vec<PromotionCode>>applied_reduction_card_types: Option<Vec<ReductionCardType>>regional_validity_summary: Option<Box<RegionalValiditySummary>>indicated_consumption: Option<Box<IndicatedConsumption>>granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>_links: Option<Vec<Link>>

Java Property Name: ‘links’

fee_refs: Option<Vec<OfferPartReference>>category: Option<Option<String>>

Categorization of the ancillary such as ‘Meal’ or ‘Gift’.

type: String

Values from the Ancillary Category Code List Listed values here are examples.

reservations: Option<Vec<ReservationRelation>>

Implementations

Source

impl AncillaryOfferPart

pub fn new( object_type: String, id: String, created_on: String, valid_from: String, price: Price, offer_mode: OfferMode, passenger_refs: Vec<String>, refundable: RefundType, exchangeable: ExchangeableType, products: Vec<ProductLegAssociation>, available_fulfillment_options: Vec<FulfillmentOption>, type: String, ) -> AncillaryOfferPart