pub struct AnonymousPassengerSpecification {
pub external_ref: String,
pub date_of_birth: Option<Option<String>>,
pub age: Option<Option<i32>>,
pub type: String,
pub prm_needs: Option<Vec<String>>,
pub cards: Option<Vec<CardReference>>,
pub gender: Option<Option<Gender>>,
pub residency: Option<String>,
pub transportable: Option<Box<TransportableSpecification>>,
}Expand description
AnonymousPassengerSpecification : Minimal specification of a passenger to request offers without any GDPR relevant attributes such as name or address. Either the date of birth or the age at the time of travel needs to be set. We recommend to use date of birth as it is more stable than age.
Fields
external_ref: StringA stable reference to a passenger from other elements, or from caller system. When received in input of a request, it must be echoed back in the response.
date_of_birth: Option<Option<String>>Date of birth of the passenger. Only needed for passengers of type persons, family child, PRM and wheelchair.
age: Option<Option<i32>>type: StringPassenger type according to UIC passenger, i.e. passenger type list. Values from the Passenger Type Code List Listed values here are examples. Proposed default PERSON
prm_needs: Option<Vec<String>>cards: Option<Vec<CardReference>>gender: Option<Option<Gender>>residency: Option<String>ISO 3166-1 alpha-2 2 character country code
transportable: Option<Box<TransportableSpecification>>Implementations
Sourceimpl AnonymousPassengerSpecification
impl AnonymousPassengerSpecification
Sourcepub fn new(
external_ref: String,
type: String,
) -> AnonymousPassengerSpecification
pub fn new( external_ref: String, type: String, ) -> AnonymousPassengerSpecification
Minimal specification of a passenger to request offers without any GDPR relevant attributes such as name or address. Either the date of birth or the age at the time of travel needs to be set. We recommend to use date of birth as it is more stable than age.