ApiNextVersion

Struct ApiNextVersion 

pub struct ApiNextVersion {
    pub version: Option<String>,
    pub available_at: Option<String>,
    pub available_from: Option<Option<String>>,
}
ApiNextVersion : Next version of the API. The next version is used to indicate the next version of the API that is being used. The version is in semantic versioning format, e.g. "4.0.0" and it is a version released at osdm.io.

Fields

version: Option<String>

Version of the next API.

available_at: Option<String>available_from: Option<Option<String>>

Date from which the next version is available.

Implementations

Source

impl ApiNextVersion

pub fn new() -> ApiNextVersion

Next version of the API. The next version is used to indicate the next version of the API that is being used. The version is in semantic versioning format, e.g. "4.0.0" and it is a version released at osdm.io.