pub struct ApiVersion {
pub version: String,
pub sunset: Option<Option<String>>,
pub next_version: Option<Box<ApiNextVersion>>,
}Expand description
ApiVersion : Version of the API. The version is used to indicate the version of the API that is being used. The version is in semantic versioning format, e.g. "3.0.0" and it is a version released at osdm.io.
Fields
version: StringVersion of the API
sunset: Option<Option<String>>Date after which the API version will no longer be available.
next_version: Option<Box<ApiNextVersion>>Implementations
Sourceimpl ApiVersion
impl ApiVersion
Sourcepub fn new(version: String) -> ApiVersion
pub fn new(version: String) -> ApiVersion
Version of the API. The version is used to indicate the version of the API that is being used. The version is in semantic versioning format, e.g. "3.0.0" and it is a version released at osdm.io.