pub struct AvailabilityScope {
pub single_selection_maps_required: Option<bool>,
pub part_references: Vec<PartReference>,
}Expand description
AvailabilityScope : fare or offerParts which should be covered by the available seats
Fields
single_selection_maps_required: Option<bool>if true the place map must include places for a single reservation or fare only
part_references: Vec<PartReference>Implementations
Sourceimpl AvailabilityScope
impl AvailabilityScope
Sourcepub fn new(part_references: Vec<PartReference>) -> AvailabilityScope
pub fn new(part_references: Vec<PartReference>) -> AvailabilityScope
fare or offerParts which should be covered by the available seats