pub struct AvailablePlace {
pub accommodation_type: String,
pub accommodation_sub_type: String,
pub place_properties: Option<Option<Vec<String>>>,
pub numeric_availability: Option<Option<i32>>,
pub trip_leg_coverage: Box<TripLegCoverage>,
}Expand description
AvailablePlace : Describes the details of the available places.
Fields
accommodation_type: StringAccommodation type definition out of the Accommodation Type Code List Listed values here are examples.
accommodation_sub_type: StringAccommodation sub type definition out of the Accommodation Sub Type Code List Listed values here are examples.
place_properties: Option<Option<Vec<String>>>Selectable place properties for the offer. For AccommodationSubType=ANY_SEAT all available and bookable properties need to be returned to give a sales tool a list of possible selections.
numeric_availability: Option<Option<i32>>For the AccommodationSubType=ANY_SEAT the total amount of places for the combination of AccommodationType and AccommodationSubType needs to returned.
trip_leg_coverage: Box<TripLegCoverage>Implementations
Sourceimpl AvailablePlace
impl AvailablePlace
Sourcepub fn new(
accommodation_type: String,
accommodation_sub_type: String,
trip_leg_coverage: TripLegCoverage,
) -> AvailablePlace
pub fn new( accommodation_type: String, accommodation_sub_type: String, trip_leg_coverage: TripLegCoverage, ) -> AvailablePlace
Describes the details of the available places.