Module back_office_status

Module back_office_status 

Enums

BackOfficeStatus
BackOfficeStatus : Status of the request sent to the back office. Valid Values: - ‘INITIATED’ - ‘EVALUATING’ - ‘DECIDED’ - ‘SETTLED’ - ‘INFORMATION_MISSING’ - ‘REQUEST_UPDATED’: Additional information, i.e. documents have been provided which should trigger reevaluation. Status of the request sent to the back office. Valid Values: - ‘INITIATED’ - ‘EVALUATING’ - ‘DECIDED’ - ‘SETTLED’ - ‘INFORMATION_MISSING’ - ‘REQUEST_UPDATED’: Additional information, i.e. documents have been provided which should trigger reevaluation.