pub struct Board {
pub stop_place_ref: Box<StopPlaceRef>,
pub stop_place_name: String,
pub planned_stop_point_name: Option<Option<String>>,
pub estimated_stop_point_name: Option<Option<String>>,
pub service_departure: Box<ServiceTime>,
pub status: Option<Box<StopCallStatus>>,
}Expand description
Board : Describes the the situation at a stop or station at which the passenger boards a Leg of a trip including time-related information. Provided by OJP.
Fields
stop_place_ref: Box<StopPlaceRef>stop_place_name: Stringplanned_stop_point_name: Option<Option<String>>Name of the bay/quay/terminal where to board/alight from the vehicle. According to planned timetable.
estimated_stop_point_name: Option<Option<String>>Name of the bay/quay/terminal where to board the vehicle. As to the latest realtime status.
service_departure: Box<ServiceTime>status: Option<Box<StopCallStatus>>Implementations
Sourceimpl Board
impl Board
Sourcepub fn new(
stop_place_ref: StopPlaceRef,
stop_place_name: String,
service_departure: ServiceTime,
) -> Board
pub fn new( stop_place_ref: StopPlaceRef, stop_place_name: String, service_departure: ServiceTime, ) -> Board
Describes the the situation at a stop or station at which the passenger boards a Leg of a trip including time-related information. Provided by OJP.