pub struct BookedOffer {Show 13 fields
pub offer_id: String,
pub external_ref: Option<String>,
pub summary: Option<Option<String>>,
pub admissions: Option<Vec<Admission>>,
pub reservations: Option<Vec<Reservation>>,
pub ancillaries: Option<Vec<Ancillary>>,
pub continuous_services: Option<Vec<ContinuousServiceBookingPart>>,
pub fees: Option<Vec<Fee>>,
pub fares: Option<Vec<Fare>>,
pub trip_coverage: Option<Box<TripCoverage>>,
pub inbound_trip_coverage: Option<Box<TripCoverage>>,
pub applied_through_ticket_tags: Option<Vec<String>>,
pub products: Option<Vec<Product>>,
}Expand description
BookedOffer : The attribute ‘offerSummary’ is meaningful at trip-offer-collection response time only. The offerSummary must be provided for product based offers. It is not needed for fares.
Fields
offer_id: StringNote that the offerId returned does not necessarily match the offerId given in the Booking Request.
external_ref: Option<String>A stable reference to the id of the booked offer in the caller’s system. When received in input of a request, it must be persisted and echoed back in the response.
summary: Option<Option<String>>A human-readable description of the booked offer.
admissions: Option<Vec<Admission>>reservations: Option<Vec<Reservation>>ancillaries: Option<Vec<Ancillary>>continuous_services: Option<Vec<ContinuousServiceBookingPart>>fees: Option<Vec<Fee>>fares: Option<Vec<Fare>>trip_coverage: Option<Box<TripCoverage>>inbound_trip_coverage: Option<Box<TripCoverage>>products: Option<Vec<Product>>Implementations
Sourceimpl BookedOffer
impl BookedOffer
Sourcepub fn new(offer_id: String) -> BookedOffer
pub fn new(offer_id: String) -> BookedOffer
The attribute ‘offerSummary’ is meaningful at trip-offer-collection response time only. The offerSummary must be provided for product based offers. It is not needed for fares.