Module booking_cleanup_request

Module booking_cleanup_request 

Structs

BookingCleanupRequest
BookingCleanupRequest : Request to cleanup a complete booking. Unconfirmed items will be deleted, any confirmed items will be refunded. There is no confirmation required. Attention point: refundDate and overruleCode are deprecated request attributes and will be ignored