BookingCleanupRequest

Struct BookingCleanupRequest 

pub struct BookingCleanupRequest {
    pub overrule_code: Option<String>,
    pub refund_date: Option<Option<String>>,
}
BookingCleanupRequest : Request to cleanup a complete booking. Unconfirmed items will be deleted, any confirmed items will be refunded. There is no confirmation required. Attention point: refundDate and overruleCode are deprecated request attributes and will be ignored

Fields

overrule_code: Option<String>

Reason for and type of an after sale, code list in IRS 90918-10. The PRM_SUPPORT_UNAVAILABLE overrule code shall only be used by the UIC PRM ABT tool. Values from the Overrule Codes Code List Listed values here are examples. - ‘CONNECTION_BROKEN’ - ‘DEATH’ - ‘EQUIPMENT_FAILURE’ - ‘PAYMENT_FAILURE’ - ‘PRM_SUPPORT_UNAVAILABLE’ - ‘SALES_STAFF_ERROR’ - ‘STOP_NOT_SERVED’ - ‘STRIKE’ - ‘TECHNICAL_FAILURE’ - ‘TICKET_NOT_USED’ - ‘INABILITY_TO_TRAVEL’: Inability to travel due to accident or sickness. - ‘EXTERNAL_COMPENSATION’: Offer has been compensated outside of the provider system in another way. - ‘DISRUPTION’: Inability to operate due to disruption. - ‘JOURNEY_OBSOLETE’: Due to external factors it’s senseless to start the trip, thus the travel is obsolete. - ‘CERTIFIED_MEDICAL_CONDITION’: A medical certificate certifies that the passenger is unable to travel. - ‘DELAY_COMPENSATION’: Allows to override conditions in context of passenger rights regulation (PRR).

refund_date: Option<Option<String>>

–Deprecated – Indicates for passes the date taken as reference to compute possible partial refund. It is also the date taken as reference to invalidate the pass partially refunded.

Implementations

Source

impl BookingCleanupRequest

pub fn new() -> BookingCleanupRequest

Request to cleanup a complete booking. Unconfirmed items will be deleted, any confirmed items will be refunded. There is no confirmation required. Attention point: refundDate and overruleCode are deprecated request attributes and will be ignored