pub enum BookingResponseContent {
Show 13 variants
All,
Booking,
BookingPassengers,
BookingPurchaser,
BookingTrips,
BookingBookedoffers,
BookingFulfillments,
BookingDocuments,
BookingRefundoffers,
BookingReleaseoffers,
BookingCancelfulfillmentsoffer,
BookingExchangeoperations,
None,
}Expand description
BookingResponseContent : Influences whether referenced resources are returned in full or as references only. Influences whether referenced resources are returned in full or as references only.
Variants
All
Booking
BookingPassengers
BookingPurchaser
BookingTrips
BookingBookedoffers
BookingFulfillments
BookingDocuments
BookingRefundoffers
BookingReleaseoffers
BookingCancelfulfillmentsoffer
BookingExchangeoperations
None