pub struct Calendar {
pub from: Option<Option<String>>,
pub until: Option<Option<String>>,
pub dates: Option<Option<Vec<String>>>,
pub utc_offset: Option<Option<i32>>,
}Fields
from: Option<Option<String>>until: Option<Option<String>>dates: Option<Option<Vec<String>>>dates included in the calendar. In case no dates are provided the range is assumed to be valid. The date-time format is used to provide an offset to UTC per date.
utc_offset: Option<Option<i32>>offset to UTC in minutes (number of minutes to be added to get UTC dates)
Implementations