Car

Struct Car 

pub struct Car {
Show 14 fields pub weight: i32, pub length: i32, pub width: i32, pub height: i32, pub brand: String, pub model: String, pub special_type: Option<Option<String>>, pub roof_width: i32, pub textile_roof: Option<bool>, pub rack: Option<Box<CarRack>>, pub attached_items: Option<Vec<String>>, pub contact_name: Option<String>, pub contact_detail: Option<Box<ContactDetail>>, pub license_plate: String,
}

Fields

weight: i32

weight in kg

length: i32

size in cm

width: i32

size in cm

height: i32

size in cm

brand: String

Free text description of the brand (e.g. BMW)

model: String

Free text description of the model (e.g. X5)

special_type: Option<Option<String>>roof_width: i32textile_roof: Option<bool>

indication that the car has a textile rook only

rack: Option<Box<CarRack>>attached_items: Option<Vec<String>>

Indication of items attached to the car

contact_name: Option<String>

Name of a contact person or company in case the car transport is booked stand alone.

contact_detail: Option<Box<ContactDetail>>license_plate: String

The license plate is a personal data item and must not be provided in an offer request. It must be patched into the offer after the customer accepted the offer for booking.

Implementations

Source

impl Car

pub fn new( weight: i32, length: i32, width: i32, height: i32, brand: String, model: String, roof_width: i32, license_plate: String, ) -> Car