pub struct CardReference {
pub code: Option<Option<String>>,
pub number: Option<Option<String>>,
pub issuer: Option<String>,
pub type: TravelAccountType,
}Expand description
CardReference : Number and issuer are needed to identify a travel account, the code identifies a reduction card.
Fields
code: Option<Option<String>>Code of the card type according to issuer. E.g. BahnCard50. Predefined values from the Reduction Card Code List
number: Option<Option<String>>Number identifying the travel account, need issuer to be unique.
issuer: Option<String>Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
type: TravelAccountTypeImplementations
Sourceimpl CardReference
impl CardReference
Sourcepub fn new(type: TravelAccountType) -> CardReference
pub fn new(type: TravelAccountType) -> CardReference
Number and issuer are needed to identify a travel account, the code identifies a reduction card.