pub struct CoachLayout {
pub id: String,
pub summary: Option<Option<String>>,
pub places: Option<Vec<CoachLayoutPlace>>,
pub signs: Option<Vec<CoachLayoutSign>>,
pub internals: Option<Vec<CoachLayoutInternal>>,
pub directed_internals: Option<Vec<CoachLayoutDirectedInternal>>,
pub compartment_numbers: Option<Vec<CoachLayoutCompartmentNumber>>,
pub grid_size: Box<CoachLayoutGridSize>,
pub _links: Option<Vec<Link>>,
}Expand description
CoachLayout : coach layout providing data to draw a coach layout. The items of a coach are located via coordinates with (0,0) in the upper left corner. All coordinates are given without sign.
Fields
id: Stringid of this coachLayout on this server
summary: Option<Option<String>>A human-readable description of the coach layout.
places: Option<Vec<CoachLayoutPlace>>list of places included in the layout
signs: Option<Vec<CoachLayoutSign>>internals: Option<Vec<CoachLayoutInternal>>directed_internals: Option<Vec<CoachLayoutDirectedInternal>>compartment_numbers: Option<Vec<CoachLayoutCompartmentNumber>>grid_size: Box<CoachLayoutGridSize>_links: Option<Vec<Link>>Java Property Name: ‘links’
Implementations
Sourceimpl CoachLayout
impl CoachLayout
Sourcepub fn new(id: String, grid_size: CoachLayoutGridSize) -> CoachLayout
pub fn new(id: String, grid_size: CoachLayoutGridSize) -> CoachLayout
coach layout providing data to draw a coach layout. The items of a coach are located via coordinates with (0,0) in the upper left corner. All coordinates are given without sign.