pub struct CoachLayoutPlace {
pub icon: String,
pub number: String,
pub direction: Option<DirectionType>,
pub remark_id: Option<String>,
pub coords: Box<LayoutCoordinates>,
}Fields
icon: StringValues from the Graphics Items Code List
number: Stringplace number as displayed physically on the place
direction: Option<DirectionType>remark_id: Option<String>Remark concerning the place (e.g. to be used in a tool tip). Code list according to UIC90918-1 Known Values: - MIGHT_HAVE_TABLE: place might have a table - MIGHT_NOT_HAVE_TABLE: table at the place might be missing - MIGHT_HAVE_DIFFERENT_DIRECTION: place might have a different direction - MIGHT_HAVE_TABLE_AND_DIFFERENT_DIRECTION: place might have a table and a different direction - MIGHT_NOT_HAVE_TABLE_AND_MIGHT_HAVE_DIFFERENT_DIRECTION: table at the place might be missing and place might have a different direction - MIGHT_BE_IN_COMPARTMENT: place might be in compartment - MIGHT_BE_IN_OPEN_SPACE: place might be in open space
coords: Box<LayoutCoordinates>Implementations
Sourceimpl CoachLayoutPlace
impl CoachLayoutPlace
pub fn new( icon: String, number: String, coords: LayoutCoordinates, ) -> CoachLayoutPlace