Module combination_tag

Module combination_tag 

Structs

CombinationTag
CombinationTag : Tag to indicate that some products from a provider can be sold only when in conjunction with product(s) from another provider using the same tag. At least one, not all, combinationTags must be in common to allow combination. No combinationTags indicate that there are no combination constraints on the product.