pub struct ComplaintPatchRequest {
pub reason: Option<String>,
pub compensation_amount: Option<Box<Price>>,
pub claim_manager: Option<Box<PersonDetail>>,
pub affected_passengers: Option<Vec<Passenger>>,
pub supporting_documents: Option<Vec<SupportingDocument>>,
pub bank_account: Option<Box<BankAccountReference>>,
}Expand description
ComplaintPatchRequest : Changes to a claim already made. This covers upload of additional supporting documents, changes to the passenger and claim manager data. The patch of the compensation amount requires an agreement between the involved parties and is used in case the legal time line for deciding the claim is passed.
Fields
reason: Option<String>Known Values: - ‘BANK_ACCOUNT’ - ‘SETTLED_TIME_LIMIT_EXCEEDED’: A distributor settled the claim as the fare provided did not reply in due time. The compensation amount debited is provided. - ‘PASSENGER_CHANGE’
compensation_amount: Option<Box<Price>>claim_manager: Option<Box<PersonDetail>>affected_passengers: Option<Vec<Passenger>>supporting_documents: Option<Vec<SupportingDocument>>bank_account: Option<Box<BankAccountReference>>Implementations
Sourceimpl ComplaintPatchRequest
impl ComplaintPatchRequest
Sourcepub fn new() -> ComplaintPatchRequest
pub fn new() -> ComplaintPatchRequest
Changes to a claim already made. This covers upload of additional supporting documents, changes to the passenger and claim manager data. The patch of the compensation amount requires an agreement between the involved parties and is used in case the legal time line for deciding the claim is passed.