pub struct Condition {
pub type: String,
pub description: String,
pub short_description: Option<Option<String>>,
}Expand description
Condition : Describes sales, usage and after sales conditions applicable to the product. See after sales conditions for individual after sales amounts. The language of the text is controlled by the accept-language header, i.e. supporting English is a must.
Fields
type: Stringdescription: Stringhuman readable documentation of the text.
short_description: Option<Option<String>>short description of the condition no longer than 64 characters
Implementations
Sourceimpl Condition
impl Condition
Sourcepub fn new(type: String, description: String) -> Condition
pub fn new(type: String, description: String) -> Condition
Describes sales, usage and after sales conditions applicable to the product. See after sales conditions for individual after sales amounts. The language of the text is controlled by the accept-language header, i.e. supporting English is a must.