pub struct ContinuousLeg {
pub start: Box<Place>,
pub end: Box<Place>,
pub service: Box<ContinuousService>,
pub time_window_start: Option<Option<String>>,
pub time_window_end: Option<Option<String>>,
pub duration: Option<Option<String>>,
pub situation_full_refs: Option<Vec<String>>,
pub co2_emission: Option<Box<Quantity>>,
}Expand description
ContinuousLeg : A leg of a journey that is not bound to a timetable. Provided by OJP.
Fields
start: Box<Place>end: Box<Place>service: Box<ContinuousService>time_window_start: Option<Option<String>>Time at which window begins.
time_window_end: Option<Option<String>>Time at which window ends.
duration: Option<Option<String>>Duration of this leg according to user preferences like walk speed.
situation_full_refs: Option<Vec<String>>co2_emission: Option<Box<Quantity>>Implementations
Sourceimpl ContinuousLeg
impl ContinuousLeg
Sourcepub fn new(
start: Place,
end: Place,
service: ContinuousService,
) -> ContinuousLeg
pub fn new( start: Place, end: Place, service: ContinuousService, ) -> ContinuousLeg
A leg of a journey that is not bound to a timetable. Provided by OJP.