pub struct ContinuousService {
pub continuous_mode: Option<String>,
pub individual_mode: Option<String>,
pub operating_day_ref: Option<String>,
pub journey_ref: Option<String>,
pub mode: String,
pub published_service_name: String,
pub origin_text: String,
pub destination_text: String,
}Expand description
ContinuousService : A vehicle movement on a continuous, non-timetabled service. Service of this leg. May be ‘walk’ in most cases, but also cycling or taxi etc. Provided by OJP.
Fields
continuous_mode: Option<String>Types of modes that run at any time without a timetable. Provided by OJP.
individual_mode: Option<String>Modes which an individual powers themselves (such as walk, cycle). Provided by OJP.
operating_day_ref: Option<String>Reference to an operating day. Provided by OJP.
journey_ref: Option<String>Reference to a journey. Provided by OJP.
mode: Stringpublished_service_name: Stringorigin_text: Stringdestination_text: StringImplementations
Sourceimpl ContinuousService
impl ContinuousService
Sourcepub fn new(
operating_day_ref: Option<String>,
journey_ref: Option<String>,
mode: String,
published_service_name: String,
origin_text: String,
destination_text: String,
) -> ContinuousService
pub fn new( operating_day_ref: Option<String>, journey_ref: Option<String>, mode: String, published_service_name: String, origin_text: String, destination_text: String, ) -> ContinuousService
A vehicle movement on a continuous, non-timetabled service. Service of this leg. May be ‘walk’ in most cases, but also cycling or taxi etc. Provided by OJP.