pub struct ContinuousServicePickUpPlace {
pub id: Option<String>,
pub description: String,
pub name: Option<String>,
pub access_description: Option<String>,
pub geo_position: Box<GeoPosition>,
pub available_vehicles: Vec<ContinuousServiceVehicleAvailability>,
pub pre_allocation_time_limit: Option<String>,
pub process_indication: Option<Vec<String>>,
pub estimated_vehicle_arrival_at_pick_up: Option<String>,
pub estimated_user_arrival_at_pick_up: Option<String>,
}Expand description
ContinuousServicePickUpPlace : Pick-up places for on-demand vehicles like taxis, bicycles or scooters
Fields
id: Option<String>id of the pick-up place
description: Stringdescription of the pick-up place
name: Option<String>name of the pick-up place
access_description: Option<String>description on how to access the on-demand vehicle
geo_position: Box<GeoPosition>available_vehicles: Vec<ContinuousServiceVehicleAvailability>pre_allocation_time_limit: Option<String>Duration for which the vehicle can be blocked until the usage starts.
process_indication: Option<Vec<String>>Machine readable indications on how the on-demand process should be handled.
estimated_vehicle_arrival_at_pick_up: Option<String>Time until when the vehicle is expected to arrive at the pick-up place (taxi,..)
estimated_user_arrival_at_pick_up: Option<String>Time until when the user of the service is expected to arrive at the pick-up place.
Implementations
Sourceimpl ContinuousServicePickUpPlace
impl ContinuousServicePickUpPlace
Sourcepub fn new(
description: String,
geo_position: GeoPosition,
available_vehicles: Vec<ContinuousServiceVehicleAvailability>,
) -> ContinuousServicePickUpPlace
pub fn new( description: String, geo_position: GeoPosition, available_vehicles: Vec<ContinuousServiceVehicleAvailability>, ) -> ContinuousServicePickUpPlace
Pick-up places for on-demand vehicles like taxis, bicycles or scooters