pub struct CorporateCode {
pub code: String,
pub beneficiary: Option<Option<String>>,
pub issuer: String,
}Expand description
CorporateCode : The corporate code is a token that reduces the price of an offer or enables offers that are not available without it. Needs with a commercial agreement between parties.
Fields
code: StringThe corporate code issued by the referenced company.
beneficiary: Option<Option<String>>The name of the party that benefits from the corporate code, intended to be presented to the end user.
issuer: StringIdentifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
Implementations
Sourceimpl CorporateCode
impl CorporateCode
Sourcepub fn new(code: String, issuer: String) -> CorporateCode
pub fn new(code: String, issuer: String) -> CorporateCode
The corporate code is a token that reduces the price of an offer or enables offers that are not available without it. Needs with a commercial agreement between parties.