pub struct Document {
pub id: String,
pub summary: Option<Option<String>>,
pub passenger_ref: Option<Option<String>>,
pub download_link: Option<Option<String>>,
pub download_expiry: Option<Option<String>>,
pub content: Option<Option<Vec<u8>>>,
pub format: Option<DocumentFormat>,
pub type: DocumentType,
pub scope: DocumentScope,
}Expand description
Document : Non travel document created. Either downloadLink + downloadExpiry or content must be provided.
Fields
id: Stringsummary: Option<Option<String>>passenger_ref: Option<Option<String>>Reference to a passenger, to be specified when the document related to an individual passenger.
download_link: Option<Option<String>>download_expiry: Option<Option<String>>Expiration time of the download link, the document will not be available at the given URI after this time.
content: Option<Option<Vec<u8>>>base64 encoded binary of the actual fulfillment document. The length restriction of 4 MBytes applies to the encoded string, so the raw document cannot exceed 3 MBytes in size.
format: Option<DocumentFormat>type: DocumentTypescope: DocumentScopeImplementations
Sourceimpl Document
impl Document
Sourcepub fn new(id: String, type: DocumentType, scope: DocumentScope) -> Document
pub fn new(id: String, type: DocumentType, scope: DocumentScope) -> Document
Non travel document created. Either downloadLink + downloadExpiry or content must be provided.