Module document_format

Module document_format 

Enums

DocumentFormat
DocumentFormat : Physical format of the document provided in the content field in Mime-Type format, e.g. application/pdf, image/jpeg, etc. Must be filled if the ‘content’ field is present. Physical format of the document provided in the content field in Mime-Type format, e.g. application/pdf, image/jpeg, etc. Must be filled if the ‘content’ field is present.