pub struct DocumentSpecification {
pub passenger_ref: Option<Option<String>>,
pub content: Option<Option<Vec<u8>>>,
pub format: Option<DocumentFormat>,
pub scope: DocumentScope,
pub type: DocumentType,
}Expand description
DocumentSpecification : Non travel document created. Either downloadLink + downloadExpiry or content must be provided.
Fields
passenger_ref: Option<Option<String>>Reference to a passenger, to be specified when the document related to an individual passenger.
content: Option<Option<Vec<u8>>>base64 encoded binary of the actual fulfillment document. The length restriction of 4 MBytes applies to the encoded string, so the raw document cannot exceed 3 MBytes in size.
format: Option<DocumentFormat>scope: DocumentScopetype: DocumentTypeImplementations
Sourceimpl DocumentSpecification
impl DocumentSpecification
Sourcepub fn new(scope: DocumentScope, type: DocumentType) -> DocumentSpecification
pub fn new(scope: DocumentScope, type: DocumentType) -> DocumentSpecification
Non travel document created. Either downloadLink + downloadExpiry or content must be provided.