pub struct EventDetail {
pub summary: String,
pub requestor: String,
pub change: HistoryStatus,
pub resource: Box<Resource>,
}Fields
summary: Stringhuman readable description of the event
requestor: StringContains detailed information about who is calling the API. It can include information such as channel, organization, sales unit or workstation id and be used to configure e.g. the fare range provided to the caller. The content of the string is part of a bilateral contract by the two parties and not standardized by OSDM. It is recommend to encrypt the information transferred.
change: HistoryStatusresource: Box<Resource>Implementations
Sourceimpl EventDetail
impl EventDetail
pub fn new( summary: String, requestor: String, change: HistoryStatus, resource: Resource, ) -> EventDetail