ExchangeOffer

Struct ExchangeOffer 

pub struct ExchangeOffer {
Show 23 fields pub exchange_fee: Box<Price>, pub accounting_ref: Option<Box<AccountingRef>>, pub exchange_price: Box<Price>, pub refundable_amount: Option<Box<Price>>, pub amount_to_be_paid: Option<Box<Price>>, pub applied_overrule_code: Option<String>, pub fulfillments: Vec<Fulfillment>, pub offer_id: String, pub summary: Option<Option<String>>, pub offer_summary: Option<Box<OfferSummary>>, pub created_on: String, pub pre_bookable_until: String, pub passenger_refs: Vec<String>, pub products: Option<Vec<Product>>, pub trip_coverage: Option<Box<TripCoverage>>, pub inbound_trip_coverage: Option<Box<TripCoverage>>, pub exchange_offer_breakdown: Option<Vec<ExchangeBreakdownItem>>, pub admission_offer_parts: Vec<AdmissionOfferPart>, pub reservation_offer_parts: Option<Vec<ReservationOfferPart>>, pub ancillary_offer_parts: Option<Vec<AncillaryOfferPart>>, pub fees: Option<Vec<Fee>>, pub fares: Option<Vec<Fare>>, pub _links: Option<Vec<Link>>,
}

Fields

exchange_fee: Box<Price>accounting_ref: Option<Box<AccountingRef>>exchange_price: Box<Price>refundable_amount: Option<Box<Price>>amount_to_be_paid: Option<Box<Price>>applied_overrule_code: Option<String>

Reason for and type of an after sale, code list in IRS 90918-10. The PRM_SUPPORT_UNAVAILABLE overrule code shall only be used by the UIC PRM ABT tool. Values from the Overrule Codes Code List Listed values here are examples. - ‘CONNECTION_BROKEN’ - ‘DEATH’ - ‘EQUIPMENT_FAILURE’ - ‘PAYMENT_FAILURE’ - ‘PRM_SUPPORT_UNAVAILABLE’ - ‘SALES_STAFF_ERROR’ - ‘STOP_NOT_SERVED’ - ‘STRIKE’ - ‘TECHNICAL_FAILURE’ - ‘TICKET_NOT_USED’ - ‘INABILITY_TO_TRAVEL’: Inability to travel due to accident or sickness. - ‘EXTERNAL_COMPENSATION’: Offer has been compensated outside of the provider system in another way. - ‘DISRUPTION’: Inability to operate due to disruption. - ‘JOURNEY_OBSOLETE’: Due to external factors it’s senseless to start the trip, thus the travel is obsolete. - ‘CERTIFIED_MEDICAL_CONDITION’: A medical certificate certifies that the passenger is unable to travel. - ‘DELAY_COMPENSATION’: Allows to override conditions in context of passenger rights regulation (PRR).

fulfillments: Vec<Fulfillment>offer_id: Stringsummary: Option<Option<String>>

A human-readable description of the offer.

offer_summary: Option<Box<OfferSummary>>created_on: Stringpre_bookable_until: String

time until the offer can be pre-booked, however its availability is not guaranteed

passenger_refs: Vec<String>products: Option<Vec<Product>>trip_coverage: Option<Box<TripCoverage>>inbound_trip_coverage: Option<Box<TripCoverage>>exchange_offer_breakdown: Option<Vec<ExchangeBreakdownItem>>

Breakdown of the exchange offer, including the exchange price, exchange fee, and refundable amount.

admission_offer_parts: Vec<AdmissionOfferPart>reservation_offer_parts: Option<Vec<ReservationOfferPart>>ancillary_offer_parts: Option<Vec<AncillaryOfferPart>>fees: Option<Vec<Fee>>fares: Option<Vec<Fare>>_links: Option<Vec<Link>>

Java Property Name: ‘links’

Implementations

Source

impl ExchangeOffer

pub fn new( exchange_fee: Price, exchange_price: Price, fulfillments: Vec<Fulfillment>, offer_id: String, created_on: String, pre_bookable_until: String, passenger_refs: Vec<String>, admission_offer_parts: Vec<AdmissionOfferPart>, ) -> ExchangeOffer