pub struct ExchangeOfferCollectionRequest {Show 13 fields
pub fulfillment_ids: Vec<String>,
pub overrule_code: Option<String>,
pub trip_specifications: Option<Vec<TripSpecification>>,
pub trip_ids: Option<Option<Vec<String>>>,
pub trip_search_criteria: Option<Box<TripSearchCriteria>>,
pub non_trip_search_criteria: Option<Box<NonTripSearchCriteria>>,
pub requested_sections: Option<Vec<Section>>,
pub offer_search_criteria: Option<Box<OfferSearchCriteria>>,
pub anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>,
pub corporate_codes: Option<Vec<CorporateCode>>,
pub promotion_codes: Option<Vec<PromotionCode>>,
pub requested_fulfillment_options: Option<Vec<FulfillmentOption>>,
pub embed: Option<Vec<OfferCollectionResponseContent>>,
}Expand description
ExchangeOfferCollectionRequest : Defines the parameters needed to request an exchange offer, either based on either an existing trip (that is then passed in) plus a set of offer search criteria, or based on trip-search and offer search criteria. At least one of the trip or tripSearchCriteria must be set.
Fields
fulfillment_ids: Vec<String>overrule_code: Option<String>Reason for and type of an after sale, code list in IRS 90918-10. The PRM_SUPPORT_UNAVAILABLE overrule code shall only be used by the UIC PRM ABT tool. Values from the Overrule Codes Code List Listed values here are examples. - ‘CONNECTION_BROKEN’ - ‘DEATH’ - ‘EQUIPMENT_FAILURE’ - ‘PAYMENT_FAILURE’ - ‘PRM_SUPPORT_UNAVAILABLE’ - ‘SALES_STAFF_ERROR’ - ‘STOP_NOT_SERVED’ - ‘STRIKE’ - ‘TECHNICAL_FAILURE’ - ‘TICKET_NOT_USED’ - ‘INABILITY_TO_TRAVEL’: Inability to travel due to accident or sickness. - ‘EXTERNAL_COMPENSATION’: Offer has been compensated outside of the provider system in another way. - ‘DISRUPTION’: Inability to operate due to disruption. - ‘JOURNEY_OBSOLETE’: Due to external factors it’s senseless to start the trip, thus the travel is obsolete. - ‘CERTIFIED_MEDICAL_CONDITION’: A medical certificate certifies that the passenger is unable to travel. - ‘DELAY_COMPENSATION’: Allows to override conditions in context of passenger rights regulation (PRR).
trip_specifications: Option<Vec<TripSpecification>>trip_ids: Option<Option<Vec<String>>>trip_search_criteria: Option<Box<TripSearchCriteria>>non_trip_search_criteria: Option<Box<NonTripSearchCriteria>>requested_sections: Option<Vec<Section>>offer_search_criteria: Option<Box<OfferSearchCriteria>>anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>corporate_codes: Option<Vec<CorporateCode>>promotion_codes: Option<Vec<PromotionCode>>requested_fulfillment_options: Option<Vec<FulfillmentOption>>embed: Option<Vec<OfferCollectionResponseContent>>Implementations
Sourceimpl ExchangeOfferCollectionRequest
impl ExchangeOfferCollectionRequest
Sourcepub fn new(
fulfillment_ids: Vec<String>,
anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>,
) -> ExchangeOfferCollectionRequest
pub fn new( fulfillment_ids: Vec<String>, anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>, ) -> ExchangeOfferCollectionRequest
Defines the parameters needed to request an exchange offer, either based on either an existing trip (that is then passed in) plus a set of offer search criteria, or based on trip-search and offer search criteria. At least one of the trip or tripSearchCriteria must be set.