Module exchange_operation_patch_request

Module exchange_operation_patch_request 

Structs

ExchangeOperationPatchRequest
ExchangeOperationPatchRequest : Allows modifying a general setting for the booking: * setting the required fulfillment type, e.g. value paper or e-ticket and preferred fulfillment media. The latter is optional and relevant in some cases only. * Provisionally exchanging some of the fulfillments in the booking