pub enum ExchangeOperationResponseContent {
All,
Exchangeoperation,
ExchangeoperationExchangeoffers,
ExchangeoperationFulfillments,
}Expand description
ExchangeOperationResponseContent : Influences whether referenced resources are returned in full or as references only. Influences whether referenced resources are returned in full or as references only.
Variants