pub enum ExchangeableType {
Yes,
No,
WithCondition,
}Expand description
ExchangeableType : If set to YES the offerpart is exchangeable without a fee before the day of departure. NO when not exchangeable or exchangeable with 100% fee, WITH_CONDITIONS in all other cases. If set to YES the offerpart is exchangeable without a fee before the day of departure. NO when not exchangeable or exchangeable with 100% fee, WITH_CONDITIONS in all other cases.
Variants