pub struct ExcludedTimeRange {
pub from: i32,
pub until: i32,
pub scope: ExclusionScope,
}Expand description
ExcludedTimeRange : time ranges excluded from the validity (e.g. off peak fulfillments)
Fields
from: i32minutes of the day in the time zone of travel
until: i32minutes of the day in the time zone of travel
scope: ExclusionScopeImplementations
Sourceimpl ExcludedTimeRange
impl ExcludedTimeRange
Sourcepub fn new(from: i32, until: i32, scope: ExclusionScope) -> ExcludedTimeRange
pub fn new(from: i32, until: i32, scope: ExclusionScope) -> ExcludedTimeRange
time ranges excluded from the validity (e.g. off peak fulfillments)