Fare

Struct Fare 

pub struct Fare {
Show 29 fields pub id: String, pub type: String, pub name: Option<Box<Text>>, pub description: Option<Box<Text>>, pub status: Option<BookingPartStatus>, pub prices: Vec<Price>, pub regional_constraint: Box<RegionalConstraint>, pub service_constraint: Option<Box<ServiceConstraint>>, pub carrier_constraint: Option<Box<CarrierConstraint>>, pub regulatory_conditions: Option<Vec<RegulatoryCondition>>, pub service_class: Option<Box<ServiceClass>>, pub travel_class: String, pub after_sales_condition: Box<AfterSalesConditionsLink>, pub combination_constraint: Vec<FareCombinationModel>, pub fulfillment_constraint: Option<Box<FulfillmentConstraint>>, pub travel_validity_constraint: Box<TravelValidity>, pub available_places: Option<Vec<AvailablePlace>>, pub place_selection: Option<Box<PlaceSelection>>, pub place_allocation: Option<Vec<PlaceAllocation>>, pub covered_section: Option<Box<Section>>, pub passenger_refs: Option<Vec<String>>, pub passenger_constraints: Option<Vec<PassengerConstraints>>, pub involved_tcos: Option<Vec<String>>, pub accounting_ref: Option<Box<AccountingRef>>, pub legacy_accounting_identifier: Option<Box<LegacyAccountingIdentifier>>, pub legacy_reservation_parameter: Option<Box<LegacyReservationParameter>>, pub required_cards: Option<Vec<CardReference>>, pub luggage_constraint: Option<Box<LuggageConstraint>>, pub available_preferences: Option<Vec<AvailablePlacePreferences>>,
}
Fare : The online representation of a fare. In case the final product requires the indication of carriers it is obligatory to provide a carrierConstraint in the fare directly that includes the list of all carriers in the includedCarrier list. Whether the carrier must be indicated needs to be derived from the requested total route and the location of the sales points for international sales. Whether the indication of carriers is obligatory is defined in the Convention concerning International Carriage by Rail (COTIF).

Fields

id: String

id of the fare item to be included in accounting

type: String

Basic UIC fare types used in 90918-10, 90918-4, and 90918-9. Values from the Fare Type Code List Listed values here are examples.

name: Option<Box<Text>>description: Option<Box<Text>>status: Option<BookingPartStatus>prices: Vec<Price>

allows specifying a price in multiple currencies

regional_constraint: Box<RegionalConstraint>service_constraint: Option<Box<ServiceConstraint>>carrier_constraint: Option<Box<CarrierConstraint>>regulatory_conditions: Option<Vec<RegulatoryCondition>>service_class: Option<Box<ServiceClass>>travel_class: String

Traditional first and second class.

after_sales_condition: Box<AfterSalesConditionsLink>combination_constraint: Vec<FareCombinationModel>fulfillment_constraint: Option<Box<FulfillmentConstraint>>travel_validity_constraint: Box<TravelValidity>available_places: Option<Vec<AvailablePlace>>place_selection: Option<Box<PlaceSelection>>place_allocation: Option<Vec<PlaceAllocation>>covered_section: Option<Box<Section>>passenger_refs: Option<Vec<String>>passenger_constraints: Option<Vec<PassengerConstraints>>

passenger constraint to be included in bar codes

involved_tcos: Option<Vec<String>>accounting_ref: Option<Box<AccountingRef>>legacy_accounting_identifier: Option<Box<LegacyAccountingIdentifier>>legacy_reservation_parameter: Option<Box<LegacyReservationParameter>>required_cards: Option<Vec<CardReference>>

One of the listed cards is required to be valid at the time of travel.

luggage_constraint: Option<Box<LuggageConstraint>>available_preferences: Option<Vec<AvailablePlacePreferences>>

Implementations

Source

impl Fare

pub fn new( id: String, type: String, prices: Vec<Price>, regional_constraint: RegionalConstraint, travel_class: String, after_sales_condition: AfterSalesConditionsLink, combination_constraint: Vec<FareCombinationModel>, travel_validity_constraint: TravelValidity, ) -> Fare

The online representation of a fare. In case the final product requires the indication of carriers it is obligatory to provide a carrierConstraint in the fare directly that includes the list of all carriers in the includedCarrier list. Whether the carrier must be indicated needs to be derived from the requested total route and the location of the sales points for international sales. Whether the indication of carriers is obligatory is defined in the Convention concerning International Carriage by Rail (COTIF).