pub struct FareCombinationModel {
pub model: String,
pub combinable_carriers: Option<Vec<String>>,
pub is_valid_only_when_combined: Option<Option<bool>>,
pub reference_cluster: Option<Option<String>>,
pub allowed_clusters: Option<Option<Vec<String>>>,
pub allowed_common_contracts: Option<Vec<String>>,
}Expand description
FareCombinationModel : Defines the model according to which the fares can be combined.
Fields
model: StringA distributor needs to support the following models: SEPARATE_TICKET, SEPARATE_CONTRACT, CLUSTERING, COMBINING.
combinable_carriers: Option<Vec<String>>List of all carriers where the model can be applied, in case the list is empty all combinations are allowed.
is_valid_only_when_combined: Option<Option<bool>>This combination model applies only in case the fare is combined with another carrier
reference_cluster: Option<Option<String>>In case of CLUSTERING model: the cluster to which the fare belongs
allowed_clusters: Option<Option<Vec<String>>>In case of CLUSTERING model: the other clusters that allow a combination
allowed_common_contracts: Option<Vec<String>>List of carriers where a common contract with separate fulfillments are allowed.
Implementations
Sourceimpl FareCombinationModel
impl FareCombinationModel
Sourcepub fn new(model: String) -> FareCombinationModel
pub fn new(model: String) -> FareCombinationModel
Defines the model according to which the fares can be combined.