Module fare_connection_point

Module fare_connection_point 

Structs

FareConnectionPoint
FareConnectionPoint : Connection point connecting two fare regimes. The connection is possible between stations of the two provided station sets. A legacy border point code (id) might be provided as an additional code within the stations (code list BORDER_POINT provided in URN). In case the connection point is a real station this station is indicated. In case the connection point is between stations for each side of the border real stations must be provided. Multiple sets of station can be provided in the rare case that the connection point connects more than two station (A-B and A-C). Multiple stations within a set at one side of the border might be provided in case of changes (new stations build near the border). Providing the UIC code for the station is mandatory.