FareConnectionPoint

Struct FareConnectionPoint 

pub struct FareConnectionPoint {
    pub object_type: String,
    pub id: String,
    pub alternative_ids: Option<Option<Vec<String>>>,
    pub geo_position: Option<Box<GeoPosition>>,
    pub ref: Option<Box<PlaceRef>>,
    pub _links: Option<Vec<Link>>,
    pub name: Option<Option<String>>,
    pub station_sets: Vec<StationSet>,
}
FareConnectionPoint : Connection point connecting two fare regimes. The connection is possible between stations of the two provided station sets. A legacy border point code (id) might be provided as an additional code within the stations (code list BORDER_POINT provided in URN). In case the connection point is a real station this station is indicated. In case the connection point is between stations for each side of the border real stations must be provided. Multiple sets of station can be provided in the rare case that the connection point connects more than two station (A-B and A-C). Multiple stations within a set at one side of the border might be provided in case of changes (new stations build near the border). Providing the UIC code for the station is mandatory.

Fields

object_type: String

Attribute is used as discriminator for inheritance between data types.

id: String

id defining the place. The code is provided as URN, relative URNs are allowed with base path urn:uic:stn ‘0850000’

alternative_ids: Option<Option<Vec<String>>>

For a place with ids in different reference systems, the alternative ids can be returned. The reference system is encoded in the string. E.g.: ‘urn:uic:std:80000’, ‘x_swe:stn:10000’, ‘ch:1:sloid:343434’

geo_position: Option<Box<GeoPosition>>ref: Option<Box<PlaceRef>>_links: Option<Vec<Link>>

Java Property Name: ‘links’

name: Option<Option<String>>station_sets: Vec<StationSet>

Implementations

Source

impl FareConnectionPoint

pub fn new( object_type: String, id: String, station_sets: Vec<StationSet>, ) -> FareConnectionPoint

Connection point connecting two fare regimes. The connection is possible between stations of the two provided station sets. A legacy border point code (id) might be provided as an additional code within the stations (code list BORDER_POINT provided in URN). In case the connection point is a real station this station is indicated. In case the connection point is between stations for each side of the border real stations must be provided. Multiple sets of station can be provided in the rare case that the connection point connects more than two station (A-B and A-C). Multiple stations within a set at one side of the border might be provided in case of changes (new stations build near the border). Providing the UIC code for the station is mandatory.