pub struct FareReferenceStation {
pub name: String,
pub code: String,
pub carrier: String,
pub stations: Vec<StopPlaceRef>,
}Expand description
FareReferenceStation : Reference to a list of stations jointly valid in a fare. The fare reference station defines a set of station that are equivalent from a tariff point of view. The code is issued by the carrier. Needed to generate bar codes as well as fulfillments.
Fields
name: Stringcode: Stringcarrier: StringIdentifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
stations: Vec<StopPlaceRef>Implementations
Sourceimpl FareReferenceStation
impl FareReferenceStation
Sourcepub fn new(
name: String,
code: String,
carrier: String,
stations: Vec<StopPlaceRef>,
) -> FareReferenceStation
pub fn new( name: String, code: String, carrier: String, stations: Vec<StopPlaceRef>, ) -> FareReferenceStation
Reference to a list of stations jointly valid in a fare. The fare reference station defines a set of station that are equivalent from a tariff point of view. The code is issued by the carrier. Needed to generate bar codes as well as fulfillments.