pub struct Fee {
pub id: String,
pub summary: Option<Option<String>>,
pub price: Box<Price>,
pub applicability: Option<String>,
pub transaction_context: Option<String>,
pub status: Option<FeeStatus>,
pub distributor_booking_ref: Option<Option<String>>,
pub refundable: Option<RefundType>,
pub conditions: Option<Vec<Condition>>,
pub product_code: Option<Option<String>>,
pub product_ref: Option<String>,
pub accounting_ref: Option<Box<AccountingRef>>,
}Expand description
Fee : Fees are used to represent additional costs for services or products. In contrast to other offer parts in OSDM, the customer is not free whether to choose a fee or not: fees are generated and applied to other services or products by the providing system.
Fields
id: Stringsummary: Option<Option<String>>A human-readable description of the fee.
price: Box<Price>applicability: Option<String>transaction_context: Option<String>status: Option<FeeStatus>distributor_booking_ref: Option<Option<String>>reference to the booking in the downstream distributor system
refundable: Option<RefundType>conditions: Option<Vec<Condition>>Structured description of the sales or after-sales conditions.
product_code: Option<Option<String>>The product code expressed in the provider system (could be a mapping from an even lower-level provider).
product_ref: Option<String>Reference to the Product representing the Fee
accounting_ref: Option<Box<AccountingRef>>Implementations
Sourceimpl Fee
impl Fee
Sourcepub fn new(id: String, price: Price) -> Fee
pub fn new(id: String, price: Price) -> Fee
Fees are used to represent additional costs for services or products. In contrast to other offer parts in OSDM, the customer is not free whether to choose a fee or not: fees are generated and applied to other services or products by the providing system.