Module fulfillment

Module fulfillment 

Structs

Fulfillment
Fulfillment : A fulfillment is a document (or part of a document in distributor mode) that - allows the passenger to prove its travel right - provides easier access to trains and stations - allows an exchange for other services (voucher) A fulfillment refers to services of one or multiple offer parts or a fare (distributor mode).