Fulfillment

Struct Fulfillment 

pub struct Fulfillment {
Show 17 fields pub id: String, pub status: FulfillmentStatus, pub booking_ref: String, pub summary: Option<Option<String>>, pub created_on: String, pub control_number: Option<Option<String>>, pub booking_parts: Option<Vec<BookingPartReference>>, pub available_usage: Option<Box<FulfillmentUsage>>, pub issuer: Option<String>, pub fulfillment_documents: Option<Vec<FulfillmentDocument>>, pub issuing_language: Option<String>, pub fulfillment_parts: Option<Vec<FulfillmentPart>>, pub content_complete: Option<Option<bool>>, pub trip_coverage: Option<Box<TripCoverage>>, pub inbound_trip_coverage: Option<Box<TripCoverage>>, pub continuous_service_usage: Option<Box<ContinuousServiceUsage>>, pub _links: Option<Vec<Link>>,
}
Fulfillment : A fulfillment is a document (or part of a document in distributor mode) that - allows the passenger to prove its travel right - provides easier access to trains and stations - allows an exchange for other services (voucher) A fulfillment refers to services of one or multiple offer parts or a fare (distributor mode).

Fields

id: Stringstatus: FulfillmentStatusbooking_ref: String

the id of the booking the fulfillment is part of

summary: Option<Option<String>>

A human-readable description of the fulfillment.

created_on: Stringcontrol_number: Option<Option<String>>

Ticket Control Number.

booking_parts: Option<Vec<BookingPartReference>>

reference to all booking parts that contributed to this fulfillment. If the fulfillment is made based on booking parts these references must be provided.

available_usage: Option<Box<FulfillmentUsage>>issuer: Option<String>

Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’

fulfillment_documents: Option<Vec<FulfillmentDocument>>

Final document created for fulfillment.

issuing_language: Option<String>

the issuing language (ISO-639-1 language code).

fulfillment_parts: Option<Vec<FulfillmentPart>>

Fulfillment items to be integrated into tickets (distributor mode).

content_complete: Option<Option<bool>>

Indicates whether the fulfillment has all documents or parts generated (if any needed) or they are still pending generation.

trip_coverage: Option<Box<TripCoverage>>inbound_trip_coverage: Option<Box<TripCoverage>>continuous_service_usage: Option<Box<ContinuousServiceUsage>>_links: Option<Vec<Link>>

Java Property Name: ‘links’

Implementations

Source

impl Fulfillment

pub fn new( id: String, status: FulfillmentStatus, booking_ref: String, created_on: String, ) -> Fulfillment

A fulfillment is a document (or part of a document in distributor mode) that - allows the passenger to prove its travel right - provides easier access to trains and stations - allows an exchange for other services (voucher) A fulfillment refers to services of one or multiple offer parts or a fare (distributor mode).