FulfillmentDocument

Struct FulfillmentDocument 

pub struct FulfillmentDocument {
    pub medium: String,
    pub type: String,
    pub download_link: Option<Option<String>>,
    pub download_expiry: Option<Option<String>>,
    pub content: Option<Option<Vec<u8>>>,
    pub format: DocumentFormat,
    pub application_provider: Option<String>,
}
FulfillmentDocument : Document created for fulfillment. Either downloadLink + downloadExpiry or content must be provided.

Fields

medium: String

Fulfillment types. RCT2, RCCST and UIC_PDF are official UIC standards. Notice:ALLOCATOR_APP is deprecated and should not be used anymore. The ALLOCATOR_APP type is replaced by the RETAILER_APP type. DISTRIBUTOR_APP was introduced to distinguish between the different types of apps that can be used to fulfill a booking. Values from the Fulfillment Media Type Code List Listed values here are examples.

type: String

The type of fulfillment document. Values from the Fulfillment Document Type Code List

download_link: Option<Option<String>>download_expiry: Option<Option<String>>

Expiration time of the download link, the document will not be available at the given URI after this time.

content: Option<Option<Vec<u8>>>

base64 encoded binary of the actual fulfillment document. The length restriction of 4 MBytes applies to the encoded string, so the raw document cannot exceed 3 MBytes in size.

format: DocumentFormatapplication_provider: Option<String>

Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’

Implementations

Source

impl FulfillmentDocument

pub fn new( medium: String, type: String, format: DocumentFormat, ) -> FulfillmentDocument

Document created for fulfillment. Either downloadLink + downloadExpiry or content must be provided.