pub struct FulfillmentPart {
pub fulfillment_media: Option<Vec<String>>,
pub passenger_ref: Option<Option<String>>,
pub control_id: Option<Option<String>>,
pub security_features: Option<Vec<FulfillmentItemSecurityFeature>>,
pub security_feature_links: Option<Vec<FulfillmentItemSecurityFeatureLinks>>,
pub fulfillment_information_texts: Option<Vec<TextElement>>,
pub is_mandatory: Option<Option<bool>>,
pub secure_paper_only: Option<Option<bool>>,
}Expand description
FulfillmentPart : Fulfillment items to be integrated in to tickets, e.g. visual security elements, additional bar codes, control keys.
Fields
fulfillment_media: Option<Vec<String>>list of fulfillment media where this item applies
passenger_ref: Option<Option<String>>reference to a passenger
control_id: Option<Option<String>>security_features: Option<Vec<FulfillmentItemSecurityFeature>>‘visual elements, bar codes’
security_feature_links: Option<Vec<FulfillmentItemSecurityFeatureLinks>>fulfillment_information_texts: Option<Vec<TextElement>>is_mandatory: Option<Option<bool>>The use of the provided features is mandatory.
secure_paper_only: Option<Option<bool>>The security feature must be used on secure paper.
Implementations
Sourceimpl FulfillmentPart
impl FulfillmentPart
Sourcepub fn new() -> FulfillmentPart
pub fn new() -> FulfillmentPart
Fulfillment items to be integrated in to tickets, e.g. visual security elements, additional bar codes, control keys.