pub struct FulfillmentUsage {
pub from_place_required: Option<Option<bool>>,
pub travel_dates: Option<Option<Vec<String>>>,
pub travel_validity_ranges: Option<Vec<TravelValidityRange>>,
pub max_available_zones: Option<Option<i32>>,
pub available_zones: Option<Vec<ZoneDefinition>>,
}Expand description
FulfillmentUsage : In case of multi-journey products describe parameters to be used to change the a fulfillment in status AVAILABLE to FULFILLED so it can be used by the passenger.
Fields
from_place_required: Option<Option<bool>>travel_dates: Option<Option<Vec<String>>>Travel dates that can be selected. Note: date only is used to cover properly the case of passes including multiple time zones.
travel_validity_ranges: Option<Vec<TravelValidityRange>>max_available_zones: Option<Option<i32>>upper limit to the number of selected zones
available_zones: Option<Vec<ZoneDefinition>>Implementations
Sourceimpl FulfillmentUsage
impl FulfillmentUsage
Sourcepub fn new() -> FulfillmentUsage
pub fn new() -> FulfillmentUsage
In case of multi-journey products describe parameters to be used to change the a fulfillment in status AVAILABLE to FULFILLED so it can be used by the passenger.