pub enum Gender {
Male,
Female,
X,
}Expand description
Gender : The gender of the passenger, which is important in the case of night trains. Values from the Gender Code List The gender of the passenger, which is important in the case of night trains. Values from the Gender Code List
Variants