GrantedReductionAmount

Struct GrantedReductionAmount 

pub struct GrantedReductionAmount {
    pub description: String,
    pub granted_amount: Box<Price>,
    pub passenger_refs: Option<Vec<String>>,
    pub trip_coverage: Option<Box<TripCoverage>>,
    pub inbound_trip_coverage: Option<Box<TripCoverage>>,
    pub applied_passenger_types: Option<Vec<String>>,
    pub applied_reductions: Option<Vec<CardReference>>,
    pub applied_corporate_codes: Option<Vec<CorporateCode>>,
    pub applied_promotion_codes: Option<Vec<PromotionCode>>,
}
GrantedReductionAmount : Applied passenger types and reductions per passenger, per offerpart, booking part and per part of the trip. Passengers might be omitted in case the reduction applies to the complete booking part.

Fields

description: String

Clear text representation of the actual passenger type, suitable to be presented to a client.

granted_amount: Box<Price>passenger_refs: Option<Vec<String>>

ids of the passengers that were granted the reduction

trip_coverage: Option<Box<TripCoverage>>inbound_trip_coverage: Option<Box<TripCoverage>>applied_passenger_types: Option<Vec<String>>applied_reductions: Option<Vec<CardReference>>applied_corporate_codes: Option<Vec<CorporateCode>>applied_promotion_codes: Option<Vec<PromotionCode>>

Implementations

Source

impl GrantedReductionAmount

pub fn new(description: String, granted_amount: Price) -> GrantedReductionAmount

Applied passenger types and reductions per passenger, per offerpart, booking part and per part of the trip. Passengers might be omitted in case the reduction applies to the complete booking part.