pub struct GridPosition {
pub x: i32,
pub y: i32,
pub z: i32,
}Expand description
GridPosition : Describes the position in a 3D grid on which the element must be placed. The grid origin (x=0, y=0) is on the top left, the x coordinate increases to the right, the y coordinate increases downwards and the z coordinate increases towards the foreground.
Fields
x: i32y: i32z: i32Implementations
Sourceimpl GridPosition
impl GridPosition
Sourcepub fn new(x: i32, y: i32, z: i32) -> GridPosition
pub fn new(x: i32, y: i32, z: i32) -> GridPosition
Describes the position in a 3D grid on which the element must be placed. The grid origin (x=0, y=0) is on the top left, the x coordinate increases to the right, the y coordinate increases downwards and the z coordinate increases towards the foreground.