Module identification_card

Module identification_card 

Structs

IdentificationCard
IdentificationCard : Person identification information to be exchanged for border control if legally required. It is not allowed to send personal information not required in the offer reply. It is legally not allowed to send these personal data already in the offer request.