IdentificationCard

Struct IdentificationCard 

pub struct IdentificationCard {
Show 13 fields pub id: String, pub type: String, pub name: Option<Option<String>>, pub nationality: Option<Option<String>>, pub birth_city: Option<Option<String>>, pub issuing_city: Option<Option<String>>, pub residence_city: Option<Option<String>>, pub birth_country_code: Option<String>, pub issuing_country_code: Option<String>, pub residence_country_code: Option<String>, pub issuing_date: Option<Option<String>>, pub gender: Option<Option<Gender>>, pub expiration_date: Option<Option<String>>,
}
IdentificationCard : Person identification information to be exchanged for border control if legally required. It is not allowed to send personal information not required in the offer reply. It is legally not allowed to send these personal data already in the offer request.

Fields

id: String

Identifier on the document.

type: String

Refer to code list for values

name: Option<Option<String>>

ICAO transliteration identical as written in the document

nationality: Option<Option<String>>

ISO 3166-1 alpha-2 2 character country code

birth_city: Option<Option<String>>issuing_city: Option<Option<String>>

place where the document is issued

residence_city: Option<Option<String>>birth_country_code: Option<String>

ISO 3166-1 alpha-2 2 character country code

issuing_country_code: Option<String>

ISO 3166-1 alpha-2 2 character country code

residence_country_code: Option<String>

ISO 3166-1 alpha-2 2 character country code

issuing_date: Option<Option<String>>gender: Option<Option<Gender>>expiration_date: Option<Option<String>>

Implementations

Source

impl IdentificationCard

pub fn new(id: String, type: String) -> IdentificationCard

Person identification information to be exchanged for border control if legally required. It is not allowed to send personal information not required in the offer reply. It is legally not allowed to send these personal data already in the offer request.