pub struct Line {
pub binary_line_id: Option<Option<Vec<u8>>>,
pub carrier: String,
pub city: Option<Option<i32>>,
pub entry_station: Option<Box<StopPlace>>,
pub line_ids: Option<Option<Vec<String>>>,
pub terminal_station: Option<Box<StopPlace>>,
pub nuts_code: Option<Option<String>>,
}Expand description
Line : terminalStation - in case the product requires a destination within the zone (e.g. local ticket to go to the main rail station). entryStation - Station to enter the zone in case the product requires to enter the zone via a specific station (e.g. local zone ticket to start from the main rail station).
Fields
binary_line_id: Option<Option<Vec<u8>>>Id to support local traffic standards (e.g. VDV,…).
carrier: StringIdentifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
city: Option<Option<i32>>entry_station: Option<Box<StopPlace>>line_ids: Option<Option<Vec<String>>>terminal_station: Option<Box<StopPlace>>nuts_code: Option<Option<String>>Nomenclature des units territoriales statistiques COMMISSION REGULATION (EU) No 31/2011
Implementations
Sourceimpl Line
impl Line
Sourcepub fn new(carrier: String) -> Line
pub fn new(carrier: String) -> Line
terminalStation - in case the product requires a destination within the zone (e.g. local ticket to go to the main rail station). entryStation - Station to enter the zone in case the product requires to enter the zone via a specific station (e.g. local zone ticket to start from the main rail station).