pub struct Mode {
pub pt_mode: String,
pub name: Option<Option<String>>,
pub short_name: Option<Option<String>>,
pub description: Option<Option<String>>,
}Expand description
Mode : A method of transportation such as bus, rail, etc. Provided by OJP.
Fields
pt_mode: StringTAP-TSI/UIC contains a sensible subset of SIRI Transport Modes. Values from the Transport Mode Code List Listed values here are examples.
name: Option<Option<String>>Name of the mode
short_name: Option<Option<String>>Short name or acronym of the mode
description: Option<Option<String>>Additional text that further describes the mode
Implementations