pub enum OfferMode {
Collective,
Individual,
}Expand description
OfferMode : Offer mode applied to provide offers for given criteria. Individual offer mode means that each passenger is given individual admissions and reservations to allow to refund individual passengers booked in a single booking. If collective mode is not supported, reverts back to the other mode and provides warning instead. Offer mode applied to provide offers for given criteria. Individual offer mode means that each passenger is given individual admissions and reservations to allow to refund individual passengers booked in a single booking. If collective mode is not supported, reverts back to the other mode and provides warning instead.
Variants