pub struct OfferOverviewRouteRequest {
pub route_specification: Box<RouteSpecification>,
pub passenger_specifications: Vec<AnonymousPassengerSpecification>,
pub start_date_time: String,
pub end_date_time: String,
pub time_frame_segmentation: Option<TimeFrameSegmentation>,
pub travel_class: Option<String>,
pub flexibility: Option<String>,
}Expand description
OfferOverviewRouteRequest : Defines the parameters needed to request an offer overview for a route. Travel class and flexibility are optional parameters to filter the desired offers.
Fields
route_specification: Box<RouteSpecification>passenger_specifications: Vec<AnonymousPassengerSpecification>start_date_time: Stringend_date_time: Stringtime_frame_segmentation: Option<TimeFrameSegmentation>Defines the segmentation of the time frame for the offer overview. The default is DAY, which means that one price offer overview is given for each day of the requested time frame (provided there aren’t more than one travel classes or flexibilities for one time segment).
travel_class: Option<String>Traditional first and second class.
flexibility: Option<String>Implementations
Sourceimpl OfferOverviewRouteRequest
impl OfferOverviewRouteRequest
Sourcepub fn new(
route_specification: RouteSpecification,
passenger_specifications: Vec<AnonymousPassengerSpecification>,
start_date_time: String,
end_date_time: String,
) -> OfferOverviewRouteRequest
pub fn new( route_specification: RouteSpecification, passenger_specifications: Vec<AnonymousPassengerSpecification>, start_date_time: String, end_date_time: String, ) -> OfferOverviewRouteRequest
Defines the parameters needed to request an offer overview for a route. Travel class and flexibility are optional parameters to filter the desired offers.