OfferOverviewTripRequest

Struct OfferOverviewTripRequest 

pub struct OfferOverviewTripRequest {
    pub trip_specifications: Option<Vec<TripSpecification>>,
    pub trip_ids: Option<Option<Vec<String>>>,
    pub trip_search_criteria: Option<Box<TripSearchCriteria>>,
    pub trip_response_parameters: Option<Box<TripResponseParameters>>,
    pub passenger_specifications: Vec<AnonymousPassengerSpecification>,
    pub travel_class: Option<String>,
    pub flexibility: Option<String>,
}
OfferOverviewTripRequest : Defines the parameters needed to request an offer overview for a trip. One of tripSearchCriteria, a list of trip specifications, or a list of tripIds must be passed in to request offers. Travel class and flexibility are optional parameters to filter the desired offers.

Fields

trip_specifications: Option<Vec<TripSpecification>>trip_ids: Option<Option<Vec<String>>>trip_search_criteria: Option<Box<TripSearchCriteria>>trip_response_parameters: Option<Box<TripResponseParameters>>passenger_specifications: Vec<AnonymousPassengerSpecification>travel_class: Option<String>

Traditional first and second class.

flexibility: Option<String>

Implementations

Source

impl OfferOverviewTripRequest

pub fn new( passenger_specifications: Vec<AnonymousPassengerSpecification>, ) -> OfferOverviewTripRequest

Defines the parameters needed to request an offer overview for a trip. One of tripSearchCriteria, a list of trip specifications, or a list of tripIds must be passed in to request offers. Travel class and flexibility are optional parameters to filter the desired offers.