OfferPartReference

Struct OfferPartReference 

pub struct OfferPartReference {
    pub id: String,
    pub summary: Option<Option<String>>,
    pub _links: Option<Vec<Link>>,
}
OfferPartReference : References all the offer part elements in an uniform format. In its part, an OfferPartReference can refer to reservation, admission, ancillary or fee.

Fields

id: Stringsummary: Option<Option<String>>

A human-readable description of the offer part reference.

_links: Option<Vec<Link>>

Java Property Name: ‘links’

Implementations

Source

impl OfferPartReference

pub fn new(id: String) -> OfferPartReference

References all the offer part elements in an uniform format. In its part, an OfferPartReference can refer to reservation, admission, ancillary or fee.