pub struct OperatingDays {
pub from: String,
pub until: String,
pub pattern: String,
}Expand description
OperatingDays : Day of public transport operation of which the characteristics are defined in a specific service calendar and which may last more than 24 hours. Provided by OJP.
Fields
from: StringStart date of period
until: StringEnd date of period
pattern: StringBit pattern for operating days between start date and end date. The length of the pattern is equal to the number of days from start date to end date. A bit value of ‘1’ indicates that an event actually happens on the day that is represented by the bit position.
Implementations
Sourceimpl OperatingDays
impl OperatingDays