Module passenger
osdm_
sys
0.1.0-alpha.1
Module passenger
Module Items
Structs
In osdm_
sys::
models
osdm_sys
::
models
Module
passenger
Structs

Passenger
Passenger : Information about a passenger. Either the date of birth or the age at the time of travel needs to be set. We recommend to use date of birth as it is more stable than age.