pub struct PassengerSpecification {
pub external_ref: String,
pub date_of_birth: Option<Option<String>>,
pub age: Option<Option<i32>>,
pub cards: Option<Vec<CardReference>>,
pub prm_needs: Option<Vec<String>>,
pub detail: Option<Box<PersonDetail>>,
pub type: String,
pub gender: Option<Option<Gender>>,
pub transportable_details: Option<Box<Transportable>>,
}Expand description
PassengerSpecification : Minimal specification of a passenger to request offers. Either the date of birth or the age at the time of travel needs to be set. We recommend to use date of birth as it is more stable than age.
Fields
external_ref: StringA stable reference to a passenger from other elements, or from caller system. When received in input of a request, it must be echoed back in the response.
date_of_birth: Option<Option<String>>Date of birth of the passenger. Only needed for passengers of type persons, family child, PRM and wheelchair.
age: Option<Option<i32>>cards: Option<Vec<CardReference>>reduction or loyalty cards owned by the passenger
prm_needs: Option<Vec<String>>For the persons with reduced mobility (PRMs) its specific needs for support are expressed.
detail: Option<Box<PersonDetail>>type: StringPassenger type according to UIC passenger, i.e. passenger type list. Values from the Passenger Type Code List Listed values here are examples. Proposed default PERSON
gender: Option<Option<Gender>>transportable_details: Option<Box<Transportable>>Implementations
Sourceimpl PassengerSpecification
impl PassengerSpecification
Sourcepub fn new(external_ref: String, type: String) -> PassengerSpecification
pub fn new(external_ref: String, type: String) -> PassengerSpecification
Minimal specification of a passenger to request offers. Either the date of birth or the age at the time of travel needs to be set. We recommend to use date of birth as it is more stable than age.