pub enum Place {
Address {
id: String,
alternative_ids: Option<Vec<String>>,
geo_position: Option<Box<GeoPosition>>,
ref: Option<Box<PlaceRef>>,
_links: Option<Vec<Link>>,
},
FareConnectionPoint {
id: String,
alternative_ids: Option<Vec<String>>,
geo_position: Option<Box<GeoPosition>>,
ref: Option<Box<PlaceRef>>,
_links: Option<Vec<Link>>,
},
PointOfInterest {
id: String,
alternative_ids: Option<Vec<String>>,
geo_position: Option<Box<GeoPosition>>,
ref: Option<Box<PlaceRef>>,
_links: Option<Vec<Link>>,
},
StopPlace {
id: String,
alternative_ids: Option<Vec<String>>,
geo_position: Option<Box<GeoPosition>>,
ref: Option<Box<PlaceRef>>,
_links: Option<Vec<Link>>,
},
}Expand description
Place : A geographic place of any type which may be specified as the origin or destination of a trip. Provided by OJP.
Variants
Address
Fields
id: Stringid defining the place. The code is provided as URN, relative URNs are allowed with base path urn:uic:stn ‘0850000’
alternative_ids: Option<Vec<String>>For a place with ids in different reference systems, the alternative ids can be returned. The reference system is encoded in the string. E.g.: ‘urn:uic:std:80000’, ‘x_swe:stn:10000’, ‘ch:1:sloid:343434’
geo_position: Option<Box<GeoPosition>>FareConnectionPoint
Fields
id: Stringid defining the place. The code is provided as URN, relative URNs are allowed with base path urn:uic:stn ‘0850000’
alternative_ids: Option<Vec<String>>For a place with ids in different reference systems, the alternative ids can be returned. The reference system is encoded in the string. E.g.: ‘urn:uic:std:80000’, ‘x_swe:stn:10000’, ‘ch:1:sloid:343434’
geo_position: Option<Box<GeoPosition>>PointOfInterest
Fields
id: Stringid defining the place. The code is provided as URN, relative URNs are allowed with base path urn:uic:stn ‘0850000’
alternative_ids: Option<Vec<String>>For a place with ids in different reference systems, the alternative ids can be returned. The reference system is encoded in the string. E.g.: ‘urn:uic:std:80000’, ‘x_swe:stn:10000’, ‘ch:1:sloid:343434’
geo_position: Option<Box<GeoPosition>>StopPlace
Fields
id: Stringid defining the place. The code is provided as URN, relative URNs are allowed with base path urn:uic:stn ‘0850000’
alternative_ids: Option<Vec<String>>For a place with ids in different reference systems, the alternative ids can be returned. The reference system is encoded in the string. E.g.: ‘urn:uic:std:80000’, ‘x_swe:stn:10000’, ‘ch:1:sloid:343434’
geo_position: Option<Box<GeoPosition>>