pub struct PlaceAllocation {
pub accommodation_type: String,
pub accommodation_sub_type: String,
pub reserved_places: Vec<ReservedPlace>,
pub trip_leg_coverage: Box<TripLegCoverage>,
}Expand description
PlaceAllocation : Describes the details of the reserved place(s).
Fields
accommodation_type: StringAccommodation type definition out of the Accommodation Type Code List Listed values here are examples.
accommodation_sub_type: StringAccommodation sub type definition out of the Accommodation Sub Type Code List Listed values here are examples.
reserved_places: Vec<ReservedPlace>Reserved places in a confirmed reservation. Multiple place packs are needed to combined person and bicycle reservations
trip_leg_coverage: Box<TripLegCoverage>Implementations
Sourceimpl PlaceAllocation
impl PlaceAllocation
Sourcepub fn new(
accommodation_type: String,
accommodation_sub_type: String,
reserved_places: Vec<ReservedPlace>,
trip_leg_coverage: TripLegCoverage,
) -> PlaceAllocation
pub fn new( accommodation_type: String, accommodation_sub_type: String, reserved_places: Vec<ReservedPlace>, trip_leg_coverage: TripLegCoverage, ) -> PlaceAllocation
Describes the details of the reserved place(s).