PlacePosition

Struct PlacePosition 

pub struct PlacePosition {
    pub number: String,
    pub status: AvailabilityStatus,
    pub reservation_refs: Option<Vec<String>>,
    pub place_properties: Option<Vec<String>>,
    pub selection_fee: Option<Box<SelectionFee>>,
}
PlacePosition : description of a place

Fields

number: String

place number as indicated at the place in the coach

status: AvailabilityStatusreservation_refs: Option<Vec<String>>

references to the reservations for which this place can be selected. The reservation ids must be part of the list of reservation ids for which the consumer has requested the available places and the consumer must accept a list by setting singleSelectionMapsRequired to false

place_properties: Option<Vec<String>>selection_fee: Option<Box<SelectionFee>>

Implementations

Source

impl PlacePosition

pub fn new(number: String, status: AvailabilityStatus) -> PlacePosition

description of a place