pub struct PlacePreSelection {
pub reservation_id: Option<String>,
pub coach: String,
pub place: String,
}Expand description
PlacePreSelection : A preselected place
Fields
reservation_id: Option<String>id of the reservation in case the places have already been selected and the customer now wants to change the selection.
Deprecated: Substituted by SpecificPlaceAvailability.reservationRefs (since: 3.5.0, removed with: 4.0.0)
coach: StringCoach number
place: StringPlace number as indicated at the place in the coach
Implementations
Sourceimpl PlacePreSelection
impl PlacePreSelection
Sourcepub fn new(coach: String, place: String) -> PlacePreSelection
pub fn new(coach: String, place: String) -> PlacePreSelection
A preselected place