pub struct PlaceRestriction {
pub reservation_ref: Box<ReservationReference>,
pub service_class: Option<String>,
pub accommodation_sub_types: Option<Vec<String>>,
}Expand description
PlaceRestriction : Reservation based place selection criteria. Each requested place selection criterion will only be considered if it is covered by the referenced reservation fare/offerPart/bookingPart. E.g. place selection criterion serviceClass=HIGH will only be considered if reservationRef references a first/high class offer.
Fields
reservation_ref: Box<ReservationReference>service_class: Option<String>Type of quality level, finer grained than the comfort class. Values from the Service Class Code List Listed values here are examples.
accommodation_sub_types: Option<Vec<String>>Specifies the accommodation sub types for which place availabilities shall be returned.
Implementations
Sourceimpl PlaceRestriction
impl PlaceRestriction
Sourcepub fn new(reservation_ref: ReservationReference) -> PlaceRestriction
pub fn new(reservation_ref: ReservationReference) -> PlaceRestriction
Reservation based place selection criteria. Each requested place selection criterion will only be considered if it is covered by the referenced reservation fare/offerPart/bookingPart. E.g. place selection criterion serviceClass=HIGH will only be considered if reservationRef references a first/high class offer.