Module place_selection

Module place_selection 

Structs

PlaceSelection
PlaceSelection : Place selection options and selected options in an offer - reference place for adjacent reservation - selected optional place properties - selected places from a graphical place selection tripLegCoverage is deprecated and can be retrieved by the reservationId