pub struct PlaceSelection {
pub reservation_id: String,
pub reference_place: Option<Box<SelectedReferencePlace>>,
pub accommodations: Option<Vec<SelectedAccommodation>>,
pub places: Option<Vec<SelectedPlace>>,
pub trip_leg_coverage: Box<TripLegCoverage>,
}Expand description
PlaceSelection : Place selection options and selected options in an offer - reference place for adjacent reservation - selected optional place properties - selected places from a graphical place selection tripLegCoverage is deprecated and can be retrieved by the reservationId
Fields
reservation_id: Stringreference_place: Option<Box<SelectedReferencePlace>>accommodations: Option<Vec<SelectedAccommodation>>places: Option<Vec<SelectedPlace>>trip_leg_coverage: Box<TripLegCoverage>Implementations
Sourceimpl PlaceSelection
impl PlaceSelection
Sourcepub fn new(
reservation_id: String,
trip_leg_coverage: TripLegCoverage,
) -> PlaceSelection
pub fn new( reservation_id: String, trip_leg_coverage: TripLegCoverage, ) -> PlaceSelection
Place selection options and selected options in an offer - reference place for adjacent reservation - selected optional place properties - selected places from a graphical place selection tripLegCoverage is deprecated and can be retrieved by the reservationId