Module point_of_interest
osdm_
sys
0.1.0-alpha.1
Module point_
of_
interest
Module Items
Structs
In osdm_
sys::
models
osdm_sys
::
models
Module
point_
of_
interest
Structs

Point
OfInterest
PointOfInterest : A type of place to or through which passengers may wish to navigate as part of their journey and which is modelled in detail by journey planners. Provided by OJP.