pub struct PostalAddress {
pub country_name: Option<Option<String>>,
pub country_code: Option<String>,
pub post_code: Option<Option<String>>,
pub city: Option<Option<String>>,
pub street: Option<Option<String>>,
pub house_number: Option<Option<String>>,
}Fields
country_name: Option<Option<String>>Country of the address.
country_code: Option<String>ISO 3166-1 alpha-2 2 character country code
post_code: Option<Option<String>>Postal code of the address.
city: Option<Option<String>>City name
street: Option<Option<String>>Street name of the address. Can also contain the house number.
house_number: Option<Option<String>>House number of the address. House number can either be in this separate field, or can be contained in the street field.
Implementations
Sourceimpl PostalAddress
impl PostalAddress
pub fn new() -> PostalAddress