pub struct Problem {
pub code: Option<Option<String>>,
pub type: Option<Option<String>>,
pub title: Option<Option<String>>,
pub status: Option<Option<i32>>,
pub detail: Option<Option<String>>,
pub instance: Option<Option<String>>,
pub pointers: Option<Vec<ProblemPointer>>,
}Expand description
Problem : Problem Details for HTTP APIs (RFC 9457) defines a ‘problem detail’ as a way to carry machine-readable details of errors in a HTTP response to avoid the need to define new error response formats for HTTP APIs. See: https://tools.ietf.org/html/rfc9457
Fields
code: Option<Option<String>>optional in version 3.1, will be made mandatory in upcoming releases
type: Option<Option<String>>An absolute URI that identifies the problem type. When dereferenced, it SHOULD provide human-readable documentation for the problem type (e.g., using HTML).
title: Option<Option<String>>A short, summary of the problem type. Written in English and readable for engineers (usually not suited for non technical stakeholders and not localized);
status: Option<Option<i32>>The HTTP status code generated by the origin server for this occurrence of the problem.
detail: Option<Option<String>>A human readable explanation specific to this occurrence of the problem.
instance: Option<Option<String>>An absolute URI that identifies the specific occurrence of the problem.
pointers: Option<Vec<ProblemPointer>>