Product

Struct Product 

pub struct Product {
Show 20 fields pub id: String, pub summary: Option<Option<String>>, pub type: Option<String>, pub code: String, pub description: Option<Option<String>>, pub owner: String, pub conditions: Option<Vec<Condition>>, pub flexibility: String, pub service_class: Option<Box<ServiceClass>>, pub travel_class: Option<String>, pub fulfillment_options: Option<Vec<FulfillmentOption>>, pub is_train_bound: Option<Option<bool>>, pub is_return_product: Option<Option<bool>>, pub service_constraint_text: Option<Option<String>>, pub carrier_constraint_text: Option<Option<String>>, pub descriptive_texts: Option<Vec<TextElement>>, pub tariff: Option<Option<String>>, pub combination_tags: Option<Vec<CombinationTag>>, pub product_tags: Option<Vec<String>>, pub _links: Option<Vec<Link>>,
}
Product : Structured description of the product, its name, comfort and sales / after-sales conditions

Fields

id: String

id of the product

summary: Option<Option<String>>

A human-readable description of the product.

type: Option<String>

General product types harmonized across fare providers. (More to be added, use null for types not listed yet.) Values from the Product Type Code List Listed values here are examples.

code: String

The product code expressed in the provider system (could be a mapping from an even lower-level provider).

description: Option<Option<String>>

Textual description of the product.

owner: String

Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’

conditions: Option<Vec<Condition>>

Structured description of the sales or after-sales conditions.

flexibility: Stringservice_class: Option<Box<ServiceClass>>travel_class: Option<String>

Traditional first and second class.

fulfillment_options: Option<Vec<FulfillmentOption>>is_train_bound: Option<Option<bool>>is_return_product: Option<Option<bool>>service_constraint_text: Option<Option<String>>carrier_constraint_text: Option<Option<String>>descriptive_texts: Option<Vec<TextElement>>tariff: Option<Option<String>>

Mapping to Tariff 42 of IRS-90918-3 (Hermes/Hosa). Helps the H2O converter in mapping offers to a requested tariff. See legacyReservationParameter.tariff in OSDM offline.

combination_tags: Option<Vec<CombinationTag>>product_tags: Option<Vec<String>>

product tags associated with the product that can be used to search for offers. This can be omitted outside of the product master data service

_links: Option<Vec<Link>>

Java Property Name: ‘links’

Implementations

Source

impl Product

pub fn new( id: String, code: String, owner: String, flexibility: String, ) -> Product

Structured description of the product, its name, comfort and sales / after-sales conditions