Module product_request_offer_selection

Module product_request_offer_selection 

Structs

ProductRequestOfferSelection
ProductRequestOfferSelection : product selection by product code or product tag for an offer request (exactly one of productCode and productTag must be provided). The number of items indicates the quantity to be required. Passengers must be referenced in case the product is intended for passengers.