pub struct PromotionCode {
pub code: String,
pub issuer: Option<Option<String>>,
}Expand description
PromotionCode : The promotion code is a token that reduces the price at POST booking time OR Token that reduces the price at POST trip-offer-collection time OR Token to receive offers that are not available without it.
Fields
code: StringThe code issued by the issuer
issuer: Option<Option<String>>The party that issues the promotion code, in case of a railway it’s its RICS code
Implementations
Sourceimpl PromotionCode
impl PromotionCode
Sourcepub fn new(code: String) -> PromotionCode
pub fn new(code: String) -> PromotionCode
The promotion code is a token that reduces the price at POST booking time OR Token that reduces the price at POST trip-offer-collection time OR Token to receive offers that are not available without it.