pub struct PurchaserSearchRequest {
pub external_ref: Option<Option<String>>,
pub company_name: Option<Option<String>>,
pub company_ref: Option<String>,
pub first_name: Option<Option<String>>,
pub last_name: Option<Option<String>>,
pub date_of_birth: Option<Option<String>>,
pub phone_number: Option<Option<String>>,
pub email: Option<Option<String>>,
}Fields
external_ref: Option<Option<String>>A stable reference to a purchaser from other elements, or from caller system. When received in input of a request, it must be echoed back in the response.
company_name: Option<Option<String>>company_ref: Option<String>Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
first_name: Option<Option<String>>last_name: Option<Option<String>>date_of_birth: Option<Option<String>>phone_number: Option<Option<String>>Format according to E.164 The international public telecommunication numbering plan
email: Option<Option<String>>Implementations
Sourceimpl PurchaserSearchRequest
impl PurchaserSearchRequest
pub fn new() -> PurchaserSearchRequest