pub struct PurchaserSpecification {
pub external_ref: Option<Option<String>>,
pub detail: Option<Box<PersonDetail>>,
pub company_details: Option<Box<CompanyDetail>>,
}Expand description
PurchaserSpecification : Minimal specification of a purchaser to request booking of an offer. Exactly one of detail or companyDetails must be provided.
Fields
external_ref: Option<Option<String>>A stable reference to a purchaser from other elements, or from caller system. When received in input of a request, it must be echoed back in the response.
detail: Option<Box<PersonDetail>>company_details: Option<Box<CompanyDetail>>Implementations
Sourceimpl PurchaserSpecification
impl PurchaserSpecification
Sourcepub fn new() -> PurchaserSpecification
pub fn new() -> PurchaserSpecification
Minimal specification of a purchaser to request booking of an offer. Exactly one of detail or companyDetails must be provided.