pub struct ReductionGranted {
pub carrier: Option<String>,
pub country: Option<String>,
pub transport_modes: Option<Vec<Mode>>,
pub service_bands: Option<Vec<String>>,
pub description: Box<Text>,
pub percentage: Option<f32>,
}Expand description
ReductionGranted : reductions granted by a reduction card type. Either carrier or country must be provided.
Fields
carrier: Option<String>Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
country: Option<String>ISO 3166-1 alpha-2 2 character country code
transport_modes: Option<Vec<Mode>>transport modes where the reduction is granted, any mode of the carrier in case the list is not provided.
service_bands: Option<Vec<String>>ServiceBrands where the reduction is granted, any service brand of the carrier in case the list is not provided.
description: Box<Text>percentage: Option<f32>Implementations
Sourceimpl ReductionGranted
impl ReductionGranted
Sourcepub fn new(description: Text) -> ReductionGranted
pub fn new(description: Text) -> ReductionGranted
reductions granted by a reduction card type. Either carrier or country must be provided.