pub struct RefundOffer {Show 19 fields
pub id: String,
pub summary: Option<Option<String>>,
pub created_on: String,
pub valid_from: String,
pub valid_until: String,
pub confirmed_on: Option<Option<String>>,
pub status: RefundStatus,
pub reimbursement_status: Option<ReimbursementStatus>,
pub reimbursement_date_time: Option<Option<String>>,
pub applied_overrule_code: Option<String>,
pub fulfillments: Vec<Fulfillment>,
pub issued_fulfillments: Option<Vec<Fulfillment>>,
pub issued_vouchers: Option<Vec<VoucherInformation>>,
pub refund_fee: Box<Price>,
pub accounting_ref: Option<Box<AccountingRef>>,
pub refundable_amount: Box<Price>,
pub refund_offer_breakdown: Option<Vec<RefundOfferBreakdownItem>>,
pub reimbursement_method: Option<Box<ReimbursementMethod>>,
pub _links: Option<Vec<Link>>,
}Fields
id: Stringid of the refund offer
summary: Option<Option<String>>A human-readable description of the refund offer.
created_on: Stringvalid_from: Stringvalid_until: Stringtime until the offer can be used
confirmed_on: Option<Option<String>>status: RefundStatusreimbursement_status: Option<ReimbursementStatus>reimbursement_date_time: Option<Option<String>>applied_overrule_code: Option<String>Reason for and type of an after sale, code list in IRS 90918-10. The PRM_SUPPORT_UNAVAILABLE overrule code shall only be used by the UIC PRM ABT tool. Values from the Overrule Codes Code List Listed values here are examples. - ‘CONNECTION_BROKEN’ - ‘DEATH’ - ‘EQUIPMENT_FAILURE’ - ‘PAYMENT_FAILURE’ - ‘PRM_SUPPORT_UNAVAILABLE’ - ‘SALES_STAFF_ERROR’ - ‘STOP_NOT_SERVED’ - ‘STRIKE’ - ‘TECHNICAL_FAILURE’ - ‘TICKET_NOT_USED’ - ‘INABILITY_TO_TRAVEL’: Inability to travel due to accident or sickness. - ‘EXTERNAL_COMPENSATION’: Offer has been compensated outside of the provider system in another way. - ‘DISRUPTION’: Inability to operate due to disruption. - ‘JOURNEY_OBSOLETE’: Due to external factors it’s senseless to start the trip, thus the travel is obsolete. - ‘CERTIFIED_MEDICAL_CONDITION’: A medical certificate certifies that the passenger is unable to travel. - ‘DELAY_COMPENSATION’: Allows to override conditions in context of passenger rights regulation (PRR).
fulfillments: Vec<Fulfillment>fulfillments to be refunded or replaced
issued_fulfillments: Option<Vec<Fulfillment>>new fulfillments issued with this offer (only available after confirmation)
issued_vouchers: Option<Vec<VoucherInformation>>refund_fee: Box<Price>accounting_ref: Option<Box<AccountingRef>>refundable_amount: Box<Price>refund_offer_breakdown: Option<Vec<RefundOfferBreakdownItem>>breakdown of the refund offer
reimbursement_method: Option<Box<ReimbursementMethod>>_links: Option<Vec<Link>>Java Property Name: ‘links’
Implementations
Sourceimpl RefundOffer
impl RefundOffer
pub fn new( id: String, created_on: String, valid_from: String, valid_until: String, status: RefundStatus, fulfillments: Vec<Fulfillment>, refund_fee: Price, refundable_amount: Price, ) -> RefundOffer