pub struct RefundSpecification {
pub fulfillment_id: String,
pub booking_part_ids: Option<Vec<String>>,
pub passenger_ids: Option<Vec<String>>,
}Fields
fulfillment_id: Stringid of the fulfillment where some part(s) should be removed
booking_part_ids: Option<Vec<String>>ids of booking parts to be removed from the fulfillment
passenger_ids: Option<Vec<String>>ids of passengers to be removed from the fulfillment
Implementations
Sourceimpl RefundSpecification
impl RefundSpecification
pub fn new(fulfillment_id: String) -> RefundSpecification