Module regional_constraint

Module regional_constraint 

Structs

RegionalConstraint
RegionalConstraint : Regional constraint of the fare- offline bulk data use the id of connection points whereas in an online environment the connection point is included