ReleaseOffer

Struct ReleaseOffer 

pub struct ReleaseOffer {
    pub id: String,
    pub summary: Option<Option<String>>,
    pub created_on: String,
    pub valid_from: String,
    pub valid_until: String,
    pub confirmed_on: Option<Option<String>>,
    pub status: ReleaseStatus,
    pub fulfillments: Vec<Fulfillment>,
    pub applied_overrule_code: Option<String>,
    pub _links: Option<Vec<Link>>,
}

Fields

id: String

id of the release offer

summary: Option<Option<String>>

A human-readable description of the refund offer.

created_on: Stringvalid_from: Stringvalid_until: String

time until the offer can be used

confirmed_on: Option<Option<String>>status: ReleaseStatusfulfillments: Vec<Fulfillment>applied_overrule_code: Option<String>

Reason for and type of an after sale, code list in IRS 90918-10. The PRM_SUPPORT_UNAVAILABLE overrule code shall only be used by the UIC PRM ABT tool. Values from the Overrule Codes Code List Listed values here are examples. - ‘CONNECTION_BROKEN’ - ‘DEATH’ - ‘EQUIPMENT_FAILURE’ - ‘PAYMENT_FAILURE’ - ‘PRM_SUPPORT_UNAVAILABLE’ - ‘SALES_STAFF_ERROR’ - ‘STOP_NOT_SERVED’ - ‘STRIKE’ - ‘TECHNICAL_FAILURE’ - ‘TICKET_NOT_USED’ - ‘INABILITY_TO_TRAVEL’: Inability to travel due to accident or sickness. - ‘EXTERNAL_COMPENSATION’: Offer has been compensated outside of the provider system in another way. - ‘DISRUPTION’: Inability to operate due to disruption. - ‘JOURNEY_OBSOLETE’: Due to external factors it’s senseless to start the trip, thus the travel is obsolete. - ‘CERTIFIED_MEDICAL_CONDITION’: A medical certificate certifies that the passenger is unable to travel. - ‘DELAY_COMPENSATION’: Allows to override conditions in context of passenger rights regulation (PRR).

_links: Option<Vec<Link>>

Java Property Name: ‘links’

Implementations

Source

impl ReleaseOffer

pub fn new( id: String, created_on: String, valid_from: String, valid_until: String, status: ReleaseStatus, fulfillments: Vec<Fulfillment>, ) -> ReleaseOffer