Reservation

Struct Reservation 

pub struct Reservation {
Show 41 fields pub object_type: String, pub id: String, pub summary: Option<Option<String>>, pub created_on: String, pub confirmable_until: Option<String>, pub valid_from: String, pub valid_until: Option<Option<String>>, pub confirmed_on: Option<Option<String>>, pub confirmed_fulfillment_options: Option<Box<FulfillmentOption>>, pub price: Box<Price>, pub refund_amount: Option<Box<Price>>, pub trip_coverage: Option<Box<TripCoverage>>, pub inbound_trip_coverage: Option<Box<TripCoverage>>, pub summary_product_id: Option<String>, pub products: Option<Vec<ProductLegAssociation>>, pub status: BookingPartStatus, pub pricing_status: Option<String>, pub offer_mode: Option<OfferMode>, pub booking_part_code: Option<String>, pub distributor_booking_ref: Option<Option<String>>, pub retailer_booking_ref: Option<Option<String>>, pub passenger_ids: Vec<String>, pub available_fulfillment_options: Option<Vec<FulfillmentOption>>, pub refundable: RefundType, pub exchangeable: ExchangeableType, pub after_sale_conditions: Option<Vec<AfterSaleCondition>>, pub after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>, pub applied_corporate_codes: Option<Vec<CorporateCode>>, pub applied_passenger_types: Option<Vec<AppliedPassengerType>>, pub applied_promotion_codes: Option<Vec<PromotionCode>>, pub applied_reductions: Option<Vec<CardReference>>, pub indicated_consumption: Option<Box<IndicatedConsumption>>, pub accounting_ref: Option<Box<AccountingRef>>, pub granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>, pub place_selection: Option<Box<PlaceSelection>>, pub place_allocation: Option<Box<PlaceAllocation>>, pub fee_refs: Option<Vec<BookingPartReference>>, pub ancillary_refs: Option<Vec<BookingPartReference>>, pub available_place_preferences: Option<Vec<AvailablePlacePreferences>>, pub graphical_reservation_supported: Option<Option<bool>>, pub supported_place_selection_flows: Option<Vec<String>>,
}
Reservation : Reservation includes the reference to the in the initial offer. The offer needs to be updated with the selected places before the confirmation which creates the reservation details including the reserved places.

Fields

object_type: String

Attribute is used as discriminator for inheritance between data types.

id: Stringsummary: Option<Option<String>>created_on: String

Validity of offer towards passenger

confirmable_until: Option<String>

confirmationTimeLimit in booking should be used. Date until the booking part needs to be confirmed. Must be provided for a booking part in PREBOOKED stated. For later states, the value is ignored and can be null.

valid_from: Stringvalid_until: Option<Option<String>>

Validity of offer towards passenger

confirmed_on: Option<Option<String>>confirmed_fulfillment_options: Option<Box<FulfillmentOption>>price: Box<Price>refund_amount: Option<Box<Price>>trip_coverage: Option<Box<TripCoverage>>inbound_trip_coverage: Option<Box<TripCoverage>>summary_product_id: Option<String>

Id of the product representing the commercial attributes of this booking part. Although not currently mandatory, this attribute should in all cases be filled in order to allow matching a booking response to the data in the booking request

products: Option<Vec<ProductLegAssociation>>

In offer mode, in almost all cases exactly one product is referenced. Only on some French trips consisting of a TGV and a TER two products need to be used. In fare mode, no product exists as first needs to created from the different fares.

status: BookingPartStatuspricing_status: Option<String>

payment status in post-payment scenarios

offer_mode: Option<OfferMode>booking_part_code: Option<String>

The unique booking code for the part in the provider system.

distributor_booking_ref: Option<Option<String>>

reference to the booking in the downstream distributor system

retailer_booking_ref: Option<Option<String>>

reference to the booking in the downstream distributor system

passenger_ids: Vec<String>

Id of the passenger

available_fulfillment_options: Option<Vec<FulfillmentOption>>refundable: RefundTypeexchangeable: ExchangeableTypeafter_sale_conditions: Option<Vec<AfterSaleCondition>>

Fine grained specification of the after sale condition of the booking.

after_sales_override_details: Option<Box<AfterSalesOverrideDetails>>applied_corporate_codes: Option<Vec<CorporateCode>>applied_passenger_types: Option<Vec<AppliedPassengerType>>applied_promotion_codes: Option<Vec<PromotionCode>>applied_reductions: Option<Vec<CardReference>>indicated_consumption: Option<Box<IndicatedConsumption>>accounting_ref: Option<Box<AccountingRef>>granted_reduction_amounts: Option<Box<GrantedReductionAmounts>>place_selection: Option<Box<PlaceSelection>>place_allocation: Option<Box<PlaceAllocation>>fee_refs: Option<Vec<BookingPartReference>>ancillary_refs: Option<Vec<BookingPartReference>>

DEPRECATED Formerly OSDM allowed to link ancillaries to reservation. Since 3.7.0, it is recommended to only link reservations to admissions, ancillaries, and not the other way round. Referrence will be removed in 4.0.0

available_place_preferences: Option<Vec<AvailablePlacePreferences>>

options for place selection in case the place selection is made after the pre-booking.

graphical_reservation_supported: Option<Option<bool>>

more detailed information on options for place selection and possible fees are part of availablePlacePreferences

supported_place_selection_flows: Option<Vec<String>>

Supported place selection flows might depend on available places.

Implementations

Source

impl Reservation

pub fn new( object_type: String, id: String, created_on: String, valid_from: String, price: Price, status: BookingPartStatus, passenger_ids: Vec<String>, refundable: RefundType, exchangeable: ExchangeableType, ) -> Reservation

Reservation includes the reference to the in the initial offer. The offer needs to be updated with the selected places before the confirmation which creates the reservation details including the reserved places.