pub struct ReturnConstraint {
pub latest_return: i32,
pub earliest_return: i32,
pub excluded_weekdays: Option<Option<Vec<i32>>>,
}Expand description
ReturnConstraint : a return trip with the same carrier must be sold in combination
Fields
latest_return: i32number of days after departure or start of validity of the last return
earliest_return: i32number of days after departure or start of validity of the earliest return
excluded_weekdays: Option<Option<Vec<i32>>>weekdays (ISO day of the week, 1 = Monday) between travel and return where travel is not allowed
Implementations
Sourceimpl ReturnConstraint
impl ReturnConstraint
Sourcepub fn new(latest_return: i32, earliest_return: i32) -> ReturnConstraint
pub fn new(latest_return: i32, earliest_return: i32) -> ReturnConstraint
a return trip with the same carrier must be sold in combination