pub struct RouteItem {
pub alternative_route_item_indices: Option<Option<Vec<i32>>>,
pub carrier_constraint: Option<Box<CarrierConstraint>>,
pub route_item_indices: Option<Option<Vec<i32>>>,
pub service_constraint: Option<Box<ServiceConstraint>>,
pub station: Option<Box<StopPlace>>,
pub fare_reference_station: Option<Box<FareReferenceStation>>,
}Expand description
RouteItem : Items to compose routes (Note - replaced viaStation, content compliant with viaStation in IRS 90918-4 and 90918-9)
Fields
alternative_route_item_indices: Option<Option<Vec<i32>>>list of alternative route parts to be used on this travel path referenced by the index in the provided list of route items
carrier_constraint: Option<Box<CarrierConstraint>>route_item_indices: Option<Option<Vec<i32>>>sequence of route items along the travel path referenced by the index in the provided list of route items
service_constraint: Option<Box<ServiceConstraint>>station: Option<Box<StopPlace>>fare_reference_station: Option<Box<FareReferenceStation>>Implementations