pub struct Section {
pub start_place: Option<Box<PlaceRef>>,
pub start_leg_id: Option<Option<String>>,
pub end_place: Option<Box<PlaceRef>>,
pub end_leg_id: Option<Option<String>>,
pub external_trip_ref: Option<Option<String>>,
}Expand description
Section : Allows to indicate the sub-part of the trip. LegIds are only relevant if a trip can be referenced. When absent, the totality of the trip is priced.
Fields
start_place: Option<Box<PlaceRef>>start_leg_id: Option<Option<String>>end_place: Option<Box<PlaceRef>>end_leg_id: Option<Option<String>>external_trip_ref: Option<Option<String>>reference to a trip in case multiple trips are provided
Implementations