pub struct SelectionFee {
pub price: Box<Price>,
}Expand description
SelectionFee : selection fee that will be applied when selecting the place in a graphical seat map. (https://osdm.io/spec/processes/#SeatSelectionFees)
Fields
price: Box<Price>Implementations
Sourceimpl SelectionFee
impl SelectionFee
Sourcepub fn new(price: Price) -> SelectionFee
pub fn new(price: Price) -> SelectionFee
selection fee that will be applied when selecting the place in a graphical seat map. (https://osdm.io/spec/processes/#SeatSelectionFees)