pub struct ServiceConstraint {
pub restricted_to_service_brands: Option<Vec<String>>,
pub excluded_service_brands: Option<Vec<String>>,
pub description: Option<Box<Text>>,
}Expand description
ServiceConstraint : Either excluded or included service brands can be set.
Fields
restricted_to_service_brands: Option<Vec<String>>excluded_service_brands: Option<Vec<String>>description: Option<Box<Text>>Implementations
Sourceimpl ServiceConstraint
impl ServiceConstraint
Sourcepub fn new() -> ServiceConstraint
pub fn new() -> ServiceConstraint
Either excluded or included service brands can be set.