pub struct ServiceTime {
pub timetabled_time: String,
pub estimated_time: Option<Option<String>>,
pub observed_time: Option<Option<String>>,
}Expand description
ServiceTime : The time needs to be in Offset Time Format, i.e. 2023-12-03T10:15:30+01:00 as it is important the time zones are important to show in the timetable. Do not use the Coordinated Universal Time (UTC) format, i.e. 2023-12-03T10:15:30Z.
Fields
timetabled_time: Stringestimated_time: Option<Option<String>>observed_time: Option<Option<String>>Implementations
Sourceimpl ServiceTime
impl ServiceTime
Sourcepub fn new(timetabled_time: String) -> ServiceTime
pub fn new(timetabled_time: String) -> ServiceTime
The time needs to be in Offset Time Format, i.e. 2023-12-03T10:15:30+01:00 as it is important the time zones are important to show in the timetable. Do not use the Coordinated Universal Time (UTC) format, i.e. 2023-12-03T10:15:30Z.