pub struct SpecificPlaceAvailability {
pub number: String,
pub status: AvailabilityStatus,
pub reservation_refs: Vec<ReservationReference>,
pub selection_fee: Option<Box<SelectionFee>>,
}Expand description
SpecificPlaceAvailability : Availability status of a specific place.
Fields
number: StringPlace number as indicated at the place in the coach.
status: AvailabilityStatusreservation_refs: Vec<ReservationReference>References requested reservation fares/offerParts/bookingParts that allow the selection of the place. This allows clients to link place availabilities with the corresponding reservation fare/offerPart/bookingPart. E.g. link a bicycle hook with a bicycle reservationOfferPart.
selection_fee: Option<Box<SelectionFee>>Implementations
Sourceimpl SpecificPlaceAvailability
impl SpecificPlaceAvailability
Sourcepub fn new(
number: String,
status: AvailabilityStatus,
reservation_refs: Vec<ReservationReference>,
) -> SpecificPlaceAvailability
pub fn new( number: String, status: AvailabilityStatus, reservation_refs: Vec<ReservationReference>, ) -> SpecificPlaceAvailability
Availability status of a specific place.