StopCallStatus

Struct StopCallStatus 

pub struct StopCallStatus {
    pub order: Option<Option<i32>>,
    pub request_stop: Option<Option<bool>>,
    pub unplanned_stop: Option<Option<bool>>,
    pub not_serviced_stop: Option<Option<bool>>,
    pub no_boarding_at_stop: Option<Option<bool>>,
    pub no_alighting_at_stop: Option<Option<bool>>,
    pub is_border_point: Option<Option<bool>>,
}
StopCallStatus : Status properties for the vehicle call at this stop. Provided by OJP.

Fields

order: Option<Option<i32>>

Sequence number of this stop in the service pattern of the journey.

request_stop: Option<Option<bool>>

The vehicle journey calls at this stop only on demand.

unplanned_stop: Option<Option<bool>>

This stop has not been planned by the planning department.

not_serviced_stop: Option<Option<bool>>

The vehicle will not call at this stop despite earlier planning.

no_boarding_at_stop: Option<Option<bool>>

Boarding will not be allowed at this stop of this journey.

no_alighting_at_stop: Option<Option<bool>>

Alighting will not be allowed at this stop of this journey.

is_border_point: Option<Option<bool>>

Indicates whether the stop is recognized by the system as a border point between two or more countries.

Implementations

Source

impl StopCallStatus

pub fn new() -> StopCallStatus

Status properties for the vehicle call at this stop. Provided by OJP.