pub struct TextElement {
pub description: String,
pub short_description: String,
pub text_element_type: TextElementType,
}Expand description
TextElement : Additional texts which should be displayed to the customer to further describe the product being offered.
Fields
description: StringFull version of the text for display when sufficient space is available.
short_description: StringBrief version of the text for display in space restricted environments, e.g. mobile phone. No longer than 64 characters.
text_element_type: TextElementTypeImplementations
Sourceimpl TextElement
impl TextElement
Sourcepub fn new(
description: String,
short_description: String,
text_element_type: TextElementType,
) -> TextElement
pub fn new( description: String, short_description: String, text_element_type: TextElementType, ) -> TextElement
Additional texts which should be displayed to the customer to further describe the product being offered.