pub struct Tip {
pub id: String,
pub summary: Option<String>,
pub booking_part_ref: Option<Box<BookingPartReference>>,
pub price: Box<Price>,
pub distributor_booking_ref: Option<Option<String>>,
pub accounting_ref: Option<Box<AccountingRef>>,
}Expand description
Tip : Tips for staff can be included e.g. for taxi drivers. The tip is part of the payment in a post payment scenario.
Fields
id: Stringsummary: Option<String>A human-readable description of the tip.
booking_part_ref: Option<Box<BookingPartReference>>price: Box<Price>distributor_booking_ref: Option<Option<String>>reference to the booking in the downstream distributor system
accounting_ref: Option<Box<AccountingRef>>Implementations