pub struct TrainLink {
pub from_station: Box<StopPlaceRef>,
pub to_station: Box<StopPlaceRef>,
pub train: String,
pub travel_date: String,
pub service_brand_code: Option<String>,
pub service_brand_abbreviation: String,
}Fields
from_station: Box<StopPlaceRef>to_station: Box<StopPlaceRef>train: Stringtravel_date: Stringdate and time of the departure where the train link starts
service_brand_code: Option<String>Service brand codes. For public transport, a code list can be found in OSDM’s code list. E.g., ‘163’ denotes TGV Lyria and ‘175’ denotes Glacier Express.
service_brand_abbreviation: StringAbbreviation of the service brand, e.g. ‘IC’, ‘TGV’. See the OSDM code list. Needs to match the service brand code.
Implementations