pub struct TransferLeg {
pub continuous_mode: Option<String>,
pub transfer_mode: Option<String>,
pub start: Box<PlaceRef>,
pub end: Box<PlaceRef>,
pub time_window_start: Option<Option<String>>,
pub time_window_end: Option<Option<String>>,
pub duration: Option<Option<String>>,
pub situation_full_refs: Option<Vec<String>>,
pub co2_emission: Option<Box<Quantity>>,
}Expand description
TransferLeg : A leg which links other legs of a trip where a transfer between different places is required. Provided by OJP.
Fields
continuous_mode: Option<String>Types of modes that run at any time without a timetable. Provided by OJP.
transfer_mode: Option<String>Modes dedicated to perform transfers. Provided by OJP.
start: Box<PlaceRef>end: Box<PlaceRef>time_window_start: Option<Option<String>>Time at which window begins.
time_window_end: Option<Option<String>>Time at which window ends.
duration: Option<Option<String>>Overall duration of this interchange.
situation_full_refs: Option<Vec<String>>co2_emission: Option<Box<Quantity>>Implementations
Sourceimpl TransferLeg
impl TransferLeg
Sourcepub fn new(start: PlaceRef, end: PlaceRef) -> TransferLeg
pub fn new(start: PlaceRef, end: PlaceRef) -> TransferLeg
A leg which links other legs of a trip where a transfer between different places is required. Provided by OJP.