pub struct Transportable {
pub type: String,
pub car: Option<Box<Car>>,
pub motor_cycle: Option<Box<MotorCycle>>,
pub trailer: Option<Box<Car>>,
}Expand description
Transportable : Transportables which are handled similar to passengers like dogs, bicycles, car transport. These transportables might need a ticket or reservation.
Fields
type: StringSubset of the values from the Passenger Type Code List Listed values here are examples.
car: Option<Box<Car>>motor_cycle: Option<Box<MotorCycle>>trailer: Option<Box<Car>>Implementations
Sourceimpl Transportable
impl Transportable
Sourcepub fn new(type: String) -> Transportable
pub fn new(type: String) -> Transportable
Transportables which are handled similar to passengers like dogs, bicycles, car transport. These transportables might need a ticket or reservation.