pub struct TransportableSpecification {
pub type: String,
pub car: Option<Box<CarSpecification>>,
pub motorcycle: Option<Box<MotorcycleSpecification>>,
pub trailer: Option<Box<CarSpecification>>,
}Expand description
TransportableSpecification : Transportables which are handled similar to passengers like dogs, bicycles, car transport. These transportables might need a ticket or reservation. The Transportable specification does not include personal data (e.g. a license plate.)
Fields
type: StringSubset of the values from the Passenger Type Code List Listed values here are examples.
car: Option<Box<CarSpecification>>motorcycle: Option<Box<MotorcycleSpecification>>trailer: Option<Box<CarSpecification>>Implementations
Sourceimpl TransportableSpecification
impl TransportableSpecification
Sourcepub fn new(type: String) -> TransportableSpecification
pub fn new(type: String) -> TransportableSpecification
Transportables which are handled similar to passengers like dogs, bicycles, car transport. These transportables might need a ticket or reservation. The Transportable specification does not include personal data (e.g. a license plate.)