TravelValidity

Struct TravelValidity 

pub struct TravelValidity {
    pub valid_travel_dates: Option<Box<Calendar>>,
    pub validity_range: Box<ValidityRange>,
    pub excluded_time_ranges: Option<Vec<ExcludedTimeRange>>,
    pub number_of_travel_days: Option<Option<i32>>,
    pub return_constraint: Option<Box<ReturnConstraint>>,
    pub train_validity: Option<Box<TrainValidity>>,
    pub validity_type: Option<String>,
    pub trip_allocation_constraint: Option<Box<TripAllocationConstraint>>,
    pub trip_interruption_constraint: Option<Box<TripInterruptionConstraint>>,
}
TravelValidity : In distributor mode, travel validity data is needed to create barcode and control data (IRS 90918-4) even in case they have been checked during the on-line sale.

Fields

valid_travel_dates: Option<Box<Calendar>>validity_range: Box<ValidityRange>excluded_time_ranges: Option<Vec<ExcludedTimeRange>>

time ranges excluded from the validity (e.g. off peak fulfillments)

number_of_travel_days: Option<Option<i32>>

number of allowed travel days (e.g. 3 travel days within 2 weeks)

return_constraint: Option<Box<ReturnConstraint>>train_validity: Option<Box<TrainValidity>>validity_type: Option<String>

Type of usage, either as single trip or multiple trips. Unrestricted fares might be combined into single trips if appropriate. Values from the Travel Validity Type Code List Values from the Tavel Validity Type Code List Listed values here are examples.

trip_allocation_constraint: Option<Box<TripAllocationConstraint>>trip_interruption_constraint: Option<Box<TripInterruptionConstraint>>

Implementations

Source

impl TravelValidity

pub fn new(validity_range: ValidityRange) -> TravelValidity

In distributor mode, travel validity data is needed to create barcode and control data (IRS 90918-4) even in case they have been checked during the on-line sale.