Module travel_validity_range
osdm_
sys
0.1.0-alpha.1
Module travel_
validity_
range
Module Items
Structs
In osdm_
sys::
models
osdm_sys
::
models
Module
travel_
validity_
range
Structs

Travel
Validity
Range
TravelValidityRange : Range for the start of validity to be used in a patch for available fulfillments (e.g. a 1 hour ticket not available during peak hours in the morning and afternoon).