TripAllocationConstraint

Struct TripAllocationConstraint 

pub struct TripAllocationConstraint {
    pub allocation_unit: String,
    pub max_units: Option<Option<i32>>,
    pub duration_unit: Option<Option<String>>,
    pub required_processes: Vec<String>,
}
TripAllocationConstraint : constraint on the use of a multiple trip ticket

Fields

allocation_unit: String

Values from the Trip Allocation Unit Code List Unit to allocate trips in a multi-trip fare. Trips can be allocated per day (e.g. Eurail) or per duration (e.g. multiples of a duration unit to cover the trip) or as single trips (e.g. carnet)) Known Values: - NONE: Individual trips don’t need to be allocated. - TRIP: allocation per individual trip. - DAY: The allocation is per travel day. - DURATION: the allocation is per duration.

max_units: Option<Option<i32>>

maximum number of allowed units to be allocated

duration_unit: Option<Option<String>>

multiples of this duration can be allocated

required_processes: Vec<String>

one of the listed processes is required for the allocation of a single trip

Implementations

Source

impl TripAllocationConstraint

pub fn new( allocation_unit: String, required_processes: Vec<String>, ) -> TripAllocationConstraint

constraint on the use of a multiple trip ticket