TripCoverage

Struct TripCoverage 

pub struct TripCoverage {
    pub covered_trip_id: String,
    pub section_index: Option<Option<i32>>,
    pub covered_leg_ids: Option<Option<Vec<String>>>,
    pub covered_sections: Option<Vec<Section>>,
}
TripCoverage : The trip coverage defines which part of the trip is covered by the offer, offer part, booking or booking part, respectively. If neither coveredLegIds nor coveredSections are defined, the complete trip is covered. coveredLegIds and coveredSections are mutually exclusive, i.e. only one of the structures can be present. If either coveredLegIds or coveredSections is defined, the sectionIndex field must be filled to indicate which part of the trip is covered by the respective OfferPart or BookingPart

Fields

covered_trip_id: Stringsection_index: Option<Option<i32>>

Describes which part of the trip (in order) is covered by the OfferPart/BookingPart which contains this TripCoverage structure. This needs to be filled if either coveredLegIds or coveredSections is present.

covered_leg_ids: Option<Option<Vec<String>>>

Indicate which legs are covered by the specific offer. Not used for fares.

covered_sections: Option<Vec<Section>>

Implementations

Source

impl TripCoverage

pub fn new(covered_trip_id: String) -> TripCoverage

The trip coverage defines which part of the trip is covered by the offer, offer part, booking or booking part, respectively. If neither coveredLegIds nor coveredSections are defined, the complete trip is covered. coveredLegIds and coveredSections are mutually exclusive, i.e. only one of the structures can be present. If either coveredLegIds or coveredSections is defined, the sectionIndex field must be filled to indicate which part of the trip is covered by the respective OfferPart or BookingPart