pub struct TripInterruptionConstraint {
pub max_interruptions: i32,
pub max_duration: Option<Option<String>>,
pub total_max_duration: Option<Option<String>>,
pub required_processes: Vec<String>,
}Expand description
TripInterruptionConstraint : rules on allowed trip interruptions. Interruptions due to a train change indicated by a trip search must not be included here.
Fields
max_interruptions: i32maximum number of allowed interruptions
max_duration: Option<Option<String>>maximum duration of one interruption
total_max_duration: Option<Option<String>>maximum duration of all interruptions on the route
required_processes: Vec<String>one of the listed processes is required for the interruption of the trip
Implementations