Module trip_parameters
osdm_
sys
0.1.0-alpha.1
Module trip_
parameters
Module Items
Structs
In osdm_
sys::
models
osdm_sys
::
models
Module
trip_
parameters
Structs

Trip
Parameters
TripParameters : Options to control the search behavior and response contents. number of results > either number of results or number of results before and after are used. Provided by OJP.