TripParameters

Struct TripParameters 

pub struct TripParameters {
    pub data_filter: Option<Box<TripDataFilter>>,
    pub policy_filter: Option<Box<BaseTripPolicyFilter>>,
    pub mobility_filter: Option<Box<TripMobilityFilter>>,
    pub number_of_results: Option<Option<i32>>,
    pub number_of_results_before: Option<Option<i32>>,
    pub number_of_results_after: Option<Option<i32>>,
    pub ignore_realtime_data: Option<Option<bool>>,
    pub transfer_limit: Option<Option<i32>>,
    pub it_modes_to_cover: Option<String>,
}
TripParameters : Options to control the search behavior and response contents. number of results > either number of results or number of results before and after are used. Provided by OJP.

Fields

data_filter: Option<Box<TripDataFilter>>policy_filter: Option<Box<BaseTripPolicyFilter>>mobility_filter: Option<Box<TripMobilityFilter>>number_of_results: Option<Option<i32>>

Deprecated in 3.7.0 as it is getting removed in OJP to avoid inconsistency.

number_of_results_before: Option<Option<i32>>number_of_results_after: Option<Option<i32>>ignore_realtime_data: Option<Option<bool>>transfer_limit: Option<Option<i32>>

The maximum number of interchanges the user will accept per trip.

it_modes_to_cover: Option<String>

Modes which an individual powers themselves (such as walk, cycle). Provided by OJP.

Implementations

Source

impl TripParameters

pub fn new() -> TripParameters

Options to control the search behavior and response contents. number of results > either number of results or number of results before and after are used. Provided by OJP.