Module trip_specification_summary

Module trip_specification_summary 

Structs

TripSpecificationSummary
TripSpecificationSummary : Trip specification summary. Provided by OJP. It requires the id of an already existing trip to change and specifies the parameters which must be used to generate the new trip.