pub struct TripSpecificationSummary {
pub id: String,
pub origin: Option<Box<PlaceRef>>,
pub destination: Option<Box<PlaceRef>>,
}Expand description
TripSpecificationSummary : Trip specification summary. Provided by OJP. It requires the id of an already existing trip to change and specifies the parameters which must be used to generate the new trip.
Fields
id: StringThe id of an already existing trip to change.
origin: Option<Box<PlaceRef>>destination: Option<Box<PlaceRef>>Implementations
Sourceimpl TripSpecificationSummary
impl TripSpecificationSummary
Sourcepub fn new(id: String) -> TripSpecificationSummary
pub fn new(id: String) -> TripSpecificationSummary
Trip specification summary. Provided by OJP. It requires the id of an already existing trip to change and specifies the parameters which must be used to generate the new trip.