pub struct Vehicle {
pub coaches: Option<Vec<Coach>>,
pub reservation_refs: Option<Vec<String>>,
}Expand description
Vehicle : List of the coaches in a vehicle run ordered according to the physical ordering of the vehicle.
Fields
coaches: Option<Vec<Coach>>reservation_refs: Option<Vec<String>>References to the reservations/fares for which all places in the vehicle can be selected. The reservation ids must be part of the list of reservation ids for which the consumer has requested the available places and the consumer must accept a list by setting singleSelectionMapsRequired to false
Implementations