pub struct Warning {
pub code: String,
pub type: Option<Option<String>>,
pub detail: Option<Option<String>>,
pub instance: Option<Option<String>>,
}Expand description
Warning : This element can be used to pass non-blocking information or events, such as a price difference with the initially offered price at booking time. It is inspired on the JSon problem structure. This structure has been deprecated and is replaced by the Problem structure.
Fields
code: Stringtype: Option<Option<String>>An absolute URI that identifies the warning type. When dereferenced, it SHOULD provide human-readable documentation for the problem type (e.g., using HTML).
detail: Option<Option<String>>A human readable explanation specific to this occurrence of the warning.
instance: Option<Option<String>>An absolute URI that identifies the specific occurrence of the warning.
Implementations
Sourceimpl Warning
impl Warning
Sourcepub fn new(code: String) -> Warning
pub fn new(code: String) -> Warning
This element can be used to pass non-blocking information or events, such as a price difference with the initially offered price at booking time. It is inspired on the JSon problem structure. This structure has been deprecated and is replaced by the Problem structure.