pub struct WarningCollection {
pub warnings: Vec<Warning>,
}Expand description
WarningCollection : List of warnings. This structure has been deprecated and replaced by the problems array.
Fields
warnings: Vec<Warning>Implementations
Sourceimpl WarningCollection
impl WarningCollection
Sourcepub fn new(warnings: Vec<Warning>) -> WarningCollection
pub fn new(warnings: Vec<Warning>) -> WarningCollection
List of warnings. This structure has been deprecated and replaced by the problems array.