pub struct Zone {
pub binary_zone_id: Option<Option<Vec<u8>>>,
pub carrier: Option<String>,
pub name: Option<Option<String>>,
pub entry_station: Option<Box<StopPlace>>,
pub terminal_station: Option<Box<StopPlace>>,
pub zone_ids: Option<Option<Vec<i32>>>,
pub nuts_code: Option<Option<String>>,
pub valid_from: Option<Option<String>>,
pub valid_until: Option<Option<String>>,
}Expand description
Zone : carrier - carrier responsible for the transport. entryStation - Station to enter the zone in case the product requires to enter the zone via a specific station (e.g. local zone ticket to start from the main rail station). terminalStation - Terminal station in case the product requires a destination within the zone (e.g. local ticket to go to the main rail station).
Fields
binary_zone_id: Option<Option<Vec<u8>>>Id to support local traffic standards (e.g. VDV,…)
carrier: Option<String>Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
name: Option<Option<String>>entry_station: Option<Box<StopPlace>>terminal_station: Option<Box<StopPlace>>zone_ids: Option<Option<Vec<i32>>>to be used in bar codes
nuts_code: Option<Option<String>>Nomenclature des units territoriales statistiques COMMISSION REGULATION (EU) No 31/2011
valid_from: Option<Option<String>>valid_until: Option<Option<String>>Implementations
Sourceimpl Zone
impl Zone
Sourcepub fn new() -> Zone
pub fn new() -> Zone
carrier - carrier responsible for the transport. entryStation - Station to enter the zone in case the product requires to enter the zone via a specific station (e.g. local zone ticket to start from the main rail station). terminalStation - Terminal station in case the product requires a destination within the zone (e.g. local ticket to go to the main rail station).