pub struct ZoneDefinition {
pub id: String,
pub name: Option<Option<String>>,
pub carrier: String,
pub polygon: Option<Box<Polygon>>,
pub nuts_codes: Option<Option<Vec<String>>>,
pub places: Option<Vec<PlaceRef>>,
}Expand description
ZoneDefinition : Definition of a zone used to define regional validity. The area of the zone can be defined via a geo-polygon, a complete list of all contained stations or area codes from the NUTS code list. The carrier is either the carrier or transport authority responsible for the definition.
Fields
id: Stringname: Option<Option<String>>carrier: StringIdentifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
polygon: Option<Box<Polygon>>nuts_codes: Option<Option<Vec<String>>>places: Option<Vec<PlaceRef>>Implementations
Sourceimpl ZoneDefinition
impl ZoneDefinition
Sourcepub fn new(id: String, carrier: String) -> ZoneDefinition
pub fn new(id: String, carrier: String) -> ZoneDefinition
Definition of a zone used to define regional validity. The area of the zone can be defined via a geo-polygon, a complete list of all contained stations or area codes from the NUTS code list. The carrier is either the carrier or transport authority responsible for the definition.