Enums
- Split
Bookings Error - struct for typed errors of method
split_bookings
Functions
- split_
bookings - Splits a booking into a set of bookings according to the defined groups of a passenger(s). Only possible if allowed by the underlying tariff, if the bookedOffers are sufficiently partitioned and no pricing is needed.