pub async fn split_bookings(
configuration: &Configuration,
booking_id: &str,
booking_split_request: BookingSplitRequest,
requestor: Option<&str>,
accept_language: Option<&str>,
traceparent: Option<&str>,
tracestate: Option<&str>,
idempotency_key: Option<&str>,
) -> Result<BookingSplitResponse, Error<SplitBookingsError>>Expand description
Splits a booking into a set of bookings according to the defined groups of a passenger(s). Only possible if allowed by the underlying tariff, if the bookedOffers are sufficiently partitioned and no pricing is needed.