Enums
- Create
Bookings Exchange Operations Error - struct for typed errors of method
create_bookings_exchange_operations - Create
Exchange Offers Collection Error - struct for typed errors of method
create_exchange_offers_collection - Delete
Bookings Exchange Operation Error - struct for typed errors of method
delete_bookings_exchange_operation - GetBookings
Exchange Operations Error - struct for typed errors of method
get_bookings_exchange_operations - Update
Bookings Exchange Operations Error - struct for typed errors of method
update_bookings_exchange_operations
Functions
- create_
bookings_ exchange_ operations - create_
exchange_ offers_ collection - Returns exchange offers for specified fulfillments submitted given requested new trip characteristics.
- delete_
bookings_ exchange_ operation - get_
bookings_ exchange_ operations - Returns the exchange operation with the id provided. It may be a provisional or a confirmed exchange.
- update_
bookings_ exchange_ operations