Enums
- GetCoach
Deck Layout Error - struct for typed errors of method
get_coach_deck_layout - GetCoach
Deck Layouts Error - struct for typed errors of method
get_coach_deck_layouts - GetCoach
Layouts Error - struct for typed errors of method
get_coach_layouts - GetCoach
Layouts Layout IdError - struct for typed errors of method
get_coach_layouts_layout_id - GetPassenger
Categories Error - struct for typed errors of method
get_passenger_categories - GetPlaces
Error - struct for typed errors of method
get_places - GetProduct
Tags Error - struct for typed errors of method
get_product_tags - GetProducts
Error - struct for typed errors of method
get_products - GetProducts
IdError - struct for typed errors of method
get_products_id - GetReduction
Cards Error - struct for typed errors of method
get_reduction_cards - GetZones
Error - struct for typed errors of method
get_zones
Functions
- get_
coach_ deck_ layout - Retrieve a coach layout description needed for graphical reservation for a given layout id.
- get_
coach_ deck_ layouts - Retrieve the coach layout description needed for graphical reservation. The coach layouts can either be retrieved as a complete list or specificity for a train identified via offerId and reservationId or fareId
- get_
coach_ layouts Deprecated - Retrieve the coach layout description needed for graphical reservation. The coach layouts can either be retrieved as a complete list or specificity for a train identified via offerId and reservationId or fareId.
Deprecated: Substituted by getCoachDeckLayouts (since: 3.5.0, removed with: 4.0.0) - get_
coach_ layouts_ layout_ id Deprecated - Retrieve a coach layout description needed for graphical reservation for a given layout id.
Deprecated: Substituted by getCoachDeckLayout (since: 3.5.0, removed with: 4.0.0) - get_
passenger_ categories - Provider may optionally define passenger categories. These are usually intended for frontend (UI) usage instead of full passenger specification entry when provider works with unified list of passenger categories. For precise entry, or when PassengerCategory is not defined, the full passenger specification must always be supported by the provider.
- get_
places - get_
product_ tags - get_
products - get_
products_ id - get_
reduction_ cards - returns a collection of reduction card definitions
- get_
zones