Enums
- Delete
Refund Offers Error - struct for typed errors of method
delete_refund_offers - GetRefund
Offers Error - struct for typed errors of method
get_refund_offers - Patch
Refund Offers Error - struct for typed errors of method
patch_refund_offers - Post
Prepare Refund Offers Error - struct for typed errors of method
post_prepare_refund_offers - Post
Refund Offers Error - struct for typed errors of method
post_refund_offers
Functions
- delete_
refund_ offers - In case the unconfimed refund offer is not sored in the booking object the delete request must return an ok (http 204). In case the refund offer is already confirmed and can not be deleted the reply must be an error (http 409 conflict).
- get_
refund_ offers - patch_
refund_ offers - post_
prepare_ refund_ offers - Step 1 in a two phase commit process. An aggregator can use this to secure that all underlaying provider systems are up and running and the provider booking is ready to be refunded.
- post_
refund_ offers - The RefundOffer contains the required information on the potential operation. One refund offer can then be accepted via a PATCH, deleted or left to die at the end of its lifetime.