Enums
- GetTrips
Collection IdError - struct for typed errors of method
get_trips_collection_id - GetTrips
IdError - struct for typed errors of method
get_trips_id - Post
Trips Change Error - struct for typed errors of method
post_trips_change - Post
Trips Error - struct for typed errors of method
post_trips
Functions
- get_
trips_ collection_ id - Returns a collection of trips for a for a given trips collection id. The unique codes of the origin and destination can be resolved using the places service.
- get_
trips_ id - A trip consists of one or more legs for a given tripId. Depending on the embed either references or full location definitions is returned.
- post_
trips - Returns trips for a given trip request based on the OJP specification.
- post_
trips_ change - Returns a new trip for given OJP parameters based on an already existing trip.