pub struct Booking {Show 27 fields
pub id: String,
pub booking_code: Option<String>,
pub external_ref: Option<Option<String>>,
pub summary: Option<Option<String>>,
pub created_on: String,
pub passengers: Vec<Passenger>,
pub purchaser: Option<Box<Purchaser>>,
pub provisional_price: Option<Box<Price>>,
pub provisional_refund_amount: Option<Box<Price>>,
pub confirmed_price: Option<Box<Price>>,
pub booked_offers: Option<Vec<BookedOffer>>,
pub trips: Option<Vec<Trip>>,
pub requested_information: Option<Option<String>>,
pub confirmation_time_limit: Option<Option<String>>,
pub fulfillment_type: Option<String>,
pub fulfillments: Option<Vec<Fulfillment>>,
pub fulfillment_status: Option<String>,
pub issued_vouchers: Option<Vec<VoucherInformation>>,
pub documents: Option<Vec<Document>>,
pub payment_methods: Option<Vec<PaymentMethod>>,
pub refund_offers: Option<Vec<RefundOffer>>,
pub release_offers: Option<Vec<ReleaseOffer>>,
pub cancel_fulfillments_offers: Option<Vec<CancelFulfillmentsOffer>>,
pub exchange_operations: Option<Vec<ExchangeOperation>>,
pub on_hold_offer: Option<Box<OnHoldOffer>>,
pub related_booking_ids: Option<Option<Vec<String>>>,
pub _links: Option<Vec<Link>>,
}Fields
id: Stringbooking_code: Option<String>The unique booking code in the provider system. Usually refers to an order number or PNR.
external_ref: Option<Option<String>>The unique booking reference in the provider system. Usually refers to an order number or PNR.
summary: Option<Option<String>>A human-readable description of the booking.
created_on: Stringpassengers: Vec<Passenger>purchaser: Option<Box<Purchaser>>provisional_price: Option<Box<Price>>provisional_refund_amount: Option<Box<Price>>confirmed_price: Option<Box<Price>>booked_offers: Option<Vec<BookedOffer>>trips: Option<Vec<Trip>>This trip will be included in the offer if the offer is part of the booking.
requested_information: Option<Option<String>>Boolean-expression indicating the data that must be set in the data model in order to proceed to next step of the process. The syntax and semantics of the expression is described in detail in the OSDM documentation.
confirmation_time_limit: Option<Option<String>>Time until the booking needs to be confirmed or put on hold. After that, the booking is no longer valid.
fulfillment_type: Option<String>Values from the Fulfillment Type Code List Listed values here are examples.
fulfillments: Option<Vec<Fulfillment>>fulfillment_status: Option<String>issued_vouchers: Option<Vec<VoucherInformation>>documents: Option<Vec<Document>>payment_methods: Option<Vec<PaymentMethod>>refund_offers: Option<Vec<RefundOffer>>Refund offers are created with the details of the to-be-confirmed refund operation. One refund offer can then be confirmed, which turns it into a refund. Refund offers in state PROPOSED might not be available in the Booking but only via the get endpoint. Confirmed refund offers must be listed here.
release_offers: Option<Vec<ReleaseOffer>>cancel_fulfillments_offers: Option<Vec<CancelFulfillmentsOffer>>exchange_operations: Option<Vec<ExchangeOperation>>on_hold_offer: Option<Box<OnHoldOffer>>If this booking has been split, this attribute references the newly created bookingIds.
_links: Option<Vec<Link>>Java Property Name: ‘links’