pub struct BookingPatchRequest {
pub external_ref: Option<Option<String>>,
pub place_selections: Option<Vec<PlaceSelection>>,
pub requested_fulfillment_type: Option<String>,
pub preferred_fulfillment_media: Option<String>,
pub used_payment_methods: Option<Vec<PaymentMethod>>,
}Expand description
BookingPatchRequest : Allows setting the required fulfillment type, e.g. value paper or e-ticket and preferred fulfillment media. The latter is optional and relevant in some cases only.
Fields
external_ref: Option<Option<String>>The unique booking reference in the distributor/retailer system. Usually refers to an order number or PNR.
place_selections: Option<Vec<PlaceSelection>>requested_fulfillment_type: Option<String>Values from the Fulfillment Type Code List Listed values here are examples.
preferred_fulfillment_media: Option<String>Fulfillment types. RCT2, RCCST and UIC_PDF are official UIC standards. Notice:ALLOCATOR_APP is deprecated and should not be used anymore. The ALLOCATOR_APP type is replaced by the RETAILER_APP type. DISTRIBUTOR_APP was introduced to distinguish between the different types of apps that can be used to fulfill a booking. Values from the Fulfillment Media Type Code List Listed values here are examples.
used_payment_methods: Option<Vec<PaymentMethod>>Implementations
Sourceimpl BookingPatchRequest
impl BookingPatchRequest
Sourcepub fn new() -> BookingPatchRequest
pub fn new() -> BookingPatchRequest
Allows setting the required fulfillment type, e.g. value paper or e-ticket and preferred fulfillment media. The latter is optional and relevant in some cases only.