pub struct BookingRequest {
pub offers: Vec<OfferSelection>,
pub passenger_specifications: Vec<PassengerSpecification>,
pub purchaser: Option<Box<PurchaserSpecification>>,
pub promotion_codes: Option<Vec<PromotionCode>>,
pub requested_fulfillment_type: Option<String>,
pub preferred_fulfillment_media: Option<String>,
pub embed: Option<Vec<BookingResponseContent>>,
pub external_ref: Option<Option<String>>,
}Fields
offers: Vec<OfferSelection>The list of offers that need to be provisionally booked, with possibly the reservations and ancillaries associated that should be booked as well.
passenger_specifications: Vec<PassengerSpecification>If needed (cf requiredInformation) or desired, this array allows providing the required details on some or all passengers
purchaser: Option<Box<PurchaserSpecification>>promotion_codes: Option<Vec<PromotionCode>>requested_fulfillment_type: Option<String>Values from the Fulfillment Type Code List Listed values here are examples.
preferred_fulfillment_media: Option<String>Fulfillment types. RCT2, RCCST and UIC_PDF are official UIC standards. Notice:ALLOCATOR_APP is deprecated and should not be used anymore. The ALLOCATOR_APP type is replaced by the RETAILER_APP type. DISTRIBUTOR_APP was introduced to distinguish between the different types of apps that can be used to fulfill a booking. Values from the Fulfillment Media Type Code List Listed values here are examples.
embed: Option<Vec<BookingResponseContent>>Influences whether referenced resources are returned in full or as references only.
external_ref: Option<Option<String>>Implementations
Sourceimpl BookingRequest
impl BookingRequest
pub fn new( offers: Vec<OfferSelection>, passenger_specifications: Vec<PassengerSpecification>, ) -> BookingRequest