pub struct Car {Show 14 fields
pub weight: i32,
pub length: i32,
pub width: i32,
pub height: i32,
pub brand: String,
pub model: String,
pub special_type: Option<Option<String>>,
pub roof_width: i32,
pub textile_roof: Option<bool>,
pub rack: Option<Box<CarRack>>,
pub attached_items: Option<Vec<String>>,
pub contact_name: Option<String>,
pub contact_detail: Option<Box<ContactDetail>>,
pub license_plate: String,
}Fields
weight: i32weight in kg
length: i32size in cm
width: i32size in cm
height: i32size in cm
brand: StringFree text description of the brand (e.g. BMW)
model: StringFree text description of the model (e.g. X5)
special_type: Option<Option<String>>roof_width: i32textile_roof: Option<bool>indication that the car has a textile rook only
rack: Option<Box<CarRack>>attached_items: Option<Vec<String>>Indication of items attached to the car
contact_name: Option<String>Name of a contact person or company in case the car transport is booked stand alone.
contact_detail: Option<Box<ContactDetail>>license_plate: StringThe license plate is a personal data item and must not be provided in an offer request. It must be patched into the offer after the customer accepted the offer for booking.
Implementations