pub struct Coach {
pub compartments: Option<Vec<Compartment>>,
pub number: String,
pub layout_id: String,
pub layout_id_upper_deck: Option<Option<String>>,
pub layout_id_lower_deck: Option<Option<String>>,
pub direction: Option<String>,
pub owner: Option<String>,
pub special_coach: Option<String>,
pub reservation_refs: Option<Vec<String>>,
}Fields
compartments: Option<Vec<Compartment>>number: Stringcoach number
layout_id: StringId to identify the coach layout. In case of two deck vehicles, both upper and lower deck layouts are provided next to each other.
layout_id_upper_deck: Option<Option<String>>id to identify a layout for the upper deck in a double deck coach
layout_id_lower_deck: Option<Option<String>>id to identify a layout for the lower deck in a double deck coach
direction: Option<String>Indicated travel direction of a coach. Standard direction is left to right with ascending coordinates in the layout values. To get the direction of travel for a place the direction information of the coach needs to be combined with the direction of the seat in the coach layout. Values from the Travel Direction Code List Listed values here are examples.
Known Values: - UNSPECIFIED - IN_DIRECTION - OPPOSITE_DIRECTION - CHANGING - @Deprecated STARING_IN_DIRECTION:
Deprecated: Substituted by STARTING_IN_DIRECTION (since: 3.5.0, removed with: 4.0.0) - STARTING_IN_DIRECTION - STARTING_OPPOSITE_TO_DIRECTION
owner: Option<String>Identifies a company. For rail, a RICS company code or compatible ERA company code are used. E.g.: ‘urn:uic:rics:1185:000011’
special_coach: Option<String>indication of special coach
reservation_refs: Option<Vec<String>>references to the reservations/fares for which all places in the coach can be selected. The reservation ids must be part of the list of reservation ids for which the consumer has requested the available places and the consumer must accept a list by setting singleSelectionMapsRequired to false