pub struct CoachAvailability {
pub number: String,
pub travel_direction: String,
pub no_passage_to_next_coach: Option<Option<bool>>,
pub decks: Option<Vec<DeckAvailability>>,
}Fields
number: StringCoach number
travel_direction: StringIndicated travel direction of a coach. Standard direction is left to right with ascending coordinates in the layout values. To get the direction of travel for a place the direction information of the coach needs to be combined with the direction of the seat in the coach layout. Values from the Travel Direction Code List Listed values here are examples.
Known Values: - UNSPECIFIED - IN_DIRECTION - OPPOSITE_DIRECTION - CHANGING - @Deprecated STARING_IN_DIRECTION:
Deprecated: Substituted by STARTING_IN_DIRECTION (since: 3.5.0, removed with: 4.0.0) - STARTING_IN_DIRECTION - STARTING_OPPOSITE_TO_DIRECTION
no_passage_to_next_coach: Option<Option<bool>>Indicates that there is no passage to the next coach.
decks: Option<Vec<DeckAvailability>>The decks of a coach ordered in ascending order from the lowest to the highest deck. Optional as for some coaches (especially special/not reservable coach types) no coach layout might exist.
Implementations
Sourceimpl CoachAvailability
impl CoachAvailability
pub fn new(number: String, travel_direction: String) -> CoachAvailability