pub struct CombinationTag {
pub id: String,
pub needs_to_be_combined: Option<Option<bool>>,
}Expand description
CombinationTag : Tag to indicate that some products from a provider can be sold only when in conjunction with product(s) from another provider using the same tag. At least one, not all, combinationTags must be in common to allow combination. No combinationTags indicate that there are no combination constraints on the product.
Fields
id: Stringneeds_to_be_combined: Option<Option<bool>>If false it means that this product can be sold also when not in conjunction with a product with the same tag. This is needed to propose specific products from one provider that depend on public ones of another.
Implementations
Sourceimpl CombinationTag
impl CombinationTag
Sourcepub fn new(id: String) -> CombinationTag
pub fn new(id: String) -> CombinationTag
Tag to indicate that some products from a provider can be sold only when in conjunction with product(s) from another provider using the same tag. At least one, not all, combinationTags must be in common to allow combination. No combinationTags indicate that there are no combination constraints on the product.