pub struct Compartment {
pub places: Vec<PlacePosition>,
pub number: Option<String>,
pub is_selectable: Option<Option<bool>>,
pub reservation_refs: Option<Vec<String>>,
pub status: Option<AvailabilityStatus>,
pub travel_class: Option<String>,
pub service_class: Option<String>,
pub selection_fee: Option<Box<SelectionFee>>,
}Expand description
Compartment : Areas within a coach that holds places. Areas might be selectable as a whole. Usual areas would be classic compartments.
Fields
places: Vec<PlacePosition>number: Option<String>Compartment number
is_selectable: Option<Option<bool>>Indicates whether compartments are selectable as a whole only
reservation_refs: Option<Vec<String>>references to the reservations/fares for which this place can be selected. The reservation ids must be part of the list of reservation ids for which the consumer has requested the available places and the consumer must accept a list by setting singleSelectionMapsRequired to false
status: Option<AvailabilityStatus>travel_class: Option<String>Traditional first and second class.
service_class: Option<String>Type of quality level, finer grained than the comfort class. Values from the Service Class Code List Listed values here are examples.
selection_fee: Option<Box<SelectionFee>>Implementations
Sourceimpl Compartment
impl Compartment
Sourcepub fn new(places: Vec<PlacePosition>) -> Compartment
pub fn new(places: Vec<PlacePosition>) -> Compartment
Areas within a coach that holds places. Areas might be selectable as a whole. Usual areas would be classic compartments.