CompartmentAvailability

Struct CompartmentAvailability 

pub struct CompartmentAvailability {
    pub service_class: String,
    pub accommodation_type: String,
    pub accommodation_sub_type: String,
    pub places: Vec<SpecificPlaceAvailability>,
    pub is_selectable: bool,
    pub number: Option<Option<String>>,
    pub status: Option<AvailabilityStatus>,
    pub reservation_refs: Option<Vec<ReservationReference>>,
    pub selection_fee: Option<Box<SelectionFee>>,
}
CompartmentAvailability : Area within a coach deck that holds places.

Fields

service_class: String

Type of quality level, finer grained than the comfort class. Values from the Service Class Code List Listed values here are examples.

accommodation_type: String

Accommodation type definition out of the Accommodation Type Code List Listed values here are examples.

accommodation_sub_type: String

Accommodation sub type definition out of the Accommodation Sub Type Code List Listed values here are examples.

places: Vec<SpecificPlaceAvailability>

Seats or bicycle hooks in a coach compartment that are covered by a requested reservation fare/offerPart/bookingPart. No place availabilities must be returned for places that are NOT covered by a requested offer.

is_selectable: bool

Indicates whether the compartment is selectable as a whole only.

number: Option<Option<String>>

Compartment number as indicated at the compartment in the coach. A compartment number must be set if the compartment is selectable as a whole only.

status: Option<AvailabilityStatus>reservation_refs: Option<Vec<ReservationReference>>

reservationRefs must be set if the compartment is selectable as a whole only

selection_fee: Option<Box<SelectionFee>>

Implementations

Source

impl CompartmentAvailability

pub fn new( service_class: String, accommodation_type: String, accommodation_sub_type: String, places: Vec<SpecificPlaceAvailability>, is_selectable: bool, ) -> CompartmentAvailability

Area within a coach deck that holds places.