DecisionType

Enum DecisionType 

pub enum DecisionType {
    Accepted,
    Rejected,
    GoodWill,
    PartiallyAccepted,
}
DecisionType : Summary result of decision on a complaint - ACCEPTED: the complaint is accepted and refund or compensation will be paid - REJECTED: the complaint is rejected and no refund or compensation will be paid - GOOD_WILL: a good will compensation is offered, no legal obligation to pay refund or compensation exists - PARTIALLY_ACCEPTED: the complaint is partially accepted, e.g. for part of the journey or part of the passengers Summary result of decision on a complaint - ACCEPTED: the complaint is accepted and refund or compensation will be paid - REJECTED: the complaint is rejected and no refund or compensation will be paid - GOOD_WILL: a good will compensation is offered, no legal obligation to pay refund or compensation exists - PARTIALLY_ACCEPTED: the complaint is partially accepted, e.g. for part of the journey or part of the passengers

Variants



Accepted



Rejected



GoodWill



PartiallyAccepted