pub enum DirectionType {
Right,
Left,
Up,
Down,
}Expand description
DirectionType : Direction of a place, defined optional as it might be omitted in case of berths in future. Code list according to UIC90918-1 Valid Values: - RIGHT: to right, RIGHT is the default. In case of walls it indicates a wall parallel with the x axis. - LEFT: to left - UP: up (from right side of a coach pointing to the middle of the aisle) - DOWN: down (from right side of the coach pointing to the middle of the aisle) Direction of a place, defined optional as it might be omitted in case of berths in future. Code list according to UIC90918-1 Valid Values: - RIGHT: to right, RIGHT is the default. In case of walls it indicates a wall parallel with the x axis. - LEFT: to left - UP: up (from right side of a coach pointing to the middle of the aisle) - DOWN: down (from right side of the coach pointing to the middle of the aisle)
Variants