pub struct ExchangeOperationPatchRequest {
pub requested_fulfillment_type: Option<String>,
pub preferred_fulfillment_media: Option<String>,
pub embed: Option<Vec<ExchangeOperationResponseContent>>,
}Expand description
ExchangeOperationPatchRequest : Allows modifying a general setting for the booking: * setting the required fulfillment type, e.g. value paper or e-ticket and preferred fulfillment media. The latter is optional and relevant in some cases only. * Provisionally exchanging some of the fulfillments in the booking
Fields
requested_fulfillment_type: Option<String>Values from the Fulfillment Type Code List Listed values here are examples.
preferred_fulfillment_media: Option<String>Fulfillment types. RCT2, RCCST and UIC_PDF are official UIC standards. Notice:ALLOCATOR_APP is deprecated and should not be used anymore. The ALLOCATOR_APP type is replaced by the RETAILER_APP type. DISTRIBUTOR_APP was introduced to distinguish between the different types of apps that can be used to fulfill a booking. Values from the Fulfillment Media Type Code List Listed values here are examples.
embed: Option<Vec<ExchangeOperationResponseContent>>Influences whether referenced resources are returned in full or as references only.
Implementations
Sourceimpl ExchangeOperationPatchRequest
impl ExchangeOperationPatchRequest
Sourcepub fn new() -> ExchangeOperationPatchRequest
pub fn new() -> ExchangeOperationPatchRequest
Allows modifying a general setting for the booking: * setting the required fulfillment type, e.g. value paper or e-ticket and preferred fulfillment media. The latter is optional and relevant in some cases only. * Provisionally exchanging some of the fulfillments in the booking