pub struct FulfillmentActivationPatchRequest {
pub selected_zone_ids: Option<Option<Vec<String>>>,
pub travel_dates: Option<Option<Vec<String>>>,
pub start_of_usage: Option<String>,
pub from_place: Option<Box<PlaceRef>>,
pub stock_control_numbers: Option<Option<Vec<String>>>,
pub continuous_service_vehicle_selection: Option<Box<ContinuousServiceVehicleSelection>>,
}Expand description
FulfillmentActivationPatchRequest : Changes the fulfillment to status AVAILABLE. In the case of multi-journey product, one of the fulfillment is now ‘activated’ and can be used to travel. Selects on-demand vehicles. Selects pick-up place and vehicle type for continuous services.
Fields
selected_zone_ids: Option<Option<Vec<String>>>travel_dates: Option<Option<Vec<String>>>start_of_usage: Option<String>from_place: Option<Box<PlaceRef>>stock_control_numbers: Option<Option<Vec<String>>>The ids of the secure paper stock that identifies the blank secure paper stock used for printing. The stock control number is only used for secure paper stock and triggers a printing of the stock control number in the ticket layout. This establishes a link between paper stock and ticket that is used to control the usage of blank secure paper stock at offices as secure paper has otherwise no intrinsic protection against internal fraud.
continuous_service_vehicle_selection: Option<Box<ContinuousServiceVehicleSelection>>Implementations
Sourceimpl FulfillmentActivationPatchRequest
impl FulfillmentActivationPatchRequest
Sourcepub fn new(start_of_usage: Option<String>) -> FulfillmentActivationPatchRequest
pub fn new(start_of_usage: Option<String>) -> FulfillmentActivationPatchRequest
Changes the fulfillment to status AVAILABLE. In the case of multi-journey product, one of the fulfillment is now ‘activated’ and can be used to travel. Selects on-demand vehicles. Selects pick-up place and vehicle type for continuous services.