LegAttribute

Struct LegAttribute 

pub struct LegAttribute {
    pub text: String,
    pub code: Option<Option<String>>,
    pub from_stop_seq_number: Option<Option<i32>>,
    pub to_stop_seq_number: Option<Option<i32>>,
}
LegAttribute : Attributes that are not valid on the whole service, but only on section of a trip made on a single mode without interchange between boarding and alighting.

Fields

text: String

Text of the attribute to be shown to the user.

code: Option<Option<String>>

Internal code of the attribute. Can be used for detection of double occurrences. Refers to Service Facilities / Leg Attributes from the Catalog of Code Lists

from_stop_seq_number: Option<Option<i32>>

The attribute is valid from the stop point with this sequence number within the leg. If missing it is valid from the beginning of the leg.

to_stop_seq_number: Option<Option<i32>>

The attribute is valid to the stop point (inclusively) with this sequence number within the leg. If missing it is valid to the end of the leg.

Implementations

Source

impl LegAttribute

pub fn new(text: String) -> LegAttribute

Attributes that are not valid on the whole service, but only on section of a trip made on a single mode without interchange between boarding and alighting.