pub struct Link {
pub rel: String,
pub href: String,
pub type: Option<Option<String>>,
pub value: Option<Option<String>>,
}Expand description
Link : The underlying system may provide links for pagination of links pointing on further information (such as HTML download links, web sites or extended APIs). Mechanism to add flexible extensions specific to an underlying system. Implemented the JSON-HAL specification.
Fields
rel: Stringthe ‘rel’ field in HATEOAS navigation.
href: StringAllows to provide a value to the link, for example id of the targeted resource or displayable representation for the link.
type: Option<Option<String>>Hint to indicate the media type expected when dereferencing the target resource.
value: Option<Option<String>>Allows to provide a value to the link, for example id of the targeted resource or displayable representation for the link.
Implementations
Sourceimpl Link
impl Link
Sourcepub fn new(rel: String, href: String) -> Link
pub fn new(rel: String, href: String) -> Link
The underlying system may provide links for pagination of links pointing on further information (such as HTML download links, web sites or extended APIs). Mechanism to add flexible extensions specific to an underlying system. Implemented the JSON-HAL specification.