pub struct MotorCycle {
pub weight: i32,
pub length: i32,
pub width: i32,
pub height: i32,
pub brand: String,
pub model: String,
pub is_side_car_included: Option<Option<bool>>,
pub contact_name: String,
pub contact_detail: Option<Box<ContactDetail>>,
pub license_plate: String,
}Fields
weight: i32weight in kg
length: i32size in cm
width: i32size in cm
height: i32size in cm
brand: StringFree text description of the brand (e.g. BMW)
model: StringFree text description of the model (e.g. X5)
is_side_car_included: Option<Option<bool>>deprecated use car of type SPECIAL_VEHILE instead
contact_name: StringName of a contact person or company in case the car transport is booked stand alone.
contact_detail: Option<Box<ContactDetail>>license_plate: StringThe license plate is a personal data item and must not be provided in an offer request. It must be patched into the offer after the customer accepted the offer for booking
Implementations