pub struct OfferCollectionRequest {Show 14 fields
pub trip_ids: Option<Option<Vec<String>>>,
pub inbound_trip_ids: Option<Option<Vec<String>>>,
pub trip_specifications: Option<Vec<TripSpecification>>,
pub inbound_trip_specifications: Option<Vec<TripSpecification>>,
pub trip_search_criteria: Option<Box<TripSearchCriteria>>,
pub trip_response_parameters: Option<Box<TripResponseParameters>>,
pub non_trip_search_criteria: Option<Box<NonTripSearchCriteria>>,
pub requested_sections: Option<Vec<Section>>,
pub offer_search_criteria: Option<Box<OfferSearchCriteria>>,
pub anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>,
pub corporate_codes: Option<Vec<CorporateCode>>,
pub promotion_codes: Option<Vec<PromotionCode>>,
pub requested_fulfillment_options: Option<Vec<FulfillmentOption>>,
pub embed: Option<Vec<OfferCollectionResponseContent>>,
}Expand description
OfferCollectionRequest : Defines the parameters needed to request an offer. Either a tripSearchCriteria, a list of trip specifications, or a list of tripIds can be passed in to request offers. If you are searching for fares you pass in the complete trip and the use the requestedSections attribute to define which part(s) you need fares (including virtual border points).
Fields
trip_ids: Option<Option<Vec<String>>>ID of trips representing single or outbound trips to be offered.
inbound_trip_ids: Option<Option<Vec<String>>>ID of trips representing return or inbound trips to be offered. Fill in only When requesting return products or fares.
trip_specifications: Option<Vec<TripSpecification>>inbound_trip_specifications: Option<Vec<TripSpecification>>trip_search_criteria: Option<Box<TripSearchCriteria>>trip_response_parameters: Option<Box<TripResponseParameters>>non_trip_search_criteria: Option<Box<NonTripSearchCriteria>>requested_sections: Option<Vec<Section>>offer_search_criteria: Option<Box<OfferSearchCriteria>>anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>corporate_codes: Option<Vec<CorporateCode>>promotion_codes: Option<Vec<PromotionCode>>requested_fulfillment_options: Option<Vec<FulfillmentOption>>embed: Option<Vec<OfferCollectionResponseContent>>Influences whether referenced resources are returned in full or as references only. Proposed default ALL
Implementations
Sourceimpl OfferCollectionRequest
impl OfferCollectionRequest
Sourcepub fn new(
anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>,
) -> OfferCollectionRequest
pub fn new( anonymous_passenger_specifications: Vec<AnonymousPassengerSpecification>, ) -> OfferCollectionRequest
Defines the parameters needed to request an offer. Either a tripSearchCriteria, a list of trip specifications, or a list of tripIds can be passed in to request offers. If you are searching for fares you pass in the complete trip and the use the requestedSections attribute to define which part(s) you need fares (including virtual border points).