pub struct OfferSelection {
pub offer_id: String,
pub external_ref: Option<String>,
pub optional_reservation_selections: Option<Vec<ReservationSelection>>,
pub optional_ancillary_selections: Option<Vec<AncillarySelection>>,
pub place_selections: Option<Vec<PlaceSelection>>,
pub after_sale_by_retailer_only: Option<Option<bool>>,
pub applied_regulatory_condition: Option<RegulatoryCondition>,
pub passenger_refs: Vec<String>,
pub through_ticket_tags: Option<Vec<String>>,
}Expand description
OfferSelection : The Ids of the offers to be booked need to be passed in.
Fields
offer_id: Stringid of the selected offer or exchangeOffer
external_ref: Option<String>A stable reference to the id of the offer in the caller’s system. When received in input of a request, it must be persisted and echoed back in the response.
optional_reservation_selections: Option<Vec<ReservationSelection>>Mandatory reservations are booked when the booking is being booked.
optional_ancillary_selections: Option<Vec<AncillarySelection>>place_selections: Option<Vec<PlaceSelection>>after_sale_by_retailer_only: Option<Option<bool>>in case the distributor has proposed this offer in conjunction with an offer of another provider constrained by a combinationTag, this flag must be set to true to indicate to the provider that after-sale must be done on the totality of the distributor’s booking. Only after-sale requests triggered by the distributor can be safely processed on this offer. When the flag is not set, standard provider logic applies.
applied_regulatory_condition: Option<RegulatoryCondition>passenger_refs: Vec<String>Implementations