pub struct Passenger {Show 13 fields
pub id: String,
pub summary: Option<Option<String>>,
pub external_ref: String,
pub date_of_birth: Option<Option<String>>,
pub age: Option<Option<i32>>,
pub type: String,
pub cards: Option<Vec<CardReference>>,
pub gender: Option<Option<Gender>>,
pub detail: Option<Box<PersonDetail>>,
pub identification_card: Option<Box<IdentificationCard>>,
pub transportable_details: Option<Box<Transportable>>,
pub prm_needs: Option<Vec<String>>,
pub _links: Option<Vec<Link>>,
}Expand description
Passenger : Information about a passenger. Either the date of birth or the age at the time of travel needs to be set. We recommend to use date of birth as it is more stable than age.
Fields
id: Stringsummary: Option<Option<String>>A human-readable description of the passenger.
external_ref: StringA stable reference to a passenger from other elements, or from caller system. When passed in passenger specification in an offer request, it must be echoed back in the response.
date_of_birth: Option<Option<String>>date of birth of the passenger
age: Option<Option<i32>>type: StringPassenger type according to UIC passenger, i.e. passenger type list. Values from the Passenger Type Code List Listed values here are examples. Proposed default PERSON
cards: Option<Vec<CardReference>>reduction or loyalty cards owned by the passenger
gender: Option<Option<Gender>>detail: Option<Box<PersonDetail>>identification_card: Option<Box<IdentificationCard>>transportable_details: Option<Box<Transportable>>prm_needs: Option<Vec<String>>For the persons with reduced mobility (PRMs) its specific needs for support are expressed.
_links: Option<Vec<Link>>Java Property Name: ‘links’