pub struct PlaceGroup {
pub service_class: String,
pub accommodation_type: Option<String>,
pub accommodation_sub_type: Option<String>,
pub places: Vec<PlaceLayout>,
}Expand description
PlaceGroup : A place group groups places by service class and optionally by accommodation sub type. A place group not necessarily needs to be visualized (e.g. as a rectangle). Visualization can be done using ServiceIcons and GraphicElements. Nevertheless, a place group can be useful for rendering of coach decks/places for which no place availabilities were returned, as further information (service class, accommodation sub type) can be displayed . If availabilities were returned for a certain place, travel class and accommodation sub type values returned in the availability response must be displayed (they replace the static travel class / accommodation sub type defined on the place group). Reason: travel class and accommodation sub type values can dynamically change for each vehicle run. Example 1: Class upgrade A customer with a second class reservation ticket might be placed on a first class seat. Example 2: New/more specific AccommodationSubType AccommodationSubType=BUSINESS defined in static master data might be changed into AccommodationSubType=BUSINESS_COMFORT on certain vehicle runs.
Fields
service_class: StringType of quality level, finer grained than the comfort class. Values from the Service Class Code List Listed values here are examples.
accommodation_type: Option<String>Accommodation type definition out of the Accommodation Type Code List Listed values here are examples.
accommodation_sub_type: Option<String>Accommodation sub type definition out of the Accommodation Sub Type Code List Listed values here are examples.
places: Vec<PlaceLayout>Seats or bicycle hooks in a coach compartment.
Implementations
Sourceimpl PlaceGroup
impl PlaceGroup
Sourcepub fn new(service_class: String, places: Vec<PlaceLayout>) -> PlaceGroup
pub fn new(service_class: String, places: Vec<PlaceLayout>) -> PlaceGroup
A place group groups places by service class and optionally by accommodation sub type. A place group not necessarily needs to be visualized (e.g. as a rectangle). Visualization can be done using ServiceIcons and GraphicElements. Nevertheless, a place group can be useful for rendering of coach decks/places for which no place availabilities were returned, as further information (service class, accommodation sub type) can be displayed . If availabilities were returned for a certain place, travel class and accommodation sub type values returned in the availability response must be displayed (they replace the static travel class / accommodation sub type defined on the place group). Reason: travel class and accommodation sub type values can dynamically change for each vehicle run. Example 1: Class upgrade A customer with a second class reservation ticket might be placed on a first class seat. Example 2: New/more specific AccommodationSubType AccommodationSubType=BUSINESS defined in static master data might be changed into AccommodationSubType=BUSINESS_COMFORT on certain vehicle runs.