pub struct ProductRequestOfferSelection {
pub product_code: Option<String>,
pub product_tag: Option<String>,
pub number_of_items: Option<Option<i32>>,
pub external_passenger_refs: Option<Vec<String>>,
}Expand description
ProductRequestOfferSelection : product selection by product code or product tag for an offer request (exactly one of productCode and productTag must be provided). The number of items indicates the quantity to be required. Passengers must be referenced in case the product is intended for passengers.
Fields
product_code: Option<String>product_tag: Option<String>number_of_items: Option<Option<i32>>external_passenger_refs: Option<Vec<String>>Implementations
Sourceimpl ProductRequestOfferSelection
impl ProductRequestOfferSelection
Sourcepub fn new() -> ProductRequestOfferSelection
pub fn new() -> ProductRequestOfferSelection
product selection by product code or product tag for an offer request (exactly one of productCode and productTag must be provided). The number of items indicates the quantity to be required. Passengers must be referenced in case the product is intended for passengers.