pub struct RefundOfferRequest {
pub fulfillment_ids: Vec<String>,
pub refund_specifications: Option<Vec<RefundSpecification>>,
pub overrule_code: Option<String>,
pub refund_date: Option<Option<String>>,
}Expand description
RefundOfferRequest : Request for a refund offer. Fulfillments can be provided in case the booking contains multiple individual fulfillments.
Fields
fulfillment_ids: Vec<String>ids of the fulfillments to refund
refund_specifications: Option<Vec<RefundSpecification>>To do a partial refund repeat the fulfillmentIds affected and point out what to refund
overrule_code: Option<String>Reason for and type of an after sale, code list in IRS 90918-10. The PRM_SUPPORT_UNAVAILABLE overrule code shall only be used by the UIC PRM ABT tool. Values from the Overrule Codes Code List Listed values here are examples. - ‘CONNECTION_BROKEN’ - ‘DEATH’ - ‘EQUIPMENT_FAILURE’ - ‘PAYMENT_FAILURE’ - ‘PRM_SUPPORT_UNAVAILABLE’ - ‘SALES_STAFF_ERROR’ - ‘STOP_NOT_SERVED’ - ‘STRIKE’ - ‘TECHNICAL_FAILURE’ - ‘TICKET_NOT_USED’ - ‘INABILITY_TO_TRAVEL’: Inability to travel due to accident or sickness. - ‘EXTERNAL_COMPENSATION’: Offer has been compensated outside of the provider system in another way. - ‘DISRUPTION’: Inability to operate due to disruption. - ‘JOURNEY_OBSOLETE’: Due to external factors it’s senseless to start the trip, thus the travel is obsolete. - ‘CERTIFIED_MEDICAL_CONDITION’: A medical certificate certifies that the passenger is unable to travel. - ‘DELAY_COMPENSATION’: Allows to override conditions in context of passenger rights regulation (PRR).
refund_date: Option<Option<String>>Indicates for passes the date taken as reference to compute possible partial refund. It is also the date taken as reference to invalidate the pass partially refunded.
Implementations
Sourceimpl RefundOfferRequest
impl RefundOfferRequest
Sourcepub fn new(fulfillment_ids: Vec<String>) -> RefundOfferRequest
pub fn new(fulfillment_ids: Vec<String>) -> RefundOfferRequest
Request for a refund offer. Fulfillments can be provided in case the booking contains multiple individual fulfillments.