pub enum RegulatoryCondition {
Civ,
Md,
EuPrr,
}Expand description
RegulatoryCondition : General conditions applied to cover legal regulations within the area of validity. Allocators must reflect these terms and conditions in the conditions of combined offers and indicate them to the customer where required. Which indications are mandatory to be shown to the customer is defined in the SCICs. Valid Values: - CIV: terms and conditions according to COTIV regulation - MD: terms and conditions according to SMPS regulation - EU_PRR: terms and conditions according to EU-PRR regulation General conditions applied to cover legal regulations within the area of validity. Allocators must reflect these terms and conditions in the conditions of combined offers and indicate them to the customer where required. Which indications are mandatory to be shown to the customer is defined in the SCICs. Valid Values: - CIV: terms and conditions according to COTIV regulation - MD: terms and conditions according to SMPS regulation - EU_PRR: terms and conditions according to EU-PRR regulation
Variants