pub struct Reimbursement {
pub id: String,
pub request: Box<ReimbursementRequest>,
pub status: BackOfficeStatus,
pub missing_information: Option<Option<Vec<String>>>,
pub decision: Option<Box<ReimbursementDecision>>,
pub _links: Option<Vec<Link>>,
}Expand description
Reimbursement : Customers who have bought a ticket which allows reimbursement and which have not traveled or traveled partially only can claim to be reimbursed. The customer must prove that he has not or only partially used the ticket. A partial use might be a only a part of the trip was traveled or only some of the travelers were traveling or a combination of both.
Fields
id: Stringrequest: Box<ReimbursementRequest>status: BackOfficeStatusmissing_information: Option<Option<Vec<String>>>decision: Option<Box<ReimbursementDecision>>_links: Option<Vec<Link>>Java Property Name: ‘links’
Implementations
Sourceimpl Reimbursement
impl Reimbursement
Sourcepub fn new(
id: String,
request: ReimbursementRequest,
status: BackOfficeStatus,
) -> Reimbursement
pub fn new( id: String, request: ReimbursementRequest, status: BackOfficeStatus, ) -> Reimbursement
Customers who have bought a ticket which allows reimbursement and which have not traveled or traveled partially only can claim to be reimbursed. The customer must prove that he has not or only partially used the ticket. A partial use might be a only a part of the trip was traveled or only some of the travelers were traveling or a combination of both.