pub struct ReimbursementRequest {
pub reimbursement_reason: String,
pub reimbursement_date: Option<Option<String>>,
pub reimbursed_passenger_ids: Vec<String>,
pub trip_sections: Option<Vec<TripSection>>,
pub fulfillment_ids: Vec<String>,
pub supporting_documents: Option<Vec<SupportingDocument>>,
}Expand description
ReimbursementRequest : The reimbursement process is used to support refunds which are not covered by the online refund/exchange processes, e.g.: Partial refund of a trip (Trip was Hamburg - Munich, but only Hamburg - Kassel was used), Refund outside of rules due to good will. This is a manual back office process within the provider’s organization which is triggered by this request. State changes can be signaled by web hook events.
Fields
reimbursement_reason: StringReason why the booking should be reimbursed.
reimbursement_date: Option<Option<String>>reimbursed_passenger_ids: Vec<String>trip_sections: Option<Vec<TripSection>>fulfillment_ids: Vec<String>supporting_documents: Option<Vec<SupportingDocument>>Implementations
Sourceimpl ReimbursementRequest
impl ReimbursementRequest
Sourcepub fn new(
reimbursement_reason: String,
reimbursed_passenger_ids: Vec<String>,
fulfillment_ids: Vec<String>,
) -> ReimbursementRequest
pub fn new( reimbursement_reason: String, reimbursed_passenger_ids: Vec<String>, fulfillment_ids: Vec<String>, ) -> ReimbursementRequest
The reimbursement process is used to support refunds which are not covered by the online refund/exchange processes, e.g.: Partial refund of a trip (Trip was Hamburg - Munich, but only Hamburg - Kassel was used), Refund outside of rules due to good will. This is a manual back office process within the provider’s organization which is triggered by this request. State changes can be signaled by web hook events.