ReturnSearchParameters

Struct ReturnSearchParameters 

pub struct ReturnSearchParameters {
    pub inward_return_date: Option<Option<String>>,
    pub outbound_trip_ids: Option<Option<Vec<String>>>,
    pub outward_offer_ids: Option<Option<Vec<String>>>,
    pub outward_offer_tag: Option<Option<String>>,
    pub departure_time: Option<Option<String>>,
    pub arrival_time: Option<Option<String>>,
    pub vias: Option<Vec<TripVia>>,
    pub parameters: Option<Box<TripParameters>>,
}
ReturnSearchParameters : This property can be used in case a return trip is being requested. This will allow to benefit from return-specific fares or product. Only one of outwardTripIds, outwardOfferIds, or should be provided. inwardReturnDate and outwardOfferTag should not be used as they are deprecated in 3.7.0 and will be removed in 4.0.0.

Fields

inward_return_date: Option<Option<String>>

Needs to be provided when creating the collection of outbound travels so that the provider knows when a inbound travel can be expected and propose appropriate product and fares. Superseded by OfferSearchCriteria.inboundDate.

outbound_trip_ids: Option<Option<Vec<String>>>

Needs to be provided when creating collection of offers covering both outbound and inbound (return) journey.

outward_offer_ids: Option<Option<Vec<String>>>

Needs to be provided when creating the collection of inbound travels so that the provider can relate the inbound travels to the outbound travels context.

outward_offer_tag: Option<Option<String>>

Needs to be provided when creating the collection of inbound travels so that the provider knows what the outbound offer is and and propose compatible offers only if desired or mandatory.

departure_time: Option<Option<String>>

Needs to be in local date time format of the stop. Exactly one of departureTime and arrivalTime must be provided.

arrival_time: Option<Option<String>>

Needs to in be local date time format of the stop. Exactly one of departureTime and arrivalTime must be provided.

vias: Option<Vec<TripVia>>

Ordered series of points where the journey must pass through. If more than one via point is given all of them must be obeyed - in the correct order. The server is allowed to replace a via stop by equivalent stops. TripDataFilters given at a via apply to the section after that via. To apply a TripDataFilter for the first section (between the origin and the first via), use the TripDataFilter within the TripParameters structure.

parameters: Option<Box<TripParameters>>

Implementations

Source

impl ReturnSearchParameters

pub fn new() -> ReturnSearchParameters

This property can be used in case a return trip is being requested. This will allow to benefit from return-specific fares or product. Only one of outwardTripIds, outwardOfferIds, or should be provided. inwardReturnDate and outwardOfferTag should not be used as they are deprecated in 3.7.0 and will be removed in 4.0.0.