pub struct StopPlace {
pub object_type: String,
pub id: String,
pub alternative_ids: Option<Option<Vec<String>>>,
pub geo_position: Option<Box<GeoPosition>>,
pub ref: Option<Box<PlaceRef>>,
pub _links: Option<Vec<Link>>,
pub name: String,
}Expand description
StopPlace : A place extended by accessibility limitation properties and some attributes of the associated equipment, comprising one or more places where vehicles may stop and where passengers may board or leave vehicles or prepare their trip, and which will usually have one or more wellknown names. Provided by OJP.
Fields
object_type: StringAttribute is used as discriminator for inheritance between data types.
id: Stringid defining the place. The code is provided as URN, relative URNs are allowed with base path urn:uic:stn ‘0850000’
alternative_ids: Option<Option<Vec<String>>>For a place with ids in different reference systems, the alternative ids can be returned. The reference system is encoded in the string. E.g.: ‘urn:uic:std:80000’, ‘x_swe:stn:10000’, ‘ch:1:sloid:343434’
geo_position: Option<Box<GeoPosition>>ref: Option<Box<PlaceRef>>_links: Option<Vec<Link>>Java Property Name: ‘links’
name: StringName of this stop place for use in passenger information.
Implementations
Sourceimpl StopPlace
impl StopPlace
Sourcepub fn new(object_type: String, id: String, name: String) -> StopPlace
pub fn new(object_type: String, id: String, name: String) -> StopPlace
A place extended by accessibility limitation properties and some attributes of the associated equipment, comprising one or more places where vehicles may stop and where passengers may board or leave vehicles or prepare their trip, and which will usually have one or more wellknown names. Provided by OJP.